<?php
/**
* Class ContentWorkflow
*
* Class for managing the content history
*
* @copyright	CONTREXX CMS - Astalavista IT Engineering GmbH Thun
* @author		Thomas Kaelin <thomas.kaelin@astalvista.ch>
* @access		public
* @module		ContentWorkflow
* @modulegroup	core
* @version		1.0.0
*/
require_once ASCMS_CORE_PATH.'/Tree.class.php';

class ContentWorkflow {
	var $strPageTitle;
	var $strStatusMessage;
		
	/**
    * Constructor
    *
    * @global 	object		$objDatabase
    * @global 	object		$objTemplate
    * @global 	array		$_CORELANG
    * @global 	array		$_CONFIG
    */
    function ContentWorkflow() {   
    	global $objDatabase,$objTemplate,$_CORELANG,$_CONFIG;

    	$objDatabase->Execute('DELETE FROM	'.DBPREFIX.'content_logfile WHERE history_id=0');    	
		$objDatabase->Execute('OPTIMIZE TABLE '.DBPREFIX.'content_logfile');
		$objDatabase->Execute('OPTIMIZE TABLE '.DBPREFIX.'content_history');
	    $objDatabase->Execute('OPTIMIZE TABLE '.DBPREFIX.'content_navigation_history');    	
    	
		$objTemplate->setVariable(	'CONTENT_NAVIGATION',
		                   			'<a href="index.php?cmd=workflow&amp;act=new">'.$_CORELANG['TXT_NEW_PAGES'].'</a>
		                   			 <a href="index.php?cmd=workflow&amp;act=updated">'.$_CORELANG['TXT_UPDATED_PAGES'].'</a>
		                   			 <a href="index.php?cmd=workflow&amp;act=deleted">'.$_CORELANG['TXT_DELETED_PAGES'].'</a>
		                   			 <a href="index.php?cmd=workflow&amp;act=unvalidated">'.$_CORELANG['TXT_WORKFLOW_VALIDATE'].'</a>
		                   		');                			
		                   			
		if ($_CONFIG['contentHistoryStatus'] == 'off') {
			$this->strStatusMessage = $_CORELANG['TXT_WORKFLOW_NOT_ACTIVE'];	
		}
	}
	
	/**
    * Calls the requested function
    *
    * @global 	object		$objTemplate
    * @global 	object		$objPerm
    * @global 	array		$_CORELANG
    */
    function getPage() {
    	global $objTemplate, $objPerm,$_CORELANG;	
					
    	if(!isset($_GET['act'])){
    	    $_GET['act'] = '';	
    	}
    	
    	switch ($_GET['act']) {	
    		//perm 76 is for validating pages
			case 'restoreHistory':
				$objPerm->checkAccess(77, 'static');
				$intPageId = $this->loadHistory($_GET['hId'],true);
				$this->redirectPage($intPageId);
			break;
			case 'activateHistory':
			$objPerm->checkAccess(79, 'static');
				$intPageId = $this->loadHistory($_GET['hId']);
				$this->redirectPage($intPageId);
			break; 
			case 'deleteHistory':
				$objPerm->checkAccess(80, 'static');
				$intPageId = $this->deleteHistory($_GET['hId']);
				$this->redirectPage($intPageId);
			break;
			case 'new':
    			$objPerm->checkAccess(75, 'static');
    			$this->showHistory();			
			break;
    		case 'updated':
    			$objPerm->checkAccess(75, 'static');
    			$this->showHistory('updated');
    		break;
    		case 'deleted':
    			$objPerm->checkAccess(75, 'static');
    			$this->showHistory('deleted');
    		break;
    		case 'unvalidated':
    			$objPerm->checkAccess(69, 'static');
    			$this->showHistory('unvalidated');
    		break;
    		case 'validate':
    			$objPerm->checkAccess(69, 'static');
    			$this->validatePage($_GET['id'],$_GET['acc']);
    			$this->showHistory('unvalidated');
    		break;
    		default:
      			$objPerm->checkAccess(69, 'static');
    			$this->showHistory('unvalidated');

    	}
    	
    	$objTemplate->setVariable(array(
			'CONTENT_TITLE'				=> $this->strPageTitle,
			'CONTENT_STATUS_MESSAGE'	=> $this->strStatusMessage
		));    			
    }
    
	/**
    * Show logfile-entries (new, updated or deleted)
    *
    * @global 	object		$objTemplate
    * @global 	object		$objDatabase
    * @global 	array		$_CORELANG
    * @global 	array		$_CONFIG
    */    
    function showHistory($strAction='new') {
		global $objTemplate,$objDatabase,$_CORELANG,$_CONFIG;
		
		switch ($strAction) {
			case 'updated':
				$this->strPageTitle	= $_CORELANG['TXT_UPDATED_PAGES'];
				$strTitle 			= $_CORELANG['TXT_UPDATED_PAGES'];
				$strPagingAct		= 'updated';
				$strQueryWhere 		= 'WHERE action="update" AND is_validated="1"';	
			break;
			case 'deleted':
				$this->strPageTitle	= $_CORELANG['TXT_DELETED_PAGES'];
				$strTitle 			= $_CORELANG['TXT_DELETED_PAGES'];
				$strPagingAct		= 'deleted';
				$strQueryWhere 		= 'WHERE action="delete" AND is_validated="1"';	
			break;
			case 'unvalidated':
				$this->strPageTitle	= $_CORELANG['TXT_WORKFLOW_VALIDATE'];
				$strTitle			= $_CORELANG['TXT_WORKFLOW_VALIDATE'];
				$strPagingAct		= 'unvalidated';
				$strQueryWhere 		= 'WHERE is_validated="0"';
			break;
			default:
				$this->strPageTitle	= $_CORELANG['TXT_NEW_PAGES'];
				$strTitle 			= $_CORELANG['TXT_NEW_PAGES'];
				$strPagingAct		= 'new';
				$strQueryWhere 		= 'WHERE action="new" AND is_validated="1"';	
		}
		
		$objTemplate->addBlockfile('ADMIN_CONTENT', 'content_history', 'content_history.html');
		$objTemplate->setVariable(array(
			'TXT_TITLE'					=> $strTitle,
		    'TXT_SUBTITLE_DATE'			=> $_CORELANG['TXT_DATE'],
		    'TXT_SUBTITLE_NAME'			=> $_CORELANG['TXT_PAGETITLE'],
		    'TXT_SUBTITLE_MODULE'		=> $_CORELANG['TXT_MODULE'],
		    'TXT_SUBTITLE_USER'			=> $_CORELANG['TXT_USER'],
		    'TXT_SUBTITLE_FUNCTIONS'	=> $_CORELANG['TXT_FUNCTIONS'],
			'TXT_DELETED_RESTORE_JS'	=> $_CORELANG['TXT_DELETED_RESTORE_JS']
		));
		
	//THEMES
		$objResult = $objDatabase->Execute('SELECT	id,
													themesname
											FROM	'.DBPREFIX.'skins
											');
		$arrThemes[0] = $_CORELANG['TXT_STANDARD'];
		while (!$objResult->EOF) {
			$arrThemes[$objResult->fields['id']] = $objResult->fields['themesname'];
			$objResult->MoveNext();
		}
	//MODULES
		$objResult = $objDatabase->Execute('SELECT	id,
													name
											FROM	'.DBPREFIX.'modules
										');
		while (!$objResult->EOF) {
			$arrModules[$objResult->fields['id']] = $objResult->fields['name'];
			$objResult->MoveNext();
		}
		$arrModules[0] = '-';
	//GROUPS
		$objResult = $objDatabase->Execute('SELECT	group_id,
													group_name
											FROM	'.DBPREFIX.'access_user_groups
										');
		$arrGroups[0] = '-';
		while (!$objResult->EOF) {
			$arrGroups[$objResult->fields['group_id']] = $objResult->fields['group_name'];
			$objResult->MoveNext();
		}
	//PAGES
		$objResult = $objDatabase->Execute('SELECT	id,
													history_id,
													action
											FROM	'.DBPREFIX.'content_logfile
											'.$strQueryWhere.'
										');
		/** start paging **/
		$strPaging = getPaging($objResult->RecordCount(),intval($_GET['pos']),'&amp;cmd=workflow&act='.$strPagingAct,'<b>'.$_ARRAYLANG['TXT_GUESTBOOK_ENTRIES'].'</b>', true);
		$objTemplate->setVariable('HISTORY_PAGING',$strPaging);
		/** end paging **/	

		$objResult = $objDatabase->SelectLimit('SELECT		id,
															history_id,
															action
												FROM		'.DBPREFIX.'content_logfile
												'.$strQueryWhere.'
												ORDER BY	id DESC',
												$_CONFIG['corePagingLimit'],
												intval($_GET['pos'])
											);		
		
		while (!$objResult->EOF) {
				$arrHistory[$objResult->fields['history_id']] = array(	'id'		=>	$objResult->fields['id'],
																		'action'	=>	$objResult->fields['action']
																	);																	
			$objResult->MoveNext();	
		}
		
		$iRowId = 0;
		
		if (count($arrHistory) > 0) {
			$intRowCount = 0;
			foreach ($arrHistory as $intHistoryId => $arrInner) {
				
				$strQueryAction = $arrInner['action'];
				$intLogfileId 	= $arrInner['id'];
			
				$objResult = $objDatabase->Execute('SELECT		navTable.id					AS navID,
																navTable.catid				AS navPageId,
																navTable.is_active			AS navActive,
																navTable.catname			AS navCatname,
																navTable.username			AS navUsername,
																navTable.changelog			AS navChangelog,
																navTable.startdate			AS navStartdate,
																navTable.enddate			AS navEnddate,
																navTable.cachingstatus		AS navCachingStatus,
																navTable.themes_id			AS navTheme,
																navTable.cmd				AS navCMD,
																navTable.module				AS navModule,
																navTable.frontend_access_id	AS navFAccess,
																navTable.backend_access_id	AS navBAccess,
																conTable.title				AS conTitle,
																conTable.metatitle			AS conMetaTitle,
																conTable.metadesc			AS conMetaDesc,
																conTable.metakeys			AS conMetaKeywords,
																conTable.content			AS conContent,
																conTable.css_name			AS conCssName,
																conTable.redirect			AS conRedirect,
																conTable.expertmode			AS conExpertMode
													FROM		'.DBPREFIX.'content_navigation_history AS navTable
													LEFT JOIN	'.DBPREFIX.'content_history AS conTable
													ON			navTable.id = conTable.id
													HAVING		navID='.$intHistoryId.'
													LIMIT		1
												');				
				$strBackendGroups 	= '';
				$strFrontendGroups 	= '';
				
				$objSubResult = $objDatabase->Execute('	SELECT	catid
														FROM	'.DBPREFIX.'content_navigation
														WHERE	catid='.$objResult->fields['navPageId'].'
														LIMIT	1
													');
				if ($objSubResult->RecordCount() == 1) {
					$boolPageExists = true;	
				} else {
					$boolPageExists = false;	
				}
				
				if ($objResult->fields['navBAccess'] != 0) {
					$objSubResult = $objDatabase->Execute('	SELECT	group_id
															FROM	'.DBPREFIX.'access_group_dynamic_ids
															WHERE	access_id='.$objResult->fields['navBAccess'].'
														');
					while (!$objSubResult->EOF) {
						$strBackendGroups .= $arrGroups[$objSubResult->fields['group_id']].',';
						$objSubResult->MoveNext();
					}
					$strBackendGroups = substr($strBackendGroups,0,strlen($strBackendGroups)-1);
				} else {
					$strBackendGroups = $arrGroups[0];					
				}
				
				if ($objResult->fields['navFAccess'] != 0) {
					$objSubResult = $objDatabase->Execute('	SELECT	group_id
															FROM	'.DBPREFIX.'access_group_dynamic_ids
															WHERE	access_id='.$objResult->fields['navFAccess'].'
														');
					while (!$objSubResult->EOF) {
						$strFrontendGroups .= $arrGroups[$objSubResult->fields['group_id']].',';
						$objSubResult->MoveNext();
					}
					$strFrontendGroups = substr($strFrontendGroups,0,strlen($strFrontendGroups)-1);
				} else {
					$strFrontendGroups = $arrGroups[0];					
				}	
				
				switch ($strAction) {
					case 'updated':
						if(!$boolPageExists) {
							$strIcon = '<img src="images/icons/empty.gif" alt="'.$_CORELANG['TXT_HISTORY_DELETED'].'" title="'.$_CORELANG['TXT_HISTORY_DELETED'].'" border="0" />';
						} else {
							$strIcon = '<a href="?cmd=content&amp;act=edit&amp;pageId='.$objResult->fields['navPageId'].'"><img src="images/icons/details.gif" alt="'.$_CORELANG['TXT_DETAILS'].'" title="'.$_CORELANG['TXT_DETAILS'].'" border="0" /></a>';
						}
					break;
					case 'deleted':
						$strIcon = '<a href="javascript:restoreDeleted(\''.$objResult->fields['navID'].'\');"><img src="images/icons/import.gif" alt="'.$_CORELANG['TXT_DELETED_RESTORE'].'" title="'.$_CORELANG['TXT_DELETED_RESTORE'].'" border="0" align="middle" /></a>';
					break;
					case 'unvalidated':
						$strIcon = '<a href="?cmd=workflow&amp;act=validate&amp;acc=1&amp;id='.$intLogfileId.'"><img src="images/icons/thumb_up.gif" alt="'.$_CORELANG['TXT_WORKFLOW_VALIDATE_ACCEPT'].'" title="'.$_CORELANG['TXT_WORKFLOW_VALIDATE_ACCEPT'].'" border="0" align="middle" /></a>&nbsp;';
						$strIcon .= '<a href="?cmd=workflow&amp;act=validate&amp;acc=0&amp;id='.$intLogfileId.'"><img src="images/icons/thumb_down.gif" alt="'.$_CORELANG['TXT_WORKFLOW_VALIDATE_DECLINE'].'" title="'.$_CORELANG['TXT_WORKFLOW_VALIDATE_DECLINE'].'" border="0" align="middle" /></a>&nbsp;';
						$strIcon .= '<a href="?cmd=content&amp;act=edit&amp;pageId='.$objResult->fields['navPageId'].'"><img src="images/icons/details.gif" alt="'.$_CORELANG['TXT_DETAILS'].'" title="'.$_CORELANG['TXT_DETAILS'].'" border="0" align="middle" /></a>';
						
						switch ($strQueryAction) {
							case 'new':
								$strPrefix = $_CORELANG['TXT_VALIDATE_PREFIX_NEW'].'&nbsp;';
							break;
							case 'delete':
								$strPrefix = $_CORELANG['TXT_VALIDATE_PREFIX_DELETE'].'&nbsp;';
							break;
							default: //update
								$strPrefix = $_CORELANG['TXT_VALIDATE_PREFIX_UPDATE'].'&nbsp;';
						}
						
					break;
					default:
						if(!$boolPageExists) {
							$strIcon = '<img src="images/icons/empty.gif" alt="'.$_CORELANG['TXT_HISTORY_DELETED'].'" title="'.$_CORELANG['TXT_HISTORY_DELETED'].'" border="0" />';
						} else {
							$strIcon = '<a href="?cmd=content&amp;act=edit&amp;pageId='.$objResult->fields['navPageId'].'"><img src="images/icons/details.gif" alt="'.$_CORELANG['TXT_DETAILS'].'" title="'.$_CORELANG['TXT_DETAILS'].'" border="0" /></a>';
						}
				}				
				
				$objTemplate->setVariable(array(
					'TXT_CONTENT_TITLE'			=>	$_CORELANG['TXT_PAGETITLE'],
					'TXT_META_TITLE'			=>	$_CORELANG['TXT_META_TITLE'],
					'TXT_META_DESCRIPTION'		=>	$_CORELANG['TXT_META_DESCRIPTION'],
					'TXT_META_KEYWORD'			=>	$_CORELANG['TXT_META_KEYWORD'],
					'TXT_CATEGORY'				=>	$_CORELANG['TXT_CATEGORY'],
					'TXT_START_DATE'			=>	$_CORELANG['TXT_START_DATE'],
					'TXT_END_DATE'				=>	$_CORELANG['TXT_END_DATE'],
					'TXT_THEMES'				=>	$_CORELANG['TXT_THEMES'],
					'TXT_OPTIONAL_CSS_NAME'		=>	$_CORELANG['TXT_OPTIONAL_CSS_NAME'],
					'TXT_MODULE'				=>	$_CORELANG['TXT_MODULE'],
					'TXT_REDIRECT'				=>	$_CORELANG['TXT_REDIRECT'],
					'TXT_SOURCE_MODE'			=>	$_CORELANG['TXT_SOURCE_MODE'],
					'TXT_CACHING_STATUS'		=>	$_CORELANG['TXT_CACHING_STATUS'],
					'TXT_FRONTEND'				=>	$_CORELANG['TXT_WEB_PAGES'],
					'TXT_BACKEND'				=>	$_CORELANG['TXT_ADMINISTRATION_PAGES'],
				));		
				
				$objTemplate->setVariable(array(
					'HISTORY_ROWCLASS'		=>	($intRowCount % 2 == 0) ? 'row0' : 'row1',
					'HISTORY_IMGDETAILS'	=>	$strIcon,
					'HISTORY_RID'			=>	$iRowId,
					'HISTORY_ID'			=>	$objResult->fields['navID'],
					'HISTORY_PID'			=>	$objResult->fields['navPageId'],
					'HISTORY_DATE'			=>	date('d.m.Y H:i:s',$objResult->fields['navChangelog']),
					'HISTORY_USER'			=>	$objResult->fields['navUsername'],
					'HISTORY_PREFIX'		=>	$strPrefix,
					'HISTORY_TITLE'			=>	stripslashes($objResult->fields['navCatname']),
					'HISTORY_CONTENT_TITLE'	=>	stripslashes($objResult->fields['conTitle']),
					'HISTORY_METATITLE'		=>	stripslashes($objResult->fields['conMetaTitle']),
					'HISTORY_METADESC'		=>	stripslashes($objResult->fields['conMetaDesc']),
					'HISTORY_METAKEY'		=>	stripslashes($objResult->fields['conMetaKeywords']),
					'HISTORY_STARTDATE'		=>	$objResult->fields['navStartdate'],
					'HISTORY_ENDDATE'		=>	$objResult->fields['navEnddate'],
					'HISTORY_THEME'			=>	stripslashes($arrThemes[$objResult->fields['navTheme']]),
					'HISTORY_OPTIONAL_CSS'	=>	(empty($objResult->fields['conCssName'])) ? '-' : stripslashes($objResult->fields['conCssName']),
					'HISTORY_MODULE'		=>	$arrModules[$objResult->fields['navModule']].' '.$objResult->fields['navCMD'],
					'HISTORY_CMD'			=>	(empty($objResult->fields['navCMD'])) ? '-' : $objResult->fields['navCMD'],
					'HISTORY_SECTION'		=>	$arrModules[$objResult->fields['navModule']],
					'HISTORY_REDIRECT'		=>	(empty($objResult->fields['conRedirect'])) ? '-' : $objResult->fields['conRedirect'],
					'HISTORY_SOURCEMODE'	=>	strtoupper($objResult->fields['conExpertMode']),
					'HISTORY_CACHING_STATUS'=>	($objResult->fields['navCachingStatus'] == 1) ? 'Y' : 'N',
					'HISTORY_FRONTEND'		=>	stripslashes($strFrontendGroups),
					'HISTORY_BACKEND'		=>	stripslashes($strBackendGroups),
					'HISTORY_CONTENT'		=>	stripslashes(htmlspecialchars($objResult->fields['conContent'])),
				));
				
				$objTemplate->parse('showPages');
				$intRowCount++;
				$iRowId++;
			}
		} else {
			$objTemplate->hideBlock('showPages');	
		}
    }
   
	/**
	* Load an page from history
	*
    * @global   object   	$objDatabase
    * @global 	array		$_CORELANG
    * @param    integer  	$intHistoryId: The entry with this id will be loaded
    * @param 	boolean		$boolInsert: This parameter has to set to true, if the page was deleted before
    * @return   integer   	$intPageId: The id of the page which was loaded
    */		
	function loadHistory($intHistoryId,$boolInsert=false) {
		global $objDatabase, $_CORELANG;
	
		$intHistoryId = intval($intHistoryId);
		
		if ($intHistoryId > 0) {			
			$objResult = $objDatabase->Execute('SELECT	catid
												FROM	'.DBPREFIX.'content_navigation_history
												WHERE	id='.$intHistoryId.'
												LIMIT	1
											');
			$objDatabase->Execute('	UPDATE	'.DBPREFIX.'content_navigation_history
									SET		is_active="0"
									WHERE	catid='.$objResult->fields['catid'].'
								');
			
			$objDatabase->Execute('	UPDATE	'.DBPREFIX.'content_navigation_history
									SET		is_active="1"
									WHERE	id='.$intHistoryId.'
									LIMIT	1
								');
						
			$objResult = $objDatabase->Execute('SELECT	*
												FROM	'.DBPREFIX.'content_navigation_history
												WHERE	id='.$intHistoryId.'
												LIMIT	1
											');
			
			$objContentTree = &new ContentTree();
			$arrCategory = $objContentTree->getThisNode($objResult->fields['parcat']);
			
			if (!is_array($arrCategory) && $boolInsert) {
					$objSubResult = $objDatabase->Execute('	SELECT	catid
															FROM	'.DBPREFIX.'content_navigation
															WHERE	module=1 AND
																	cmd="lost_and_found" AND
																	lang='.$objResult->fields['lang'].'
															LIMIT	1
														');
					$intParcat = intval($objSubResult->fields['catid']);	
				} else {
					$intParcat = ($objResult->fields['parcat']);
				}
			
			if ($boolInsert) {
				//remove entry from logfile first
				$objDatabase->Execute('	DELETE
										FROM	'.DBPREFIX.'content_logfile
										WHERE	action="delete" AND
												history_id='.$intHistoryId.'
										LIMIT	1
									');
				
				$objDatabase->Execute('	INSERT 
										INTO	'.DBPREFIX.'content_navigation
										SET		catid='.$objResult->fields['catid'].',
												parcat='.$intParcat.',
												catname="'.$objResult->fields['catname'].'",
												target="'.$objResult->fields['target'].'",
												displayorder='.$objResult->fields['displayorder'].',
												displaystatus="'.$objResult->fields['displaystatus'].'",
												cachingstatus="'.$objResult->fields['cachingstatus'].'",
												username="'.$objResult->fields['username'].'",
												changelog='.time().',
												cmd="'.$objResult->fields['cmd'].'",
												lang='.$objResult->fields['lang'].',
												module='.$objResult->fields['module'].',
												startdate="'.$objResult->fields['startdate'].'",
												enddate="'.$objResult->fields['enddate'].'",
												protected='.$objResult->fields['protected'].',
												frontend_access_id='.$objResult->fields['frontend_access_id'].',
												backend_access_id='.$objResult->fields['backend_access_id'].',
												themes_id='.$objResult->fields['themes_id'].'
									');
				
				$objResult = $objDatabase->Execute('SELECT	*
													FROM	'.DBPREFIX.'content_history
													WHERE	id='.$intHistoryId.'
													LIMIT	1
												');
				$objDatabase->Execute('	INSERT
										INTO	'.DBPREFIX.'content
										SET		id='.$objResult->fields['page_id'].',
												content="'.$objResult->fields['content'].'",
												title="'.$objResult->fields['title'].'",
												metatitle="'.$objResult->fields['metatitle'].'",
												metadesc="'.$objResult->fields['metadesc'].'",
												metakeys="'.$objResult->fields['metakeys'].'",
												metarobots="'.$objResult->fields['metarobots'].'",
												css_name="'.$objResult->fields['css_name'].'",
												redirect="'.$objResult->fields['redirect'].'",
												expertmode="'.$objResult->fields['expertmode'].'"
									');				
			} else {
				$objDatabase->Execute('	UPDATE	'.DBPREFIX.'content_navigation
										SET		parcat='.$intParcat.',
												catname="'.$objResult->fields['catname'].'",
												target="'.$objResult->fields['target'].'",
												displayorder='.$objResult->fields['displayorder'].',
												displaystatus="'.$objResult->fields['displaystatus'].'",
												cachingstatus="'.$objResult->fields['cachingstatus'].'",
												username="'.$objResult->fields['username'].'",
												changelog='.time().',
												cmd="'.$objResult->fields['cmd'].'",
												lang='.$objResult->fields['lang'].',
												module='.$objResult->fields['module'].',
												startdate="'.$objResult->fields['startdate'].'",
												enddate="'.$objResult->fields['enddate'].'",
												protected='.$objResult->fields['protected'].',
												frontend_access_id='.$objResult->fields['frontend_access_id'].',
												backend_access_id='.$objResult->fields['backend_access_id'].',
												themes_id='.$objResult->fields['themes_id'].'
										WHERE	catid='.$objResult->fields['catid'].'
										LIMIT	1
									');
				
				$objResult = $objDatabase->Execute('SELECT	*
													FROM	'.DBPREFIX.'content_history
													WHERE	id='.$intHistoryId.'
													LIMIT	1
												');
				$objDatabase->Execute('	UPDATE	'.DBPREFIX.'content
										SET		content="'.$objResult->fields['content'].'",
												title="'.$objResult->fields['title'].'",
												metatitle="'.$objResult->fields['metatitle'].'",
												metadesc="'.$objResult->fields['metadesc'].'",
												metakeys="'.$objResult->fields['metakeys'].'",
												metarobots="'.$objResult->fields['metarobots'].'",
												css_name="'.$objResult->fields['css_name'].'",
												redirect="'.$objResult->fields['redirect'].'",
												expertmode="'.$objResult->fields['expertmode'].'"
										WHERE	id='.$objResult->fields['page_id'].'
										LIMIT	1
									');				
			}
			$this->statusMessage = $_CORELANG['TXT_HISTORY_RESTORED'];
		}
		
		return intval($objResult->fields['page_id']);
	}  

	/**
	* Delete an history entry
	*
    * @global   object   	$objDatabase
    * @global 	array		$_CORELANG
    * @param    integer  	$intHistoryId: The entry with this id will be deleted
    * @return   integer   	$intPageId: The history-entry which was deleted belonged to this pageid
    */		
	function deleteHistory($intHistoryId) {
		global $objDatabase, $_CORELANG;
		
		$intHistoryId = intval($intHistoryId);
		
		if ($intHistoryId > 0) {
			$objResult = $objDatabase->Execute('SELECT	is_active,
														catid
												FROM	'.DBPREFIX.'content_navigation_history
												WHERE	id='.$intHistoryId.'
												LIMIT	1
											');
			if (intval($objResult->fields['is_active']) != 1) {
				$objDatabase->Execute('	DELETE
										FROM	'.DBPREFIX.'content_logfile
										WHERE	history_id='.$intHistoryId.' AND
												(action="update" OR 
												action="new")
										LIMIT	1
									');
				$objDatabase->Execute('	DELETE
										FROM	'.DBPREFIX.'content_navigation_history
										WHERE	id='.$intHistoryId.'
										LIMIT	1
									');
				$objDatabase->Execute('	DELETE
										FROM	'.DBPREFIX.'content_history
										WHERE	id='.$intHistoryId.'
										LIMIT	1
									');
				
				$this->statusMessage = $_CORELANG['TXT_HISTORY_DELETE_DONE'];
			} else {
				//this history-entry is currently active, don't allow to delete
				$this->statusMessage = $_CORELANG['TXT_HISTORY_DELETE_ACTIVE'];
			}
		}
		
		return intval($objResult->fields['catid']);
	}
	
	
	/**
	* Redirect to content manager (open site)
	*
    * @param    integer  	The page with this id will be shown in content manager
    */	
	function redirectPage($intPageId) {
		header('location:index.php?cmd=content&act=edit&pageId='.intval($intPageId));
		exit;
	}
	
	/**
	* Validate an incoming page
	*
    * @global   object   	$objDatabase
    * @global 	array		$_CORELANG
    * @param    integer  	$intHistoryId: The entry with this id will be validated
    * @return   integer   	$intValidateStatus: 1 -> accept page, 0 -> decline page
    */		
	function validatePage($intLogfileId,$intValidateStatus) {
		global $objDatabase, $_CORELANG;
		
		$intLogfileId = intval($intLogfileId);
		$intValidateStatus = intval($intValidateStatus);
				
		if ($intLogfileId != 0) {
			$objResult = $objDatabase->Execute('SELECT	action,
														history_id
												FROM	'.DBPREFIX.'content_logfile
												WHERE	id='.$intLogfileId.' AND
														is_validated="0"
												LIMIT	1
											');
			
			$intHistoryId = $objResult->fields['history_id'];
			$strAction = $objResult->fields['action'];
		
			$objResult = $objDatabase->Execute('SELECT	page_id
												FROM	'.DBPREFIX.'content_history	
												WHERE	id = '.$intHistoryId.'
												LIMIT	1
											');
			$row = $objResult->FetchRow();
			$intPageId = $row['page_id'];			
			
			switch ($strAction) {
				case 'new':						
					if ($intValidateStatus == 1) {
						$objDatabase->Execute('	UPDATE	'.DBPREFIX.'content_logfile
												SET		is_validated="1"
												WHERE	id='.$intLogfileId.'
												LIMIT	1
											');
						$objDatabase->Execute('	UPDATE	'.DBPREFIX.'content_navigation_history
												SET		changelog='.time().'
												WHERE	id='.$intHistoryId.' AND
														catid='.$intPageId.'
												LIMIT	1
											');
						$objDatabase->Execute('	UPDATE	'.DBPREFIX.'content_navigation
												SET		is_validated="1",
														activestatus="1",
														changelog='.time().'
												WHERE	catid='.$intPageId.'
												LIMIT	1
											');
						$this->strStatusMessage = $_CORELANG['TXT_WORKFLOW_VALIDATE_NEW_ACCEPT'];
					} else {				
						$objDatabase->Execute('	DELETE
												FROM	'.DBPREFIX.'content_logfile
												WHERE	id='.$intLogfileId.'
												LIMIT	1
											');
						$objDatabase->Execute('	DELETE
												FROM	'.DBPREFIX.'content_navigation_history
												WHERE	id='.$intHistoryId.'
												LIMIT	1
											');
						$objDatabase->Execute('	DELETE
												FROM	'.DBPREFIX.'content_history
												WHERE	id='.$intHistoryId.'
												LIMIT	1
											');
						$objDatabase->Execute('	DELETE
												FROM	'.DBPREFIX.'content
												WHERE	id='.$intPageId.'
												LIMIT	1
											');
						$objDatabase->Execute('	DELETE
												FROM	'.DBPREFIX.'content_navigation
												WHERE	catid='.$intPageId.'
												LIMIT	1
											');
						$this->strStatusMessage = $_CORELANG['TXT_WORKFLOW_VALIDATE_NEW_DECLINE'];
					}			
				break;
				case 'delete':
					if ($intValidateStatus == 1) {
						//really delete page
						$objDatabase->Execute('	UPDATE	'.DBPREFIX.'content_logfile
												SET		is_validated="1"
												WHERE	id='.$intLogfileId.'
												LIMIT	1
											');
						$objDatabase->Execute('	DELETE 
												FROM 	'.DBPREFIX.'content 
												WHERE 	id='.$intPageId.'
												LIMIT	1
											');
						$objDatabase->Execute('	DELETE 
												FROM 	'.DBPREFIX.'content_navigation 
												WHERE 	catid='.$intPageId.'
												LIMIT	1
											');						
						$this->strStatusMessage = $_CORELANG['TXT_DATA_RECORD_DELETED_SUCCESSFUL'];
					} else {
						//decline delete
						$objDatabase->Execute('	DELETE
												FROM	'.DBPREFIX.'content_logfile
												WHERE	id='.$intLogfileId.'
												LIMIT	1
											');
						$this->strStatusMessage = $_CORELANG['TXT_WORKFLOW_VALIDATE_DELETE_DECLINE'];					
					}
				break;
				default: //update
					if ($intValidateStatus == 1) {
						//allow update
						$this->loadHistory($intHistoryId,false);
						$objDatabase->Execute('	UPDATE	'.DBPREFIX.'content_logfile
												SET		is_validated="1"
												WHERE	id='.$intLogfileId.'
												LIMIT	1
											');
						$this->strStatusMessage = $_CORELANG['TXT_WORKFLOW_VALIDATE_UPDATE_ACCEPT'];
					} else {
						//decline update
						$objDatabase->Execute('	DELETE
												FROM	'.DBPREFIX.'content_logfile
												WHERE	id='.$intLogfileId.'
												LIMIT	1
											');
						$objDatabase->Execute('	DELETE
												FROM	'.DBPREFIX.'content_navigation_history
												WHERE	id='.$intHistoryId.'
												LIMIT	1
											');
						$objDatabase->Execute('	DELETE
												FROM	'.DBPREFIX.'content_history
												WHERE	id='.$intHistoryId.'
												LIMIT	1
											');
						$this->strStatusMessage = $_CORELANG['TXT_WORKFLOW_VALIDATE_UPDATE_DECLINE'];
					}
			}
		}
	}
}