<?php
/**
* Class Initialize
*
* init CMS
*
* @copyright	CONTREXX CMS - Astalavista IT Engineering GmbH Thun
* @author		Astalavista Development Team <thun@astalvista.ch>
* @access		public
* @module		database
* @modulegroup	core
* @version		1.0.0                                            
*/

class InitCMS
{
	var $defaultBackendLangId;
	var $backendLangCharset;	
	var $backendLangId;
		
	var $defaultFrontendLangId; 
	var $frontendLangCharset;
	var $frontendLangId;
	var $frontendLangName;			
	var $userFrontendLangId;
			
	var $currentThemesId;	
	var $is_home;
	var $arrLang =array();
	var $templates = array();
	var $arrModulePath = array();
	
	
    /**
    * string $mode
    * frontend or backend
    */		
	var $mode; 

  
    /**
    * Constructor
    *
    */	    
	function InitCMS($mode="frontend")
	{
		global $objDatabase;
		
		$this->is_home=false;
		$this->mode=$mode;
		
		$objResult = $objDatabase->Execute("SELECT id,
									themesid,
									print_themes_id,
									lang,
		                            name,
									charset,
		                            backend,
		                            frontend,
									is_default 
		                       FROM ".DBPREFIX."languages");		
		
		if ($objResult !== false) {
			while (!$objResult->EOF) {
				$this->arrLang[$objResult->fields['id']]= array(
				    'id'         => $objResult->fields['id'],
				    'themesid'   => $objResult->fields['themesid'],
				    'print_themes_id' => $objResult->fields['print_themes_id'],				    
				    'lang'       => $objResult->fields['lang'],
				    'name'       => $objResult->fields['name'],
				    'charset'    => $objResult->fields['charset'],
				    'backend'    => $objResult->fields['backend'],
				    'frontend'   => $objResult->fields['frontend'],
				    'is_default' => $objResult->fields['is_default']);
				    
				if ($objResult->fields['is_default']=="true") {
					$this->defaultBackendLangId = $objResult->fields['id'];
					$this->defaultFrontendLangId = $objResult->fields['id'];
				}
				$objResult->MoveNext();
			}
		}
		if ($mode == "frontend") {
			$this->_initBackendLanguage();
			$this->getUserFrontendLangId();
		}
		$this->_initFrontendLanguage();
		$this->loadModulePaths();
	}

	

	
	function _initBackendLanguage()
	{
		// Backend language initialization
		$userId=0;
		
		if(isset($_SESSION['auth']['userid'])){
		     $userId=intval($_SESSION['auth']['userid']);
		}
						
		if(isset($_SESSION['auth']['lang']) && !empty($_SESSION['auth']['lang'])) {
            $backendLangId=intval($_SESSION['auth']['lang']); 
		} elseif(isset($_COOKIE['backendLangId']) && !empty($_COOKIE['backendLangId'])) {
		    $backendLangId=intval($_COOKIE['backendLangId']);			
		} else {
            $backendLangId=$this->defaultBackendLangId;             
		}	
		
		if($this->arrLang[$backendLangId]['backend']!=1) {
			$backendLangId=$this->defaultBackendLangId;
		}
		
		$this->backendLangId= $this->arrLang[$backendLangId]['id'];
		$this->currentThemesId= $this->arrLang[$backendLangId]['themesid'];
		$this->backendLangCharset = $this->arrLang[$backendLangId]['charset'];
		setcookie ("backendLangId", $backendLangId, time()+3600*24*30);							
	}	


	
	function _initFrontendLanguage()
	{		
		// Frontend language initialization	
		if(isset($_GET['langId']) AND !empty($_GET['langId'])){
		    $frontendLangId=intval($_GET['langId']);
	    } elseif(isset($_COOKIE['langId']) AND !empty($_COOKIE['langId'])){
		    $frontendLangId = intval($_COOKIE['langId']);			
	    } else {
	        $frontendLangId = $this->defaultFrontendLangId;	
	    }
		if($this->arrLang[$frontendLangId]['frontend']!=1){
			$frontendLangId = $this->defaultFrontendLangId;
		}
			    
		$this->frontendLangId= $frontendLangId;
		if(isset($_GET['printview']) && $_GET['printview']==1) {
		    $this->currentThemesId= $this->arrLang[$frontendLangId]['print_themes_id'];
		} else {
		    $this->currentThemesId= $this->arrLang[$frontendLangId]['themesid'];	
		}
		
		$this->frontendLangCharset = $this->arrLang[$frontendLangId]['charset'];
		setcookie ("langId", $frontendLangId, time()+3600*24*30);						
	}	

	
	

	
	/**
	* Gets the selected User Frontend Language id
	*
	* This method is only for the backend use!
	*            
	* @return   string $this->userFrontendLangId                                           
	*/	
    function getUserFrontendLangId()
	{	    			
		// print_r($_COOKIE);
		if(isset($_POST['userFrontendLangId']) AND !empty($_POST['userFrontendLangId'])){
		    $id=intval($_POST['userFrontendLangId']);
	    } elseif(isset($_SESSION['userFrontendLangId']) AND !empty($_SESSION['userFrontendLangId'])){
		    $id = intval($_SESSION['userFrontendLangId']);			
	    } else {
	        $id = $this->defaultFrontendLangId;	
	    }
	    
		if($this->arrLang[$id]['frontend']!=1){
			$id=$this->defaultFrontendLangId;
		}
			    
		$this->userFrontendLangId= $id;
	    $_SESSION['userFrontendLangId'] = $id;	    
		return $this->userFrontendLangId; 	  	  	 		
	}	

	
    function getDefaultFrontendLangId()
	{
		  return $this->defaultFrontendLangId; 	  	  	 		
	}
	
	

    function getDefaultBackendLangId()
	{
		  return $this->defaultFrontendLangId; 	  	  	 		
	}
		
	
	
    function getFrontendLangId()
	{
		  return $this->frontendLangId;  	  	 		
	}
	
	
    function getFrontendLangName()
	{
        return $this->arrLang[$this->frontendLangId]['lang'];	   		
	}	
	

	
    function getBackendLangId()
	{
		  return $this->backendLangId; 	  	  	 		
	}	

	
	
	
    /**
    * gets all languages as an array
    *
    * @access public
    * @return array $arrLang
    */
     
    function getLanguageArray()
	{
		return $this->arrLang; 	  	 		
	}	
	
	

	
    /**
    * gets the current language charset for the html header
    *
    * @param string   charset
    * @access public
    */
     
    function getFrontendLangCharset()
	{
		if (empty($this->frontendLangCharset)){
            return "iso-8859-1";
		}else{
		    return $this->frontendLangCharset; 
		}  	  	 		
	}

	
    /**
    * gets the current language charset for the html header
    *
    * @param string   charset
    * @access public
    */
     
    function getBackendLangCharset()
	{
		if (empty($this->backendLangCharset)){
            return "iso-8859-1";
		}else{
		    return $this->backendLangCharset; 
		}  	  	 		
	}	
	
		
	
    /**
    * getDefaultLangId
    *
    * @param string   current language id
    * @access public
    */	 
    function getFrontendDefaultLangId()
	{
		  return $this->defaultFrontendLangId; 	  	  	 		
	}

	
    /**
    * getDefaultLangId
    *
    * @param string   current language id
    * @access public
    */	 
    function getBackendDefaultLangId()
	{
		  return $this->defaultBackendLangId; 	  	  	 		
	}		
	
	
    /**
    * getTemplate Function
    *
    * @param  array    Template strings
    * @access public
    */		
	function getTemplates()
	{
		global $objDatabase;
		
		$objResult = $objDatabase->SelectLimit("SELECT id,
									themesname,
		                            foldername 
		                       FROM ".DBPREFIX."skins 
		                      WHERE id = '$this->currentThemesId'",1);
		if ($objResult !== false) {
			while (!$objResult->EOF) {
				$themesPath = $objResult->fields['foldername'];
				$objResult->MoveNext();
			}
		}
								
	  	$this->templates['index'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/index.html'));
		$this->templates['content'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/content.html'));
		$this->templates['home'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/home.html'));
		$this->templates['navbar'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/navbar.html'));
		$this->templates['subnavbar'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/subnavbar.html'));
		$this->templates['sidebar'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/sidebar.html'));
		$this->templates['shopnavbar'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/shopnavbar.html'));			
		$this->templates['headlines'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/headlines.html'));
		$this->templates['javascript'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/javascript.js'));			
		//$this->templates['style'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/style.css'));
		$this->templates['buildin_style'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/buildin_style.css'));
		@$this->templates['calendar_headlines'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/events.html'));
		
	  	return $this->templates; 	  	  	 		
	}


	
	/**
	*  initialise the configuration array
	*
	* @return    array   $arrSettings
	*/
	function loadConfiguration()
	{
	    global $_SYSCONFIG, $objDatabase;
	    
	    $arrSettings = $_SYSCONFIG;    
	    
	    $objResult = $objDatabase->Execute("SELECT setname, setvalue FROM ".DBPREFIX."settings");
	    if ($objResult !== false) {
	        while (!$objResult->EOF) {
	            $setname=$objResult->fields['setname'];
				$setvalue=$objResult->fields['setvalue'];
				$arrSettings[$setname]=$setvalue;
				$objResult->MoveNext();
			}
		}
		else{
	        die("init::loadConfiguration() error");
		}
	    return $arrSettings;
	}	
	

	
	function loadModulePaths()
	{
		global $objDatabase;
		
		// generate "module paths" array
		$query = "SELECT name, is_core FROM ".DBPREFIX."modules";
		$objResult = $objDatabase->Execute($query);
		if ($objResult !== false) {
			while (!$objResult->EOF) {
				if(strlen($objResult->fields['name'])>0){
					switch($objResult->fields['name']){
						case 'core':
							$this->arrModulePath[$objResult->fields['name']] = ASCMS_DOCUMENT_ROOT.'/lang/';
							break;
						case 'home':
							// home is not a real modul
							break;
						default:
						$this->arrModulePath[$objResult->fields['name']] = ($objResult->fields['is_core'] == 1 ? ASCMS_CORE_MODULE_PATH : ASCMS_MODULE_PATH).'/'.$objResult->fields['name'].'/lang/';
					}
				}
				$objResult->MoveNext();
			}
			// add special modules
			$this->arrModulePath['media'] = ASCMS_CORE_MODULE_PATH.'/media/lang/';;
		}
	}

	
	
	/**
	*  initialise the setting array
	*
	* @return    array   $arrayLanguageSettings                                                                             
	*/
	function loadLanguageData($module = '')
	{
		global $objInit, $_CORELANG;

		$_ARRAYLANG = array();
		
		if($objInit->mode == "backend"){
			$langId = $this->backendLangId;
		} else {
			$langId = $this->frontendLangId;
		}	
		
    	// check which module will be loaded
    	if(empty($module)){
	    	if($objInit->mode == "backend"){
	    		$module = isset($_REQUEST['cmd']) ? addslashes(strip_tags($_REQUEST['cmd'])) : 'core';
	    	} else {
	    		$module = isset($_REQUEST['section']) ? addslashes(strip_tags($_REQUEST['section'])) : 'core';
	    	}
    	}
    	
    	if (ereg("media.?", $module)) {
    		$module = "media";
    	}
    	
    	// change module for core components
		if(!array_key_exists($module,$objInit->arrModulePath) && $module != "media"){
			$module = '';
		} else {
	    	// check if the language file exist
	    	$path = $objInit->arrModulePath[$module].$objInit->arrLang[$langId]['lang'].'/'.$objInit->mode.'.php';
	   		if(!file_exists($path)){
	    		$langId = $objInit->mode == "backend" ? $objInit->getBackendDefaultLangId() : $objInit->getFrontendDefaultLangId();
				$path = $objInit->arrModulePath[$module].$objInit->arrLang[$langId]['lang'].'/'.$objInit->mode.'.php';
				if(!file_exists($path)){
	    			$path = '';
				}
			}
		}

		// load variables
		if(empty($module)){
			return $_CORELANG;
		} else {
			if(!empty($path)){
				//require_once($path);
				require($path);
				
				// remove escape characters
				foreach ($_ARRAYLANG as $langTxtId => $langTxt) {
					$_ARRAYLANG[$langTxtId] = ereg_replace("\\\"", "\"", $_ARRAYLANG[$langTxtId]);
				}
				
				return $_ARRAYLANG;
			} else {
				//die("init::loadLanguageData() error (".$objInit->arrModulePath[$module].$objInit->arrLang[$_LANGID]['lang'].'/'.$objInit->mode.'.php'.")");
				return $_CORELANG;
			}
		}
	}
	
	
	/**
	* Gets the page id
	*
	* gets the current pageId
	*
	* @global	 object	    $objDatabase      
	* @param     integer	$catID
	* @param     string		$command
	* @return    integer    $catID                                                                              
	*/
	function getPageID($catID="", $section="", $command="")
	{
		global $objDatabase;
		
		$langId = $this->getFrontendLangId();
		
		switch ($section) {
			case 'home':
				$this->is_home = true;
				break;
				
			case 'logout':
				$section = 'login';
				break;
			
			default:
		}
		
		if (empty($catID) OR $catID=="0"){
			if (empty($section) AND empty($command)){
				$query="SELECT n.catid AS catid, 
				               n.module AS module,
				               n.themes_id AS themes_id 
				          FROM ".DBPREFIX."content_navigation AS n, 
				               ".DBPREFIX."modules AS m 
				         WHERE 1 
				           AND m.name = 'home' 
				           AND n.module=m.id 
				           AND lang='".$langId."'";
				$objResult = $objDatabase->SelectLimit($query, 1);
				if ($objResult !== false) {
					$catID=$objResult->fields['catid'];
					$this->_setCustomizedThemesId($objResult->fields['themes_id']);
					$this->is_home=true;
				}else{
					die("init::getPageId() error");
				}
			}
			// section without command is given!
			elseif (!empty($section) AND empty($command)){
				$query="SELECT catid,
							   themes_id 
				         FROM ".DBPREFIX."content_navigation, 
				              ".DBPREFIX."modules 
				        WHERE name = '".$section."' 
				          AND cmd = ''
				          AND module=id 
				          AND lang='".$langId."'
				        ORDER BY parcat ASC";
				
				//$query="SELECT catid FROM ".DBPREFIX."content_navigation WHERE section = '$section' LIMIT 1"
				$objResult = $objDatabase->SelectLimit($query, 1);
				if ($objResult !== false) {
				    if (!$objResult->EOF) {
				        $catID = $objResult->fields['catid'];
				        $this->_setCustomizedThemesId($objResult->fields['themes_id']);
				    }
				}else{
					die("init::getPageId() error");
				}
			}
			else
			{
				$query="SELECT catid,
			                   themes_id 
				          FROM ".DBPREFIX."content_navigation, 
				               ".DBPREFIX."modules 
				        WHERE name = '".$section."' 
				          AND cmd = '".$command."'
				          AND lang='".$langId."' 
				          AND module=id";
				
				$objResult = $objDatabase->SelectLimit($query,1);
				if ($objResult !== false) {
				    if (!$objResult->EOF) {
				    	$catID = $objResult->fields['catid'];
				    	$this->_setCustomizedThemesId($objResult->fields['themes_id']);
				    }
				}
				if(empty($catID)){
					die("init::getPageID() error");
				}			
			}
			return $catID;
		} else{
			$query="SELECT themes_id 
			          FROM ".DBPREFIX."content_navigation 
			         WHERE catid = '".$catID."'";

			$objResult = $objDatabase->SelectLimit($query, 1);
			if ($objResult !== false) {
			    if (!$objResult->EOF) {
			    	$this->_setCustomizedThemesId($objResult->fields['themes_id']);
			    }
			}			
			return $catID;
		}
	}

	
	
	/**
	* Sets the customized ThemesId
	*
	* This method set the currentThemesId if a customized themesId is set
	* in the navigation table. 
	*    
	* @access private  	 
	* @param optional string $themesId
	* @access public                                                                             
	*/	
    function _setCustomizedThemesId($themesId="")
    {
    	global $objDatabase;
    	
		if(!isset($_GET['printview'])) {
	        $themesId=intval($themesId);       
	        if($themesId>0){
	        	$objResult = $objDatabase->Execute("SELECT id FROM ".DBPREFIX."skins");
	        	if ($objResult !== false) {
					while(!$objResult->EOF) {
				    	if ($objResult->fields['id']==$themesId) {
				    	    $this->currentThemesId=intval($themesId);	
				    	}
				    	$objResult->MoveNext();
				    }      	       	        		
	        	}
	        } 
		}      	
    }
    
    
    
    
    function getUserFrontendLangMenu()
    { 
		$i = 0;
		if (isset($_SERVER['QUERY_STRING'])) {
			parse_str($_SERVER['QUERY_STRING'], $vars);
		}
		$query = isset($vars['cmd']) ? "?cmd=".$vars['cmd'] : "";
		
		$return = "\n<form action='index.php".$query."' method='post' name='userFrontendLangIdForm'>\n";      	   
		$return .= "<select name='userFrontendLangId' size='1' onchange=\"document.forms['userFrontendLangIdForm'].submit()\">\n";		
		
		foreach($this->arrLang as $id=>$value){
			if($this->arrLang[$id]['frontend']==1) {
				$i++;
				if($id==$this->userFrontendLangId) {
				    $return .= "<option value='".$id."' selected='selected'>Frontend [".$value['name']."]</option>\n";
				} else {
				    $return .= "<option value='".$id."'>Frontend [".$value['name']."]</option>\n";	
				}
		    }
		}
		$return .= "</select>\n</form>\n";
		return ($i>1) ? $return : ""; 	   	
    }
    
    

	function getPrintUri() {
		if (!isset($_SERVER['REQUEST_URI'])) {
		        $arr = explode("/", $_SERVER['PHP_SELF']);
		        $_SERVER['REQUEST_URI'] = "/" . $arr[count($arr)-1];
		        if (isset($_SERVER['argv'][0]) && $_SERVER['argv'][0]!="") {
		                $_SERVER['REQUEST_URI'] .= "?" . $_SERVER['argv'][0];
		        }
		}	
		$retval = (count($_GET) == 0) ? $_SERVER['REQUEST_URI']."?printview=1" : $_SERVER['REQUEST_URI']."&printview=1";	
		return htmlspecialchars($retval);
	} 
	
	

	function getPageUri() {	
		return $_SERVER['SCRIPT_URI'];	
	}
}
?>