<?php
/**
* Class Navigation 
*
* This class creates the navigation tree
*
* @copyright	CONTREXX CMS - Astalavista IT Engineering GmbH Thun
* @author		Astalavista Development Team <thun@astalvista.ch>
* @access		public
* @module		navigation
* @modulegroup	core
* @version		1.0.0
*/ 

class Navigation
{
    var $langId; 
    var $data = array();
    var $table = array(); 
    var $tree = array();
    var $parents = array();   
    var $pageId;
    var $styleNameActive = "active";
    var $styleNameNormal = "inactive";
    var $separator = " > ";
    var $spacer = "&nbsp;";
    var $levelInfo = "down";
    var $subNavSign = " >>";
    var $subNavTag = '<ul id="menubuilder" class="menu">{SUB_MENU}</ul>';
    var $_objTpl;
    var $topLevelPageId;
    
    
    /**
    * Constructor
    *
    * @global    string   $_LANGID
    * @param     integer  $pageId
    */
	function Navigation($pageId)
	{
	    global $_LANGID;	
	    
	    $this->langId = $_LANGID;
	    $this->pageId = $pageId;		   	
        $this->_initialize();
        $this->_getParents();		  
		// $parcat is the starting parent id
		// optional $maxLevel is the maximum level, set to 0 to show all levels
		$this->_buildTree();                	
	}
	

	
    /**
    * Initialize the data hash from the database
    *
    * @global  object $objDatabase
    * @access private
    */	
    function _initialize()
    {
    	global $objDatabase;
    	
		$objResult = $objDatabase->Execute("SELECT n.cmd AS cmd,
			                   n.catid AS catid,
			                   n.catname AS catname,
			                   n.target AS target, 
			                   n.parcat AS parcat,
			                   n.displayorder AS displayorder,
			                   m.name AS section,
			                   n.displaystatus AS displaystatus
			              FROM ".DBPREFIX."content_navigation AS n,
			                   ".DBPREFIX."modules AS m 
			             WHERE n.module=m.id 
			               AND (n.displaystatus = 'on' OR n.catid='".$this->pageId."')
			               AND n.lang='".$this->langId."'
			               AND (n.startdate<=CURDATE() OR n.startdate='0000-00-00')
           				   AND (n.enddate>=CURDATE() OR n.enddate='0000-00-00') 
           				   AND n.activestatus='1' 
           				   AND n.is_validated='1'
			          ORDER BY n.parcat DESC, n.displayorder ASC");
		
		if ($objDatabase->Affected_Rows() > 0) {
			while (!$objResult->EOF) {
				// generate array $this->table
				if (!isset($this->table[$objResult->fields['parcat']])) {
					$this->table[$objResult->fields['parcat']] = array();
				}
				$this->table[$objResult->fields['parcat']][$objResult->fields['catid']] =stripslashes($objResult->fields['catname']);
				
				// generate array $this->parentId
				$this->parentId[$objResult->fields['catid']] = $objResult->fields['parcat'];
				
				// generate array $this->arrPages
				if (!isset($this->arrPages[$objResult->fields['parcat']])) {
					$this->arrPages[$objResult->fields['parcat']] = array();
				}
				array_push($this->arrPages[$objResult->fields['parcat']], $objResult->fields['catid']);
				
				if ($objResult->fields['catid'] == $this->pageId && !isset($this->topLevelPageId)) {
					$this->topLevelPageId = ($objResult->fields['parcat'] == 0 ? $objResult->fields['catid'] :$objResult->fields['parcat']);
				}
				
				// generate array $this->data
				$s=$objResult->fields['section'];
				$c=$objResult->fields['cmd'];
				$section = ($s=="") ? "" : "&amp;section=$s"; 
				$cmd = ($c=="") ? "" : "&amp;cmd=$c"; 
				$link = (!empty($s)) ? "?section=".$s.$cmd : "?page=".$objResult->fields['catid'].$section.$cmd;
				
				$this->data[$objResult->fields['catid']]= array(
				    'catid'    => $objResult->fields['catid'],
				    'url'      => $_SERVER['PHP_SELF'].$link,			
				    'catname'  => stripslashes($objResult->fields['catname']),
				    'target'   => $objResult->fields['target'],
				    'status' => $objResult->fields['displaystatus'] 
			    );
			    $objResult->MoveNext();
			}
			ksort($this->table);
			
			// generate page tree
			if (count($this->arrPages)>1) {
				while (count($this->arrPages) > 1) {
					$countBefore = count($this->arrPages);
					foreach ($this->arrPages as $pageId => $arrSubPages) {
						if ($pageId != 0) {
							$mount = true;
							foreach ($arrSubPages as $subPageId) {
								if (!is_array($subPageId) && isset($this->arrPages[$subPageId])) {
									$mount = false;
									break;
								}
							}
							
							if ($mount) {
								$position = false;
								foreach ($this->arrPages as $mainPageId => $arrSubPages2) {
									foreach ($arrSubPages2 as $key => $subPageId2) {
										if ($pageId == $subPageId2) {
											$keyId = $key;
											$position = $mainPageId;
											break 2;
										}
									}
								}
								
								if ($position !== false) {
									if ($position != 0 && $this->topLevelPageId == $pageId) {
										$this->topLevelPageId = $position;
									}
									$this->arrPages[$position][$keyId] = array($pageId => $this->arrPages[$pageId]);
								}
								unset($this->arrPages[$pageId]);
							}
						}
					}
					if ($countBefore == count($this->arrPages)) {
						break;
					}
				}
			}
		}
    }
    
    /**
    * builds the navigation tree sorted by parents
    *
    * @access private
    * @param int $parentId (Optional)
    * @param int $maxlevel (Optional) 
    * @param int $level (Optional)              
    */	
	function _buildTree($parentId=0,$maxlevel=0,$level=0)
	{
		if (!empty($this->table[$parentId])) {
			foreach($this->table[$parentId] AS $id => $data ){
		    	$this->tree[$id]=$level+1;	 	            	
				if ((isset($this->table[$id])) AND (($maxlevel>=$level+1) OR ($maxlevel==0))){
				  $this->_buildTree($id,$maxlevel,$level+1);
				}
		    }
		}
	}
	

	
    /**
    * Gets the parsed navigation
    *
    * @access private
    * @param string  $templateContent    
    * @return mixed parsed navigation      
    */	
	function getNavigation($templateContent)
	{		
		$this->_objTpl = &new HTML_Template_Sigma('.');
		$this->_objTpl->setErrorHandling(PEAR_ERROR_DIE);			
		$this->_objTpl->setTemplate($templateContent);
		
		// not set
		$topLevelBlockName = NULL;
		$blockName = NULL;
		$htmlOutput = NULL;	
		$navigationId[] = 0; // CSS styling ID's
		
		/*
		$counter = count($this->tree);
		for ($i=0,$j=1;$j<$counter;$i++,$j++)
		*/
		
		if (isset($this->_objTpl->_blocks['navigation_dropdown'])) {
			// set submenu tag
			if ($this->_objTpl->blockExists('sub_menu')) {
				$this->subNavTag = trim($this->_objTpl->_blocks['sub_menu']);
				$templateContent = ereg_replace('<!-- BEGIN sub_menu -->.*<!-- END sub_menu -->', NULL, $templateContent);
			}
			
			$navigation = $this->_buildDropDownNavigation($this->arrPages[0],1, true);			
			return  ereg_replace('<!-- BEGIN level_. -->.*<!-- END level_. -->', $navigation, $templateContent);
		} elseif (isset($this->_objTpl->_blocks['navigation'])) {
			$array_ids = array_keys( $this->tree );	
			// foreach($this->tree as $id => $level)
			foreach( $array_ids as $key => $id ) { 			
				$level =$this->tree[$id];
				if (!isset($navigationId[$level])) {
					$navigationId[$level] = 0;
				}
				$navigationId[$level]++;
				if (isset($array_ids[$key+1])) {
					$nextlevel = ( isset( $this->tree[$array_ids[$key+1]] ) ) ? $this->tree[$array_ids[$key+1]] : 0;
				} else {
					$nextlevel = 0;
				}
				
				$hideLevel=false;
				// checks if the page is in the current tree
				if(in_array($this->parentId[$id], $this->parents)){						
					// checks for customized blocks. e.g. "level_1"
					if($this->_objTpl->blockExists('level_'.$level)){ 				
						// gets the top level block name from the template
						if(!isset($topLevelBlockName)){
	                        $topLevelBlockName='level_'.$level;
						}
						$blockName = 'level_'.$level;			    
					}
					// no customized blocks for this level
					else {
						// we already had cutomized blocks 
						if(isset($topLevelBlockName)){
							// checks for the standard block e.g. "level"
							if($this->_objTpl->blockExists('level')){ 				
								$blockName = 'level';			    
							}else {
								$hideLevel=true; 	
							}										
						}
					}
	
					if(isset($topLevelBlockName)){				
						if(!$hideLevel){
													
							// checks if we are in the active tree
							$activeTree = (in_array($id, $this->parents)) ? true : false;
							if ($this->data[$id]['status'] == 'on') {
								// gets the style sheets value for active or inactive						
								$style = ($activeTree) ? $this->styleNameActive : $this->styleNameNormal;
								// get information about the next level id -> down or empty					
								// $levelInfo = (($level > $nextlevel) OR $activeTree AND $id <> $this->pageId) ? $this->levelInfo : "";
								
								$levelInfo = ($level > $nextlevel) ? $this->levelInfo : "";	
								$target = empty($this->data[$id]['target']) ? "_self" : $this->data[$id]['target'];			
										
								$this->_objTpl->setCurrentBlock($blockName);									
							    $this->_objTpl->setVariable('URL',$this->data[$id]['url']);
							    $this->_objTpl->setVariable('NAME',$this->data[$id]['catname']);
							    $this->_objTpl->setVariable('TARGET',$target);
							    $this->_objTpl->setVariable('LEVEL_INFO',$levelInfo);
							    $this->_objTpl->setVariable('NAVIGATION_ID',$navigationId[$level]);
							    $this->_objTpl->setVariable('STYLE',$style);			    
							    $this->_objTpl->parse($blockName);
							    $htmlOutput.=$this->_objTpl->get($blockName, true);
							}
						}										
					}			
				}
			}
			unset($navigationId);
			
			if(isset($topLevelBlockName)){
				// replaces the top level block with the complete parsed navigation
				// this is because the Sigma Template system don't support nested blocks 
				// with difference object based orders
				$this->_objTpl->replaceBlock($topLevelBlockName, $htmlOutput, true);		
				$this->_objTpl->touchBlock($topLevelBlockName);
				if($this->_objTpl->blockExists('navigation')){ 		
				    $this->_objTpl->parse('navigation');
				}
			}
			return $this->_objTpl->get();
		}
	}

	/**
	* Build drop down navigation menu
	*
	* Build a drop down navigation menu
	*
	* @access private
	* @param mixed $arrPage
	* @param integer $level
	* @param boolean $mainPage
	* @return string $navigation
	*/
	function _buildDropDownNavigation($arrPage, $level, $mainPage = false) {
		$navigation = "";
		$tmpNavigation = "";
		
		foreach ($arrPage as $page) {
			$navigationId[$level]++;
			
			// page has childs
			if (is_array($page)) {
				// get page id
				$keys = array_keys($page);
				$id = $keys[0];
				// get sub navigation
				
				$subNavigation = str_replace("{SUB_MENU}", $this->_buildDropDownNavigation($page[$id], $level + 1), $this->subNavTag)."\n";
				if (($this->_objTpl->blockExists('level_all') || $this->_objTpl->blockExists('level_'.($level+1))) && !$mainPage ) {
				    $this->data[$id]['catname'] = $this->data[$id]['catname'];
				    if (!empty($subNavigation) && ($id != $this->parentId[$this->pageId] )) { //)$this->data[$id]['status'] == 'on') {
				    	$this->data[$id]['catname'] .= $this->subNavSign;
				    }
				}
			} else {
				$subNavigation = "";
				$id = $page;
			}
			
			if ($this->_objTpl->blockExists('level_'.$level)) {
				$tmpNavigation = trim($this->_objTpl->_blocks['level_'.$level]);
			}
			
			if (!empty($tmpNavigation)) {
				if ($this->data[$id]['status'] == 'on') {
					$target = empty($this->data[$id]['target']) ? "_self" : $this->data[$id]['target'];
					
					if ($level == 1 && $this->topLevelPageId == $id) {
						$tmpNavigation = str_replace('{STYLE}', "starter_active", $tmpNavigation);
					} elseif ($level == 1) {
						$tmpNavigation = str_replace('{STYLE}', "starter_normal", $tmpNavigation);
					}
					
					$tmpNavigation = str_replace('{URL}', $this->data[$id]['url'], $tmpNavigation);
					$tmpNavigation = str_replace('{NAME}', $this->data[$id]['catname'], $tmpNavigation);
					$tmpNavigation = str_replace('{TARGET}', $target, $tmpNavigation);
					$tmpNavigation = str_replace('{NAVIGATION_ID}', $navigationId[$level], $tmpNavigation);
					$tmpNavigation = str_replace('{SUB_MENU}', $subNavigation, $tmpNavigation);
					
					$navigation .= $tmpNavigation."\n";
				}
			}
		}
		return $navigation;
	}
	
	
	/**
    * Get an array with all parentids
    *
    * @access  private
    */
	function _getParents()
	{
		$parentId = $this->parentId[$this->pageId];		
		while($parentId!=0) {
			if(is_array($this->table[$parentId])) { 		
				array_push($this->parents, $parentId);
				$parentId = $this->parentId[$parentId];
			} 			
		}		
		// adds the current pageId and the root id 0 to the parents array
		array_push($this->parents, $this->pageId, 0);		
	}
	
	

	/**
    * Get trail
    *
    * @param     integer  $currentid
    * @return    integer  $allparents
    */
	function getTrail()
	{
		$return ="";
		$parentId = $this->parentId[$this->pageId];
		while ($parentId!=0) {
			if(!is_array($this->table[$parentId])) { 
			    return $return;	
			}
			$n = $this->data[$parentId]['catname'];
			$u = $this->data[$parentId]['url'];
			$trail = "<a href=\"".$u."\" title=\"".$n."\">".$n."</a>".$this->separator;
			$return=$trail.$return;
			$parentId = $this->parentId[$parentId]; 
		}
		return $return;
	}
	
	
	
    /**
    * getFrontendLangNavigation()
    *
    * @param string   language navigation
    * @access public
    */	
  
    function getFrontendLangNavigation()
	{
	  	global $objInit;
	  	$this->arrLang = $objInit->getLanguageArray();  
		$langNavigation = "";				
	  	if(count($this->arrLang)>1) {
	  	  	foreach($this->arrLang as $id=>$value) {
	  	  		if($this->arrLang[$id]['frontend']==1) {
	  	  		    $langNavigation .= " [ <a href='?langId=".$id."' title='".$value['name']."' >".$value['name']."</a> ] ";
	  	  		}
	  	  	}
	  	}
		return $langNavigation; 	  	  	 		
	}
	
	
	
	function _debug($obj){
		  echo "<pre>";
		  print_r($obj);	
		  echo "</pre>";		
	}
}
?>