<?php
/**
* Class block
*
* block module class
*
* @copyright	CONTREXX CMS - Astalavista IT Engineering GmbH Thun
* @author		Astalavista Development Team <thun@astalvista.ch>            
* @module		block
* @modulegroup	modules
* @access		public
* @version		1.0.0
*/
require_once ASCMS_MODULE_PATH.'/block/lib/blockLib.class.php';

class blockManager extends blockLibrary
{
	/**
	* Template object
	*
	* @access private
	* @var object
	*/
	var $_objTpl;
	
	/**
	* Page title
	*
	* @access private
	* @var string
	*/
	var $_pageTitle;
	
	/**
	* Status message
	*
	* @access private
	* @var string
	*/
	var $_statusMessage = '';
	
	/**
	* Block Name and Status
	*
	* @access private
	* @var string
	*/
	var $blockIdNameStatus = array();
	
	/**
	* Constructor
	*/
	function blockManager()
	{
		$this->__construct();
	}
	
	/**
	* PHP5 constructor
	*
	* @global object $objTemplate
	* @global array $_ARRAYLANG
	*/
	function __construct()
	{
		global $objTemplate, $_ARRAYLANG, $_CONFIG, $objDatabase;
		
		$this->_objTpl = &new HTML_Template_Sigma(ASCMS_MODULE_PATH.'/block/template');
		$this->_objTpl->setErrorHandling(PEAR_ERROR_DIE);
    	
		if (isset($_POST['saveSettings'])) {
			$arrSettings = array(
				'blockStatus'	=> isset($_POST['blockUseBlockSystem']) ? intval($_POST['blockUseBlockSystem']) : 0,
				'blockRandom'	=> isset($_POST['blockUseBlockRandom']) ? intval($_POST['blockUseBlockRandom']) : 0
			);
			$this->_saveSettings($arrSettings);
		}
		
    	$objTemplate->setVariable("CONTENT_NAVIGATION", "	".($_CONFIG['blockStatus'] == '1' ? "<a href='index.php?cmd=block&amp;act=overview'>".$_ARRAYLANG['TXT_BLOCK_OVERVIEW']."</a><a href='index.php?cmd=block&amp;act=modify'>".$_ARRAYLANG['TXT_BLOCK_NEW_BLOCK']."</a>" : "")."
    														<a href='index.php?cmd=block&amp;act=settings'>".$_ARRAYLANG['TXT_BLOCK_SETTINGS']."</a>");
    	
    	//Get Block Name and Status
		$objBlockName = $objDatabase->Execute("SELECT id, name, random, active FROM ".DBPREFIX."module_block_blocks");
		if ($objBlockName !== false) {
			while (!$objBlockName->EOF) {
				$this->blockIdNameStatus[$objBlockName->fields['id']]['name'] = $objBlockName->fields['name'];
				$this->blockIdNameStatus[$objBlockName->fields['id']]['status'] = $objBlockName->fields['active'];
				$this->blockIdNameStatus[$objBlockName->fields['id']]['random'] = $objBlockName->fields['random'];
				$objBlockName->MoveNext();
			}
		}
	}
	
	/**
	* Get page
	*
	* Get a page of the block system administration
	*
	* @access public
	* @global object $objTemplate
	*/
	function getPage() 
	{
		global $objTemplate, $_CONFIG;
		
		if (!isset($_REQUEST['act'])) {
			$_REQUEST['act'] = '';
		}
		
		if ($_CONFIG['blockStatus'] != '1') {
			$_REQUEST['act'] = 'settings';
		}
		
		switch ($_REQUEST['act']) {
		case 'modify':
			$this->_showModifyBlock();
			break;
		case 'save':
			$this->_saveBlock();
			$this->_showOverview();
			break;
		case 'settings':
			$this->_showSettings();
			break;
		case 'del':
			$this->_delBlock();
			$this->_showOverview();
			break;
		case 'activate':
			$this->_activateBlock();
			$this->_showOverview();
			break;
		case 'deactivate':
			$this->_deactivateBlock();
			$this->_showOverview();
			break;
		case 'random':
			$this->_randomizeBlock();
			$this->_showOverview();
			break;	
		case 'random_off':
			$this->_randomizeBlockOff();
			$this->_showOverview();
			break;
		default:
			$this->_showOverview();
			break;
		}
		
		$objTemplate->setVariable(array(
			'CONTENT_TITLE'				=> $this->_pageTitle,
			'CONTENT_STATUS_MESSAGE'	=> $this->_statusMessage,
			'ADMIN_CONTENT'				=> $this->_objTpl->get()
		));
	}
	
	/**
	* Show overview
	*
	* Show the blocks overview page
	*
	* @access private
	* @global array $_ARRAYLANG
	* @see blockLibrary::_getBlocks(), blockLibrary::blockNamePrefix
	*/
	function _showOverview()
	{
		global $_ARRAYLANG, $objDatabase;
		
		$this->_pageTitle = $_ARRAYLANG['TXT_BLOCK_BLOCKS'];
		$this->_objTpl->loadTemplateFile('module_block_overview.html');
		
		$this->_objTpl->setVariable(array(
			'TXT_BLOCK_BLOCKS'				=> $_ARRAYLANG['TXT_BLOCK_BLOCKS'],
			'TXT_BLOCK_NAME'				=> $_ARRAYLANG['TXT_BLOCK_NAME'],
			'TXT_BLOCK_PLACEHOLDER'			=> $_ARRAYLANG['TXT_BLOCK_PLACEHOLDER'],
			'TXT_BLOCK_SUBMIT_SELECT'		=> $_ARRAYLANG['TXT_BLOCK_SUBMIT_SELECT'],
			'TXT_BLOCK_SUBMIT_DELETE'		=> $_ARRAYLANG['TXT_BLOCK_SUBMIT_DELETE'],
			'TXT_BLOCK_SUBMIT_ACTIVATE'		=> $_ARRAYLANG['TXT_BLOCK_SUBMIT_ACTIVATE'],
			'TXT_BLOCK_SUBMIT_DEACTIVATE'	=> $_ARRAYLANG['TXT_BLOCK_SUBMIT_DEACTIVATE'],
			'TXT_BLOCK_SUBMIT_RANDOM'		=> $_ARRAYLANG['TXT_BLOCK_SUBMIT_RANDOM'],
			'TXT_BLOCK_SUBMIT_RANDOM_OFF'	=> $_ARRAYLANG['TXT_BLOCK_SUBMIT_RANDOM_OFF'],
			'TXT_BLOCK_SELECT_ALL'			=> $_ARRAYLANG['TXT_BLOCK_SELECT_ALL'],
			'TXT_BLOCK_DESELECT_ALL'		=> $_ARRAYLANG['TXT_BLOCK_DESELECT_ALL'],
			'TXT_BLOCK_RANDOM'				=> $_ARRAYLANG['TXT_BLOCK_RANDOM'],
			'TXT_BLOCK_PLACEHOLDER'			=> $_ARRAYLANG['TXT_BLOCK_PLACEHOLDER'],
			'TXT_BLOCK_FUNCTIONS'			=> $_ARRAYLANG['TXT_BLOCK_FUNCTIONS'],		
			'TXT_DELETE_BLOCKS_ALL'			=> $_ARRAYLANG['TXT_DELETE_BLOCKS_ALL'],
		));
		
		$arrBlocks = &$this->_getBlocks();
		if (count($arrBlocks)>0) {
			$rowNr = 0;
			foreach ($arrBlocks as $blockId) {
	
				if($this->blockIdNameStatus[$blockId]['status'] ==  '1'){
					$status = "<a href='index.php?cmd=block&act=deactivate&blockId=".$blockId."' title=''><img src='images/icons/led_green.gif' border='0' alt='' /></a>";
				}else{
					$status = "<a href='index.php?cmd=block&act=activate&blockId=".$blockId."' title=''><img src='images/icons/led_red.gif' border='0' alt='' /></a>";
				}
				
				if($this->blockIdNameStatus[$blockId]['random'] ==  '1'){
					$random = "<img src='images/icons/refresh.gif' border='0' alt='' />";
				}else{				
					$random = "";
				}
				
				$this->_objTpl->setVariable(array(
					'BLOCK_ROW_CLASS'		=> $rowNr % 2 ? "row1" : "row2",
					'BLOCK_ID'				=> $blockId,
					'BLOCK_RANDOM'			=> $random,
					'BLOCK_PLACEHOLDER'		=> $this->blockNamePrefix.$blockId,
					'BLOCK_NAME'			=> $this->blockIdNameStatus[$blockId]['name'],
					'BLOCK_MODIFY'			=> str_replace('%NAME%', $this->blockNamePrefix.$blockId, $_ARRAYLANG['TXT_BLOCK_MODIFY_BLOCK']),
					'BLOCK_STATUS'			=> $status,
				));
				$this->_objTpl->parse('blockBlockList');
				
				$rowNr ++;
			}
		}
	}
	
	/**
	* Show modify block
	*
	* Show the block modification page
	*
	* @access private
	* @global array $_ARRAYLANG
	* @see blockLibrary::_getBlockContent(), blockLibrary::blockNamePrefix
	*/
	function _showModifyBlock()
	{
		global $_ARRAYLANG;
		
		$blockId = isset($_REQUEST['blockId']) ? intval($_REQUEST['blockId']) : 0;
		$pageTitle = $blockId != 0 ? str_replace('%NAME%', $this->blockNamePrefix.$blockId, $_ARRAYLANG['TXT_BLOCK_MODIFY_BLOCK']) : $_ARRAYLANG['TXT_BLOCK_ADD_BLOCK'];
		$blockContent = '';
		$blockName = '';
		$blockRandom = '';
		
		$this->_pageTitle = $pageTitle;
		$this->_objTpl->loadTemplateFile('module_block_modify.html');
		
		if ($blockId != 0) {
			$blockContent = $this->_getBlockContent($blockId);
			$blockName = $this->blockIdNameStatus[$blockId]['name'];;
			if($this->blockIdNameStatus[$blockId]['random'] == '1'){
				$blockRandom = "checked";
			}
		}
		
		$this->_objTpl->setVariable(array(
			'BLOCK_ID'				=> $blockId,
			'BLOCK_MODIFY_TITLE'	=> $pageTitle,
			'BLOCK_NAME'			=> $blockName,
			'BLOCK_RANDOM'			=> $blockRandom,		
			'BLOCK_CONTENT'			=> get_wysiwyg_editor('blockBlockContent', $blockContent)
		));
		
		$this->_objTpl->setVariable(array(
			'TXT_BLOCK_CONTENT'	=> $_ARRAYLANG['TXT_BLOCK_CONTENT'],
			'TXT_BLOCK_NAME'	=> $_ARRAYLANG['TXT_BLOCK_NAME'],
			'TXT_BLOCK_RANDOM'	=> $_ARRAYLANG['TXT_BLOCK_RANDOM'],
			'TXT_BLOCK_SAVE'	=> $_ARRAYLANG['TXT_BLOCK_SAVE']
		));
	}
	
	/**
	* Save block
	*
	* Add or update the conten to a block
	*
	* @access private
	* @global array $_ARRAYLANG
	* @see blockLibrary::_updateBlock()
	*/
	function _saveBlock()
	{
		global $_ARRAYLANG;
		
		$blockId = isset($_POST['blockId']) ? intval($_POST['blockId']) : 0;
		$blockContent = isset($_POST['blockBlockContent']) ? contrexx_addslashes($_POST['blockBlockContent']) : '';
		$blockName = $_POST['blockName'];
		$blockRandom = $_POST['blockRandom'];
		
		if($blockName == null ){
			$blockName = $_ARRAYLANG['TXT_BLOCK_NO_NAME'];
		}
		
		if ($blockId != 0) {
			if ($this->_updateBlock($blockId, $blockContent, $blockName, $blockRandom)) {
				$this->_statusMessage = $_ARRAYLANG['TXT_BLOCK_BLOCK_UPDATED_SUCCESSFULLY'];
				header("LOCATION: ?cmd=block");
			}else{
				$this->_statusMessage = $_ARRAYLANG['TXT_BLOCK_BLOCK_COULD_NOT_BE_UPDATED'];
			}
		}else{
			if($this->_addBlock($blockId, $blockContent, $blockName, $blockRandom)) {
				$this->_statusMessage = $_ARRAYLANG['TXT_BLOCK_BLOCK_UPDATED_SUCCESSFULLY'];
				header("LOCATION: ?cmd=block");
			}else{
				$this->_statusMessage = $_ARRAYLANG['TXT_BLOCK_BLOCK_COULD_NOT_BE_UPDATED'];
			}
		}
	}
	
	/**
	* del block
	*
	* delete a block
	*
	* @access private
	* @global array $_ARRAYLANG
	*/
	function _delBlock()
	{
		global $_ARRAYLANG, $objDatabase;
		
		$arrDelBlocks = $_POST['selectedBlockId'];
		
		if($arrDelBlocks != null){
			foreach ($arrDelBlocks as $blockId){
				$query = "DELETE FROM ".DBPREFIX."module_block_blocks WHERE id=$blockId";
				$objDatabase->Execute($query);
			}
		}else{
			if(isset($_GET['blockId'])){
				$blockId = $_GET['blockId'];
				$query = "DELETE FROM ".DBPREFIX."module_block_blocks WHERE id=$blockId";
				$objDatabase->Execute($query);
			}
		}
	}
	
	/**
	* activate block
	*
	* change the status from a block
	*
	* @access private
	* @global array $_ARRAYLANG
	*/
	function _activateBlock()
	{
		global $_ARRAYLANG, $objDatabase;
		
		$arrStatusBlocks = $_POST['selectedBlockId'];
		if($arrStatusBlocks != null){
			foreach ($arrStatusBlocks as $blockId){
				$query = "UPDATE ".DBPREFIX."module_block_blocks SET active='1' WHERE id=$blockId";
				$objDatabase->Execute($query);
			}
		}else{
			if(isset($_GET['blockId'])){
				$blockId = $_GET['blockId'];
				$query = "UPDATE ".DBPREFIX."module_block_blocks SET active='1' WHERE id=$blockId";
				$objDatabase->Execute($query);
			}
		}
		
		header("LOCATION: ?cmd=block");
	}
	
	/**
	* deactivate block
	*
	* change the status from a block
	*
	* @access private
	* @global array $_ARRAYLANG
	*/
	function _deactivateBlock()
	{
		global $_ARRAYLANG, $objDatabase;
		
		$arrStatusBlocks = $_POST['selectedBlockId'];
		if($arrStatusBlocks != null){
			foreach ($arrStatusBlocks as $blockId){
				$query = "UPDATE ".DBPREFIX."module_block_blocks SET active='0' WHERE id=$blockId";
				$objDatabase->Execute($query);
			}
		}else{
			if(isset($_GET['blockId'])){
				$blockId = $_GET['blockId'];
				$query = "UPDATE ".DBPREFIX."module_block_blocks SET active='0' WHERE id=$blockId";
				$objDatabase->Execute($query);
			}
		}
		
		header("LOCATION: ?cmd=block");
	}
	
	/**
	* add to random
	*
	* change the status from a block
	*
	* @access private
	* @global array $_ARRAYLANG
	*/
	function _randomizeBlock()
	{
		global $_ARRAYLANG, $objDatabase;
		
		$arrStatusBlocks = $_POST['selectedBlockId'];
		if($arrStatusBlocks != null){
			foreach ($arrStatusBlocks as $blockId){
				$query = "UPDATE ".DBPREFIX."module_block_blocks SET random='1' WHERE id=$blockId";
				$objDatabase->Execute($query);
			}
		}
		
		header("LOCATION: ?cmd=block");
	}
	
	/**
	* del the random
	*
	* change the status from a block
	*
	* @access private
	* @global array $_ARRAYLANG
	*/
	function _randomizeBlockOff()
	{
		global $_ARRAYLANG, $objDatabase;
		
		$arrStatusBlocks = $_POST['selectedBlockId'];
		if($arrStatusBlocks != null){
			foreach ($arrStatusBlocks as $blockId){
				$query = "UPDATE ".DBPREFIX."module_block_blocks SET random='0' WHERE id=$blockId";
				$objDatabase->Execute($query);
			}
		}
		
		header("LOCATION: ?cmd=block");
	}
	
	/**
	* Show settings
	*
	* Show the settings page
	*
	* @access private
	* @global array $_ARRAYLANG
	*/
	function _showSettings()
	{
		global $_ARRAYLANG, $_CONFIG;
		
		$this->_pageTitle = $_ARRAYLANG['TXT_BLOCK_SETTINGS'];
		$this->_objTpl->loadTemplateFile('module_block_settings.html');
		
		$this->_objTpl->setVariable(array(
			'TXT_BLOCK_SETTINGS'						=> $_ARRAYLANG['TXT_BLOCK_SETTINGS'],
			'TXT_BLOCK_USE_BLOCK_SYSTEM'				=> $_ARRAYLANG['TXT_BLOCK_USE_BLOCK_SYSTEM'],
			'TXT_BLOCK_USE_BLOCK_RANDOM'				=> $_ARRAYLANG['TXT_BLOCK_USE_BLOCK_RANDOM'],
			'TXT_BLOCK_USE_BLOCK_RANDOM_PLACEHOLDER'	=> $_ARRAYLANG['TXT_BLOCK_USE_BLOCK_RANDOM_PLACEHOLDER'],
			'TXT_BLOCK_SAVE'							=> $_ARRAYLANG['TXT_BLOCK_SAVE']
		));
		
		$this->_objTpl->setVariable('BLOCK_USE_BLOCK_SYSTEM', $_CONFIG['blockStatus'] == '1' ? 'checked="checked"' : '');
		$this->_objTpl->setVariable('BLOCK_USE_BLOCK_RANDOM', $_CONFIG['blockRandom'] == '1' ? 'checked="checked"' : '');
	}
}
?>
