<?php
/**
* Class Shop manager 
*
* Class for the administration of the shop 
*
* @copyright   CONTREXX CMS - Astalavista IT Engineering GmbH Thun
* @author      Ivan Schmid <ivan.schmid@astalavista.ch>              
* @module      shopmanager
* @modulegroup shop                                                                                     
* @access public
* @version 1.0.0
*/


require_once ASCMS_MODULE_PATH .'/shop/shopLib.class.php';
require_once ASCMS_MODULE_PATH .'/shop/lib/Currency.class.php';
require_once ASCMS_MODULE_PATH .'/shop/lib/Payment.class.php';
require_once ASCMS_MODULE_PATH .'/shop/lib/Shipment.class.php';
require_once ASCMS_MODULE_PATH .'/shop/lib/PaymentProcessing.class.php';



class Shop extends shoplibrary
{
    var $pageContent;
    var $objTemplate;
    var $arrCategoriesSorted = array();
    var $arrCategoriesTable = array();
    var $arrCategoriesName = array();
    var $arrParentCategoriesId = array();
    var $arrParentCategoriesTable = array();
    var $statusMessage = "";
    var $thumbnailNameSuffix = "_thumb";
    var $customerId;
    var $customerUsername;
    var $customerPrefix; 
    var $customerCompany;    
    var $customerLastname;             
    var $is_reseller = 0;
    var $is_auth = 0;
    var $noPictureName = "no_picture.gif";
    var $shopImageWebPath;
    var $shopImagePath;
    var $inactiveStyleName = "inactive";
    var $activeStyleName = "active";
    var $arrProductAttributes = array();
    var $langId; 
    
    

	/**
	* Object of the payment offerer
	* @access private
	* @var array
	* @see Payment.class.php
	*/
    var $objPayment;
    
	/**
	* Object of the payment processing
	* @access private
	* @var array
	* @see PaymentProcessing.class.php
	*/
    var $objProcessing;    
    
    
	/**
	* Shipment object
	* @access public
	* @var array
	*/
    var $objShipment;    
    
    
	/**
	* Currency object
	* @access public
	* @var object Currency
	*/    
    var $objCurrency; 
    
	/**
	* Active currency unit name( e.g. CHF, EUR, USD )
	* @access private
	* @var string
	*/
    var $aCurrencyUnitName;
	
    /**
	* Currency navbar indicator (true|false)
	* @access private
	* @var boolean
	*/
    var $_hideCurrencyNavbar = false;

    
	/**
    * Constructor
    *
    * @param  string  
    * @access public
    */   
    function Shop($pageContent)
    { 
    	$this->__construct($pageContent);    
    }    
    
    
    
    
    /**
    * Constructor PHP5!
    *
    * @param  string  
    * @access public
    */
    function __construct($pageContent = ''){
    	
    	global $_ARRAYLANG, $_LANGID, $objDatabase; 
    	
	    $this->langId = $_LANGID;  	
		$this->pageContent = $pageContent;  
		$this->shopImageWebPath = ASCMS_SHOP_IMAGES_WEB_PATH . '/';
		$this->shopImagePath = ASCMS_SHOP_IMAGES_PATH. '/';

    	// sigma template
		$this->_objTpl = &new HTML_Template_Sigma('.');
		$this->_objTpl->setErrorHandling(PEAR_ERROR_DIE);	
		$this->_objTpl->setTemplate($this->pageContent, true, true);	
		
		// Currency object
		// see Currency.class.php
		$this->objCurrency = &new Currency();
		$this->aCurrencyUnitName = $this->objCurrency->getActiveCurrencyParameter("symbol");
		
		// Shipment object
		// see Shipment.class.php
		$this->objShipment = &new Shipment();		
		
		
		// Payment object
		// see Payment.class.php
		$this->objPayment = &new Payment();		
		
		
		// initialize the countries array
		$this->_initCountries();
		
		// initialize the shipment array
		$this->_initShipment();		
		      
        $this->_authenticate();
         
        $this->_initConfiguration();
        $this->_initPayment();
        
        // initialize the product options names and values array
        $this->initProductAttributes();
        
		// Payment processing object
		// see PaymentProcessing.class.php
		$this->objProcessing = &new PaymentProcessing($this->arrConfig);        
        
		
		$query = "SELECT catid, 
		                   parentid, 
		                   catname
		              FROM ".DBPREFIX."module_shop_categories
		             WHERE catstatus=1
		          ORDER BY parentid ASC, 
		                   catsorting ASC";
		
		$objResult = $objDatabase->Execute($query);
				

		while (!$objResult->EOF) {			
		    $this->arrCategoriesTable[$objResult->fields['parentid']][$objResult->fields['catid']]=stripslashes($objResult->fields['catname']);
		    $this->arrCategoriesName[$objResult->fields['catid']]=stripslashes($objResult->fields['catname']);	
		    $this->arrParentCategoriesId[$objResult->fields['catid']]=$objResult->fields['parentid'];	
		    $this->arrParentCategoriesTable[$objResult->fields['catid']][$objResult->fields['parentid']]=stripslashes($objResult->fields['catname']);
		    $objResult->MoveNext();
		}	
    }
    
    
    
    
    function initProductAttributes()
    {
    	global $objDatabase;
		
		// get product attributes
		$query = "SELECT attributes.product_id AS productId,
						 attributes.attributes_name_id AS nameId,
						 attributes.attributes_value_id AS valueId,
						 attributes.sort_id AS sort_id,
						 name.name AS nameTxt,
						 name.display_type as type,
						 value.value AS valueTxt,
						 value.price AS price,
						 value.price_prefix AS pricePrefix
					FROM ".DBPREFIX."module_shop_products_attributes AS attributes,
						 ".DBPREFIX."module_shop_products_attributes_name AS name,
						 ".DBPREFIX."module_shop_products_attributes_value AS value
				   WHERE attributes.attributes_name_id = name.id
					 AND attributes.attributes_value_id = value.id
				   ORDER BY sort_id, value ASC";
		
		if (($objResult = $objDatabase->Execute($query)) !== false) {
			while (!$objResult->EOF) {
				if (!isset($this->arrProductAttributes[$objResult->fields['productId']][$objResult->fields['nameId']])) {
					$this->arrProductAttributes[$objResult->fields['productId']][$objResult->fields['nameId']] = array(
							'name'		=> $objResult->fields['nameTxt'],
							'type'		=> $objResult->fields['type']
					);
				}
				
				$this->arrProductAttributes[$objResult->fields['productId']][$objResult->fields['nameId']]['values'][$objResult->fields['valueId']] = array(
						'id'			=> $objResult->fields['valueId'],
						'value' 		=> $objResult->fields['valueTxt'],
						'price'			=> $objResult->fields['price'],
						'price_prefix'	=> $objResult->fields['pricePrefix'],
				);
				$objResult->MoveNext();
			}
		}
    }

       
    // needed 
    function getShopPage()
    {
    	if (isset($_GET['cmd'])){
	        switch($_GET['cmd']){
				case "success":
					$_GET['act'] = "success";
					break;
				case "confirm":
	                $_GET['act'] = "confirm";
				    break;
				case "payment":
	                $_GET['act'] = "payment";
				    break;
				case "account":
	                $_GET['act'] = "account";
				    break;	
				case "cart":
	                $_GET['act'] = "cart";
				    break;	
				case "products":
	                $_GET['act'] = "products";	
	                break;  
				case "discounts":
	                $_GET['act'] = "discounts";	
	                break;                  
				case "login":
	                $_GET['act'] = "login";	
	                break;
				case "login":
	                $_GET['act'] = "login";	
	                break;
				case "terms":
	                $_GET['act'] = "terms";	
	                break;               
				default:
				    //$_GET['act'] = "products";    	           
				    break;
			} 
    	}
    		  	
    	if (isset($_GET['act'])){    	   	
	        switch($_GET['act']){
				case "terms":
					// just to do nothing else than show the requested page
					break;				
				case "success":
					$this->success();
					break;
				case "confirm":
	                $this->confirm();
				    break;	
				case "payment":
	                $this->payment();
				    break;	
				case "account":
	                $this->account();
				    break;	
				case "cart":
	                $this->cart();
				    break;	
				case "products":
	                $this->products();
				    break;
				case "discounts":
	                $this->discounts();
				    break;				    		    			    		    
				case "login":
	                $this->login();
	                break;  
	            case "destroy":
	            	$this->destroyCart();
	            	$this->products();
	            	break;			    			    			    
				case "paypalIpnCheck":
					require_once "payments/paypal/paypal.class.php";
					$objPaypal = new PayPal;
					$objPaypal->ipnCheck();
					exit;
					break;
				default:    	
	                $this->products();
				    break;
			}
    	}
    	else {
    	    $this->products();	
    	}
    	
    	return $this->_objTpl->get();
    }  


    
   
    
    function getShopNavbar($shopNavbarContent)
    {	
    	global $objDatabase, $_ARRAYLANG;
		
		$objTpl = &new HTML_Template_Sigma('.');
		$objTpl->setErrorHandling(PEAR_ERROR_DIE);	    
	    $objTpl->setTemplate($shopNavbarContent, true, true);
   	
    	if ($this->is_auth==1) {
    		if (empty($this->customerCompany)){
    		   $loginInfo = $this->customerPrefix." ".$this->customerLastname."<br />";	
    		} else {
    		   $loginInfo = $this->customerCompany."<br />";
    		}  		
    		$loginStatus = $_ARRAYLANG['TXT_LOGGED_IN_AS']."<br />";   		
    	} else {
    		$loginInfo = "";
    		$loginStatus = $_ARRAYLANG['TXT_LOGGED_IN_AS_SHOP_GUEST'];    		   		
    	} 
    	$objTpl->setVariable("SHOP_CART_INFO", $this->showCartInfo());  	
    	$objTpl->setVariable("SHOP_LOGIN_STATUS",$loginStatus);   	
    	$objTpl->setVariable("SHOP_LOGIN_INFO",$loginInfo); 
    	
    	// start currencies
    	if (!$this->_hideCurrencyNavbar) {
    		if ($objTpl->blockExists("shopCurrencies")) {   			
		    	$objTpl->setCurrentBlock("shopCurrencies"); 	    	
		    	
		    	$curNavbar = $this->objCurrency->getCurrencyNavbar();	
		    	if (!empty($curNavbar)){
		    		$objTpl->setVariable("SHOP_CURRENCIES",$curNavbar);
		    		$objTpl->setVariable("TXT_CURRENCIES",$_ARRAYLANG['TXT_CURRENCIES']);
		    	}
		    	$objTpl->parseCurrentBlock("shopCurrencies");  
		        // end currencies
    		} 
    	}     

		if($objTpl->blockExists("shopNavbar")) {
			$objTpl->setCurrentBlock("shopNavbar");
		}    	  	  	        
        $currentCatId = 0;
        if (isset($_GET['catId'])){
		    $currentCatId = intval($_GET['catId']);	
        }
		$treeArray = $this->_makeArrCategories();											
		$arrayTreeParents = $this->_makeArrCurrentCategories($currentCatId);
		$thisTree = 0;
		$topLevelId = 0;
		$i_style = 1;		
		foreach ($treeArray as $k => $v) {	
		    $expand = false;
			$level = intval($v);					
			if ($level==0){
				$expand=true;
				$topLevelId = $currentCatId;
			} else {			
				$pcat = $this->arrParentCategoriesId[$k];
				if ( in_array ($pcat, $arrayTreeParents) 
				     OR $thisTree==1
				     OR $topLevelId==$pcat 
				   ) 
				{
					if ($k==$currentCatId){
						$thisTree = 1;
					} else {
						$thisTree = 0;					
					}
					$expand = true;
				}
			}					
			if ($expand){
				$width ="";
				$style ="";
				$style_no = "";
				$styleLevel = 0;
				if ($level!=0){
					$count= $level*3;
					for ($i = 1; $i <= $count; $i++) {$width .="&nbsp;";}
				} else {
					$style_no = "_$i_style";
					$i_style++;
				}
				$styleLevel = $level+1;
				//$style = "shopnav$styleLevel$style_no";
				$style = "shopnavbar".$styleLevel;
				if ($currentCatId==$k){
					$style .= "_active";
				}											
				$objTpl->setVariable(array(					
				'SHOP_CATEGORY_STYLE'	=> $style,				
				'SHOP_CATEGORY_ID' 		=> $k,
				'SHOP_CATEGORY_OFFSET' 	=> $width,
				'SHOP_CATEGORY_NAME'    => $this->arrCategoriesName[$k],			
				));
				$objTpl->parseCurrentBlock("shopNavbar");
			}
		}
		return $objTpl->get();   	
	}
	
	
	
	
    
    /**
    * Do admin tree array
    *
    * @param    integer  $parcat
    * @param    integer  $level
    * @param    integer  $maxlevel
    * @return   array    $this->treeArray
    */
	function _makeArrCategories($parcat=0, $level=0)
	{
		$list=$this->arrCategoriesTable[$parcat];	 	 		 
		 if (is_array($list)){
				while (list($key,$val)=each($list)){			  
					  $this->arrCategoriesSorted[$key]=$level;					  
		              if ( isset($this->arrCategoriesTable[$key])){
					  	$this->_makeArrCategories($key,$level+1);
					  }					  
				}
		 }
		 return $this->arrCategoriesSorted;
	}
	
	
	
	
	
	/**
    * Get trail
    *
    * @param     integer  $currentid
    * @return    integer  $allparents
    */
	function _makeArrCurrentCategories($currentid=1)
	{	
		$a = array();
		while ($currentid!=0) {
			$x=$this->arrParentCategoriesTable[$currentid];			
			if (!is_array($x)){
				$a[]=0;
				$currentid=0;
			} else{
				$result=each($x);
				$a[] = $result[0];
				$currentid = $result[0];
			}				
		}
		RETURN $a;
	}
	
       
   
    function products()
    {	
    	global $objDatabase, $_ARRAYLANG, $_CONFIG, $themesPages;
    	
    	// Check payment validation
    	if (isset($_GET['handler']) && !empty($_GET['handler'])){
    		switch ($_GET['handler']){
    			case "yellowpay":
    				$this->_checkPaymentValidation($_POST['txtOrderIDShop'],$_POST['SessionId']);
    				exit;
    				break;
    		}
    	}
    	
    	// initialize variabes
    	$pos=0;
    	$paging = "";
    	$class="";
    	  	    	
    	$this->_objTpl->setGlobalVariable('TXT_SEE_LARGE_PICTURE',$_ARRAYLANG['TXT_SEE_LARGE_PICTURE']);  
    	$this->_objTpl->setGlobalVariable('TXT_ADD_TO_CARD',$_ARRAYLANG['TXT_ADD_TO_CARD']); 
    	$this->_objTpl->setGlobalVariable('TXT_PRODUCT_ID',$_ARRAYLANG['TXT_PRODUCT_ID']);    	    
    	$this->_objTpl->setGlobalVariable("SHOP_JAVASCRIPT_CODE", $this->getJavascriptCode()); 
    	$this->_objTpl->setVariable('SHOPNAVBAR_FILE', $this->getShopNavbar($themesPages['shopnavbar']));  
    	
    	$productId = isset($_REQUEST['productId']) ? intval($_REQUEST['productId']) : 0; 
    	if (isset($_REQUEST['referer']) && $_REQUEST['referer'] == 'cart') {
    		$cartProdId = $productId;
    		$productId = $_SESSION['shop']['cart']['products'][$productId]['id'];
    	}
    	 		
    	$catId = isset($_REQUEST['catId']) ? intval($_REQUEST['catId']) : 0;
    	$term= isset($_REQUEST['term']) ? mysql_escape_string(stripslashes(trim($_REQUEST['term']))) : ''; 	       	    
	    	    	    
	    $shopMenuOptions = $this->getCatMenu($selectedId=$catId);	    
	    $shopMenu = "<form action='?section=shop' method='post'>\n<input type='text' name='term' value=\"".$term."\" />\n<select name='catId'>\n<option value=\"0\">".$_ARRAYLANG['TXT_ALL_PRODUCT_GROUPS']."</option>".$shopMenuOptions."</select>\n<input type='submit' name='Submit' value='".$_ARRAYLANG['TXT_SEARCH']."' />\n</form>";
	    $this->_objTpl->setVariable("SHOP_MENU", $shopMenu);
	    $this->_objTpl->setVariable("SHOP_CART_INFO", $this->showCartInfo());            	    
	    
		$q_search = "";
		$q_special_offer = "AND (is_special_offer = 1) ";
		$q1_category = "";
		$q2_category = "";
		$pagingTermQuery = "";
		$pagingCatIdQuery="";
		
		if ($catId!=0) {
		   $q_special_offer = "";
		   $q1_category = "," .DBPREFIX."module_shop_categories AS c";
		   $q2_category = "AND ( p.catid = c.catid 
			               AND c.catid = $catId) ";	
		   $pagingCatIdQuery= "&amp;catId=".$catId;	   
		}
		
		if (!empty($term)) { 
		   $q_special_offer = "";                                
		   $q_search = "AND (
		                      p.title LIKE '%$term%' 
		                   OR p.description LIKE '%$term%'
		                   OR p.shortdesc LIKE '%$term%'
		                   OR p.id LIKE '%$term%'                            
		               )";
		   $pagingTermQuery = "&amp;term=".$term;
		}
		        
	    if ($productId!=0) {  
		    $q = "SELECT *
			        FROM ".DBPREFIX."module_shop_products   
			       WHERE id = $productId";
	    } else {
			$q = "SELECT p.id, 
			             p.picture,
			             p.title,  
						 p.normalprice,
						 p.resellerprice,
			             p.shortdesc,
			             p.description, 			
			             p.stock, 
			             p.manufacturer_url,
			             p.discountprice, 
			             p.is_special_offer, 
			             p.status,
			             p.sort_order
			        FROM ".DBPREFIX."module_shop_products AS p
			        $q1_category     
			       WHERE status=1 " . $q_special_offer . $q2_category . $q_search .
			    "ORDER BY p.sort_order ASC, p.id DESC";
        }                	    
		$objResult = $objDatabase->Execute($q);		
		if (isset($_GET['pos'])) {
			$pos = intval($_GET['pos']);
		}
		$count = $objResult->RecordCount();
		if ($count==0) {
			$paging = "<br />".$_ARRAYLANG['TXT_SELECT_SUB_GROUP'];
		} elseif ($count>$_CONFIG['corePagingLimit']) {
		    $paging = "<br />".getPaging($count, $pos, "&amp;section=shop".$pagingCatIdQuery.$pagingTermQuery, "<b>".$_ARRAYLANG['TXT_PRODUCTS']."</b>", true);		    
		   // $q .= " LIMIT $pos, {$_CONFIG['corePagingLimit']}";	
			
			if (!($objResult = $objDatabase->SelectLimit($q, $_CONFIG['corePagingLimit'], $pos))) { 
			    $this->errorHandling();
				return false;
			}
		}	
		$this->_objTpl->setVariable("SHOP_PRODUCT_PAGING", $paging); 
		$this->_objTpl->setVariable("SHOP_PRODUCT_TOTAL", $count); 																				    		
		$this->_objTpl->setCurrentBlock('shopProductRow');	
        if ($count>0) {
        	$formId = 0;  	 
			while (!$objResult->EOF) {
				$productSubmitFunction = "";
				// if (($i % 2) == 0) {$class="row1";} else {$class="row2";}
				$fileArr = explode (".", $objResult->fields['picture']);
				$file = $fileArr[0].$this->thumbnailNameSuffix.".".$fileArr[1];		    		    			
				
				// no product picture available
				if (empty($fileArr[1])){	    		    
					$thumbnailPath = $this->shopImageWebPath.$this->noPictureName;
					$pictureLink = "javascript:alert('".$_ARRAYLANG['TXT_NO_PICTURE_AVAILABLE']."');";			
				} else {
					$thumbnailPath = $this->shopImageWebPath.$file;
					$picturePath = $this->shopImageWebPath.$objResult->fields['picture'];					
					$size=getimagesize($this->shopImagePath.$objResult->fields['picture']);
					$width=$size[0]+25;
					$height=$size[1]+25;		
					$pictureLink = "javascript:viewPicture('".$picturePath."','width=".$width.",height=".$height."')";					
				}				
											
				// Show the stock
				$stock = ($objResult->fields['stock_visibility']==1) ? $_ARRAYLANG['TXT_STOCK'].": ".intval($objResult->fields['stock']) : "";	

				// Show the manufacturer hyperlink
				$manufacturerLink = strlen($objResult->fields['manufacturer_url'])>10 ? "<a href=\"".$objResult->fields['manufacturer_url']."\" target='new'>".$_ARRAYLANG['TXT_MANUFACTURER_URL']."</a>" : "";					

				// Show the price			
				$price = $this->_getProductPrice($objResult->fields['normalprice'], $objResult->fields['resellerprice']);	
				$discountPrice_Unit = $this->aCurrencyUnitName;										
				
				// if no discountprice
				if ($objResult->fields['discountprice']== "0.00" OR $objResult->fields['is_special_offer']==0){
					$discountPrice = "";
					$discountPrice_Unit = "";
				} else {				
					$price = "<s>".$price."</s>";													
					$discountPrice = $this->objCurrency->getCurrencyPrice($objResult->fields['discountprice']);														
				}		
				
				$longDescription = $objResult->fields['description'];
				$shortDescription = $objResult->fields['shortdesc'];
				
				if ($productId==0) {  
					$description = $shortDescription;
					if (!empty($longDescription)) {
					    $detailLink = "<a href='?section=shop&amp;cmd=details&amp;productId=".$objResult->fields['id']."'>".$_ARRAYLANG['TXT_MORE_INFORMATIONS']."</a>";				
					} else {
						$detailLink = "";
					}
				} else {
					$description = $shortDescription;		        	
				}
				
				// set submit button name
				if (isset($_GET['cmd']) && $_GET['cmd'] == "details" && isset($_GET['referer']) && $_GET['referer'] == "cart") {
						$productSubmitName = "updateProduct[".$cartProdId."]";
						$productSubmitFunction = $this->productOptions($objResult->fields['id'], $formId, $cartProdId);
				} else {
						$productSubmitName = "addProduct";
						$productSubmitFunction = $this->productOptions($objResult->fields['id'], $formId);
				}
				
				
				
				//call product options and set the submit name with the return value
				$shopProductFormName = "shopProductForm{$formId}";
				
				$this->_objTpl->setVariable(array(
					'SHOP_ROWCLASS' 		            => $class,
					'SHOP_PRODUCT_ID' 		            => $objResult->fields['id'],
					'SHOP_PRODUCT_TITLE' 		        => $objResult->fields['title'],
					'SHOP_PRODUCT_DESCRIPTION'          => $description,
					'SHOP_PRODUCT_DETAILDESCRIPTION'    => $longDescription,
					'SHOP_PRODUCT_THUMBNAIL'            => $thumbnailPath,
					'SHOP_PRODUCT_THUMBNAIL_LINK'       => $pictureLink,
					'SHOP_PRODUCT_PRICE'     	        => ($price=="0.00") ? "" : $price,
					'SHOP_PRODUCT_PRICE_UNIT'           => ($price=="0.00") ? "" : $this->aCurrencyUnitName,													
					'SHOP_PRODUCT_DISCOUNTPRICE'        => $discountPrice,
					'SHOP_PRODUCT_DISCOUNTPRICE_UNIT'   => $discountPrice_Unit,															
					'SHOP_PRODUCT_STOCK'		        => $stock,
					'SHOP_MANUFACTURER_LINK'            => $manufacturerLink,
					'SHOP_PRODUCT_DETAILLINK'	        => $detailLink,
					'SHOP_PRODUCT_FORM_NAME'			=> $shopProductFormName,
					'SHOP_PRODUCT_SUBMIT_NAME'			=> $productSubmitName,
					'SHOP_PRODUCT_SUBMIT_FUNCTION'		=> $productSubmitFunction
				));	
				   			
				$this->_objTpl->parse('shopProductRow');
				$formId++;	
				$objResult->MoveNext();	   
			} 
		} else {
							
			$this->_objTpl->hideBlock('shopProductRow');
		}  		   	
    }    
    
    
    
    function productOptions($product_Id, $formName, $cartProdId = false)
    {	
    	global $_ARRAYLANG, $_CONFIG;
    	
    	// check if the product option block is set in the template
    	if ($this->_objTpl->blockExists('shopProductOptionsRow') && $this->_objTpl->blockExists('shopProductOptionsValuesRow')) {
    		$domId = 0;
    		$checkOptionIds = "";
    		
			if ($cartProdId !== false) {
    			$product_Id = $_SESSION['shop']['cart']['products'][$cartProdId]['id'];
    		}	
	    	
	    	//start products options block		
			$this->_objTpl->setCurrentBlock('shopProductOptionsRow');
			
			//start products options values block		
			$this->_objTpl->setCurrentBlock('shopProductOptionsValuesRow');	
			
			//check options
			if (!isset($this->arrProductAttributes[$product_Id])) {
				//hideblocks
				$this->_objTpl->hideBlock("shopProductOptionsRow"); 
				$this->_objTpl->hideBlock("shopProductOptionsValuesRow"); 
			} else {
				foreach ($this->arrProductAttributes[$product_Id] as $optionId => $arrOptionDetails) {
					$selectValues = "";
					
					// create head of option menu/checkbox/radiobutton
					switch ($arrOptionDetails['type']) {
						case '0':
							$selectValues = "<select name=\"productOption[".$optionId."]\" id=\"productOption-".$product_Id."-{$optionId}-{$domId}\" style=\"width:180px;\">\n";
							$selectValues .= "<option value=\"0\">".$arrOptionDetails['name']."&nbsp;".$_ARRAYLANG['TXT_CHOOSE']."</option>\n";
							break;
						case '1':
							$selectValues = "<input type=\"hidden\" id=\"productOption-".$product_Id."-{$optionId}\" value=\"{$arrOptionDetails['name']}\" />\n";
							$checkOptionIds .= "$optionId;";
							break;
					}
					
					$i = 0;
					foreach ($arrOptionDetails['values'] as $valueId => $arrValues) {
						$valuePrice = "";
						$selected = false;
						
						//price prefix
						if ($arrValues['price'] != '') {
							if ($arrValues['price'] != '0.00'){
								$currencPrice = $this->objCurrency->getCurrencyPrice($arrValues['price']);
								$valuePrice = '&nbsp;&nbsp;('.$arrValues['price_prefix'].'&nbsp;'.$currencPrice.'&nbsp;'.$this->aCurrencyUnitName.')';
							}
						}
						
						// mark the option value as selected if it was already selected and this site was requested from the cart
						if ($cartProdId !== false && isset($_SESSION['shop']['cart']['products'][$cartProdId]['options'][$optionId])) {
							if (in_array($valueId, $_SESSION['shop']['cart']['products'][$cartProdId]['options'][$optionId])) {
								$selected = true;
							}
						}
						
						// create option menu/checkbox/radiobutton
						switch ($arrOptionDetails['type']) {
							case '0':
								$selectValues .= "<option value=\"$valueId\" ".($selected == true ? "selected=\"selected\"" : "")." >".$arrValues['value'].$valuePrice."</option>\n";
								break;
								
							case '1':
								$selectValues .= "<input type=\"radio\" name=\"productOption[".$optionId."]\" id=\"productOption-".$product_Id."-{$optionId}-{$domId}\" value=\"$valueId\" ".($selected == true ? "checked=\"checked\"" : "")." /><label for=\"productOption-".$product_Id."-{$optionId}-{$domId}\">&nbsp;".$arrValues['value'].$valuePrice."</label><br />\n";
								break;
								
							case '2':
								$selectValues .= "<input type=\"checkbox\" name=\"productOption[".$optionId."][$i]\" id=\"productOption-".$product_Id."-{$optionId}-{$domId}\" value=\"$valueId\" ".($selected == true ? "checked=\"checked\"" : "")." /><label for=\"productOption-".$product_Id."-{$optionId}-{$domId}\">&nbsp;".$arrValues['value'].$valuePrice."</label><br />\n";
								break;
						}
						
						$i++;
						$domId++;
					}
					
					// create foot of option menu/checkbox/radiobutton
					switch ($arrOptionDetails['type']) {
						case '0':
							$selectValues .= "</select><br />\n";
							break;
							
						case '1':
							$selectValues .= "<br />";
							break;
							
						case '2':
							$selectValues .= "<br />";
							break;
					}
					
					
					// initialize variables	
					$this->_objTpl->setVariable(array(
						'SHOP_PRODCUT_OPTION'				=> $selectValues,
						'SHOP_PRODUCT_OPTIONS_NAME'	        => $arrOptionDetails['name'],
						'SHOP_PRODUCT_OPTIONS_TITLE'	    => "<a href=\"javascript:{}\" onclick=\"toggleOptions($product_Id)\">".$_ARRAYLANG['TXT_OPTIONS']."</a>\n",
					));
					
					$this->_objTpl->parse('shopProductOptionsValuesRow');
					//end products options values block
				}
				$this->_objTpl->parse('shopProductOptionsRow');
			}
    	}
    	return strlen($checkOptionIds)>0 ? "return checkProductOption('shopProductForm{$formName}', $product_Id, '".substr($checkOptionIds,0,strlen($checkOptionIds)-1)."');" : "";
    }

    
    
    function discounts()
    {	
    	global $objDatabase, $_ARRAYLANG, $themesPages;
    	
        ////////////////////////////////////////////
        // Add-on: Shop Headlines in startpage
        ////////////////////////////////////////////
		// $this->_objTpl->setVariable(getShopNews());
		////////////////////////////////////////////	    	  	
    	
	    $q = "SELECT *
		        FROM ".DBPREFIX."module_shop_products   
		       WHERE is_special_offer = 1
	             AND status = 1
	        ORDER BY sort_order"; 
	               	    
		if (!($objResult = $objDatabase->SelectLimit($q, 4))) { 
		    $this->errorHandling();
			return false;
		}
		$count = $objResult->RecordCount();															    									   	       	
        $i = 1;            
        
		while (!$objResult->EOF) {
			$fileArr = explode (".", $objResult->fields['picture']);
			$file = $fileArr[0].$this->thumbnailNameSuffix.".".$fileArr[1];		    		    
			$arrThumbnailPath[$i] = $this->shopImageWebPath.$file;
			
			// no product picture available
			if (empty($fileArr[0])) {	    		    
				$arrThumbnailPath[$i] = $this->shopImageWebPath."no_picture.gif";					
			} else {
				$arrThumbnailPath[$i] = $this->shopImageWebPath.$file;					
			}		

			$price = $this->_getProductPrice($objResult->fields['normalprice'], $objResult->fields['resellerprice']);
				
			if ($objResult->fields['discountprice']== "0.00"){
				$arrPrice[$i] = $price;			
			    $arrDiscountPrice[$i] = "";
			} else {			
				$arrPrice[$i] = "<s>".$price."</s>";
				$arrDiscountPrice[$i] = $this->objCurrency->getCurrencyPrice($objResult->fields['discountprice']);											
			}	
			$arrDetailLink[$i] = "?section=shop&amp;cmd=details&amp;productId=".$objResult->fields['id'];
			$arrTitle[$i] = $objResult->fields['title'];			
			$i++;
			$objResult->MoveNext();
		}
		
		$this->_objTpl->setGlobalVariable(array(
			'TXT_PRICE_NOW' => $_ARRAYLANG['TXT_PRICE_NOW'],
			'TXT_INSTEAD_OF' => $_ARRAYLANG['TXT_INSTEAD_OF']
			));		
		
		for ($i=1;$i<=$count;$i=$i+2){	
				if (!empty($arrTitle[$i+1])){
					$this->_objTpl->setCurrentBlock("shopProductRow2");
					$this->_objTpl->setVariable(array(
						'SHOP_PRODUCT_TITLE' 		         => $arrTitle[$i+1],
						'SHOP_PRODUCT_THUMBNAIL'            => $arrThumbnailPath[$i+1],
						'SHOP_PRODUCT_PRICE'     		     => $arrPrice[$i+1],
						'SHOP_PRODUCT_DISCOUNTPRICE'	     => $arrDiscountPrice[$i+1],
						'SHOP_PRODUCT_PRICE1_2'     	     => $arrPrice_2[$i+1],
						'SHOP_PRODUCT_DISCOUNTPRICE1_2'	     => $arrDiscountPrice_2[$i+1],
						'SHOP_PRODUCT_PRICE_UNIT'     		 => $this->aCurrencyUnitName,
						'SHOP_PRODUCT_DISCOUNTPRICE_UNIT'	 => $this->aCurrencyUnitName,										
						'SHOP_PRODUCT_DETAILLINK'		     => $arrDetailLink[$i+1],
						));
					$this->_objTpl->parse("shopProductRow2");
				}	
				$this->_objTpl->setCurrentBlock("shopProductRow1");	
				$this->_objTpl->setVariable(array(
					'SHOP_PRODUCT_TITLE' 		         => $arrTitle[$i],
					'SHOP_PRODUCT_THUMBNAIL'            => $arrThumbnailPath[$i],
					'SHOP_PRODUCT_PRICE'     		     => $arrPrice[$i],
					'SHOP_PRODUCT_DISCOUNTPRICE'	     => $arrDiscountPrice[$i],
					'SHOP_PRODUCT_PRICE1_2'     	     => $arrPrice_2[$i],
					'SHOP_PRODUCT_DISCOUNTPRICE1_2'	     => $arrDiscountPrice_2[$i],			
					'SHOP_PRODUCT_PRICE_UNIT'     		 => $this->aCurrencyUnitName,
					'SHOP_PRODUCT_DISCOUNTPRICE_UNIT'	 => $this->aCurrencyUnitName,										
					'SHOP_PRODUCT_DETAILLINK'		     => $arrDetailLink[$i],
					));
				$this->_objTpl->parse("shopProductRow1");
		}					
    }    	
   
    
  
    
    function showCartInfo()
    {
		global $_ARRAYLANG;
		$cartInfo = "";
		
		if (isset($_SESSION['shop'])){			
			$cartInfo = $_ARRAYLANG['TXT_EMPTY_SHOPPING_CART'];
			if ($this->calculateItems($_SESSION['shop']['cart'])>0){
				$cartInfo = $_ARRAYLANG['TXT_SHOPPING_CART']." ".$this->calculateItems($_SESSION['shop']['cart']).
				            " ".$_ARRAYLANG['TXT_SHOPPING_CART_VALUE']." ".$this->_calculatePrice($_SESSION['shop']['cart']).
				            " ".$this->aCurrencyUnitName;
			    $cartInfo = "<a href=\"?section=shop&amp;cmd=cart\">$cartInfo</a>";  
			} 
		}
		return $cartInfo;  
    } 

    
    
    
 
    function destroyCart()
    {
		if ($_SESSION['shop']){
            unset($_SESSION['shop']);                                             
		}
    }          
    
    
    
    
    
    function _calculatePrice($cart)
    {
		global $objDatabase;
		$price = 0.00;
		if (is_array($cart['products'])) {
			foreach ($cart['products'] as $arrProduct) {
				$objResult = $objDatabase->SelectLimit("SELECT normalprice,
				                   resellerprice,
				                   discountprice,
				                   is_special_offer
				              FROM ".DBPREFIX."module_shop_products   
				             WHERE id = ".$arrProduct['id'], 1);
				if ($objResult !== false && $objResult->RecordCount() == 1) {
					$item_price = $this->_getProductPrice($objResult->fields['normalprice'], $objResult->fields['resellerprice'],$objResult->fields['discountprice'],$objResult->fields['is_special_offer']);
					$optionsPrice = $arrProduct['optionPrice'];
					$price +=($item_price+$optionsPrice)*$arrProduct['quantity'];
				}
			}
		}
		return $this->objCurrency->formatPrice($price);
    }

    

    
    function _getProductPrice($normalPrice, 
                             $resellerPrice="0.00",
                             $discountPrice="0.00",
                             $is_special_offer=0)
    {		
		
    	if ($is_special_offer==1 AND $discountPrice!="0.00") {
    		$price = $discountPrice;
    	}
    	else {
	    	if ($this->is_reseller==1 AND $resellerPrice!="0.00"){				
	            $price = $resellerPrice;
			} else {
			    $price = $normalPrice;        	
			}
    	}				
		return $this->objCurrency->getCurrencyPrice($price);   	
    }   
    
       
    
    

          
    function _calculateShipmentPrice($shipmentId, $totalPrice)
    {
    	$shipmentPrice = 0;
    	if ($this->objShipment->arrActiveShipmentMethods[$shipmentId]['costs_free_sum'] == 0 || $totalPrice < $this->objShipment->arrActiveShipmentMethods[$shipmentId]['costs_free_sum']) {
			$shipmentPrice = $this->objShipment->arrActiveShipmentMethods[$shipmentId]['costs'];
    	}
	    return $this->objCurrency->getCurrencyPrice($shipmentPrice);	
    }    
    
    
    
    
    function _calculatePaymentPrice($paymentId, $totalPrice)
    {
    	$paymentPrice = 0;
    	if ($this->objPayment->arrPaymentObject[$paymentId]['costs_free_sum'] == 0 || $totalPrice < $this->objPayment->arrPaymentObject[$paymentId]['costs_free_sum']) {
			$paymentPrice = $this->objPayment->arrPaymentObject[$paymentId]['costs'];
    	}
	    return $this->objCurrency->getCurrencyPrice($paymentPrice);	
    }     

    
    
    function calculateItems($cart)
    {
		$items = 0;
		if (is_array($cart['products'])) {
			foreach ($cart['products'] as $arrProduct) {
				$items += $arrProduct['quantity'];
			}
		}
		return $items;	
    }
    
   
    
    function getJavascriptCode()
    {
    	global $_ARRAYLANG;
    	$javascriptCode = "
					<script language=\"JavaScript\" type=\"text/javascript\">
					<!-- //
					function viewPicture(picture,features){
					    window.open(picture,'',features);
					}
    	
    				function toggleOptions(productId) {
    					if (document.getElementById('product_options_layer'+productId)) {
		    				if (document.getElementById('product_options_layer'+productId).style.display == 'none') {
		    					document.getElementById('product_options_layer'+productId).style.display = 'block';
		    				} else {
		    					document.getElementById('product_options_layer'+productId).style.display = 'none';
		    				}
		    			}
    				}
    	
    				function checkProductOption(objForm, productId, strProductOptionIds) {
    					arrOptionIds = strProductOptionIds.split(\";\");
    					var status = true;
    					var arrFailOptions = new Array();
    					var optionName = '';
    					var formEl = '';
    					var elId = '';
    					var elType = '';
    	
    					// check each option
    					for (i = 0; i < arrOptionIds.length; i++) {
    						checkStatus = false;

    						// get options from form
    						for (el = 0; el < document.forms[objForm].elements.length; el++) {
    							// check if the element has a id attribute
    							var formEl = document.forms[objForm].elements[el];
    							if (formEl.getAttribute('id')) {
    								// check if the element belongs to the option
    								var searchName = 'productOption-'+productId+'-'+arrOptionIds[i];
    								var elId = formEl.getAttribute('id');
    								if (elId.substr(0,searchName.length) == searchName) {
    									// check if the element has a type attribute
    									if (formEl.type) {
    										var elType = formEl.type;
    										switch (elType) {
    											case 'radio':
    												if (formEl.checked == true) {
    													checkStatus = true;
    												}
    												break;
    					
    											case 'hidden':
													optionName = formEl.value;
    												break;
    										}
    	
    									}
    								}
    							}
    						} // end for
    	    				if (checkStatus == false && elType == 'radio') {
    							status = false;
    							arrFailOptions.push(optionName);
    						}
    					} // end for
    					if (status == false) {
    						msg = \"{$_ARRAYLANG['TXT_MAKE_DECISION_FOR_OPTIONS']}:\\n\";
    						for (i = 0;i < arrFailOptions.length;i++) {
    							msg += \"- \"+arrFailOptions[i]+\"\\n\";
    						}
    						document.getElementById('product_options_layer'+productId).style.display = 'block';
    						alert(msg);
    					}
    					return status;
    				}
					// -->
					</script>";
    	return  $javascriptCode;
    }  
    
    
    
    
    function errorHandling()
    {
    	global $_ARRAYLANG;
        $this->statusMessage.= $_ARRAYLANG['TXT_DATABASE_QUERY_ERROR']."<br />";
    }

    
    
    
    
	/*
	* Get dropdown menue
	*
	* Gets back a dropdown menu like  <option value='catid'>Catname</option>
    *
    * @param    integer  $selectedid
    * @return   string   $result
    */
	function getCatMenu($selectedid=0)
	{
		 $result = $this->doShopCatMenu($parcat=0, 0,$selectedid);
		 return $result;
	}
	

	
	
	
	/*
	* Do shop categories menu
	*
    * @param    integer  $parcat
    * @param    integer  $level
    * @param    integer  $selectedid
    * @return   string   $result
    */
	function doShopCatMenu($parcat=0,$level,$selectedid)
	{						
		$result=""; 
		$list=$this->arrCategoriesTable[$parcat];   								
		 if (is_array($list)){
				while (list($key,$val)=each($list)){
					  $output ="";
					  $selected ="";
					  if ($level!=0){
							$count= $level*3;
							for ($i = 1; $i <= $count; $i++) {
								$output .="&nbsp;";
							}
					  }
					  if ($selectedid==$key){
                          $selected= "selected='selected'";
					  }
					  $result.= "<option value='$key' $selected>$output$val</option>\n";				  				  
		              if (isset($this->arrCategoriesTable[$key])){
							$result.= $this->doShopCatMenu($key,$level+1,$selectedid);
					  }
				}
		 }
		 return $result;
	} 


		
	
	/**
	* Function protectShop
	* 
	* @global    object     $objDatabase
	* @return    boolean    result
	* @access private                                                                              
	*/		
	function _authenticate() 
	{					
	    global $objDatabase, $sessionObj;			    		  	    	
	    if (isset($_SESSION['shop']['username']) && isset($_SESSION['shop']['password'])){
			$username = mysql_escape_string($_SESSION['shop']['username']);	
			$password = md5(mysql_escape_string($_SESSION['shop']['password']));
			 
			$query = "SELECT password, 
			                       username,
			                       email, 
			                       customerid,
			                       prefix,
			                       company,
			                       lastname,
			                       is_reseller  
				              FROM ".DBPREFIX."module_shop_customers
				             WHERE username = '$username' 
			                   AND password='$password'";
			 	
			if ($objResult = $objDatabase->Execute($query)) {
				if (!$objResult->EOF) {
					$this->is_reseller = $objResult->fields['is_reseller'];
					$this->is_auth = 1;
				    $this->customerId= $objResult->fields['customerid'];
				    $this->customerUsername= $objResult->fields['username'];
				    $this->customerPrefix= $objResult->fields['prefix'];
				    $this->customerCompany= $objResult->fields['company'];
				    $this->customerLastname= $objResult->fields['lastname'];
				    $_SESSION['shop']['email'] = $objResult->fields['email'];
				    $sessionObj->cmsSessionUserUpdate($username=$objResult->fields['username']);
					return true;
				}
			}
		}
		$sessionObj->cmsSessionUserUpdate($username="unknown");	
		$sessionObj->cmsSessionStatusUpdate($status="shop");
	    return false;
	}


	
   

    function cart()
    {	
    	global $objDatabase, $_ARRAYLANG, $objDatabase;
    	
    	// hide currency navbar
    	// $this->_hideCurrencyNavbar=true;
    	   	
	    $this->_objTpl->setVariable(array(
	        'TXT_PRODUCT_ID' => $_ARRAYLANG['TXT_PRODUCT_ID'],
	        'TXT_PRODUCT' => $_ARRAYLANG['TXT_PRODUCT'],
	        'TXT_UNIT_PRICE' => $_ARRAYLANG['TXT_UNIT_PRICE'],
	        'TXT_QUANTITY' => $_ARRAYLANG['TXT_QUANTITY'],
	        'TXT_TOTAL' => $_ARRAYLANG['TXT_TOTAL'],
	        'TXT_INTER_TOTAL' => $_ARRAYLANG['TXT_INTER_TOTAL'],	
	        'TXT_SHIP_COUNTRY' => $_ARRAYLANG['TXT_SHIP_COUNTRY'],
	        'TXT_UPDATE' => $_ARRAYLANG['TXT_UPDATE'],
	        'TXT_NEXT' => $_ARRAYLANG['TXT_NEXT'],
	        'TXT_EMPTY_CART' => $_ARRAYLANG['TXT_EMPTY_CART'],
	        'TXT_CONTINUE_SHOPPING' => $_ARRAYLANG['TXT_CONTINUE_SHOPPING']    
		));    	

		if (!isset($_SESSION['shop']['cart'])){
			$_SESSION['shop']['cart']['products'] = array();
			$_SESSION['shop']['cart']['items'] = 1;
			$_SESSION['shop']['cart']['total_price'] = "0.00";
		}
	    
		// Add new product to cart
    	if (isset($_REQUEST['productId'])) {
			$productId = intval($_REQUEST['productId']);
			
			if (isset($_REQUEST['updateProduct']) && is_array($_REQUEST['updateProduct'])) {
				$keys = array_keys($_REQUEST['updateProduct']);
				$oldCartProdId = $keys[0];
			}
			
			$isNewProduct = true;
			if (count($_SESSION['shop']['cart']['products'])>0) {
				foreach ($_SESSION['shop']['cart']['products'] as $cartProdId => $arrProduct) {
					// check if the same product is already in the cart
					if ($arrProduct['id'] == $productId && (!isset($oldCartProdId) || $oldCartProdId != $cartProdId)) {
						if (isset($_POST['productOption']) && count($_POST['productOption']>0)) {
							$arrCartProductOptions = array_keys($arrProduct['options']);
							$arrProductOptions = array_keys($_POST['productOption']);
							
							// check for the same options
							if ($arrCartProductOptions == $arrProductOptions) {
								// check for the same option values
								foreach ($_POST['productOption'] as $optionId => $valueId) {
									if (is_array($arrProduct['options'][$optionId])) {
										$arrPostValues = array();
										if (is_array($valueId)) {
											$arrPostValues = array_values($valueId);
										} else {
											if ($valueId != 0) {
												array_push($arrPostValues, $valueId);
											}
										}
										
										if ($arrPostValues != $arrProduct['options'][$optionId]) {
											continue 2;
										}
									} else {
										if (!isset($arrProduct['options'][$optionId][$valueId])) {
											continue 2;
										}
									}
								}
								$isNewProduct = false;
								break;
							}
						} else {
							$isNewProduct = false;
							break;
						}
					}
				}
			}
			
			if ($isNewProduct) {
				if (isset($oldCartProdId)) {
					$cartProdId = $oldCartProdId;
				} else {
					$arrProduct = array('id' => $productId, 'quantity' => 1);
					array_push($_SESSION['shop']['cart']['products'], $arrProduct);
					$arrKeys = array_keys($_SESSION['shop']['cart']['products']);
					$cartProdId = $arrKeys[count($arrKeys)-1];
				}
			} else {
				if (isset($oldCartProdId)) {
					if ($oldCartProdId != $cartProdId) {
						$_SESSION['shop']['cart']['products'][$cartProdId]['quantity'] += $_SESSION['shop']['cart']['products'][$oldCartProdId]['quantity'];
						unset($_SESSION['shop']['cart']['products'][$oldCartProdId]);
					}
				} else {
					$_SESSION['shop']['cart']['products'][$cartProdId]['quantity']++;
				}
			}
			
			//options array
			$_SESSION['shop']['cart']['products'][$cartProdId]['options'] = array();
			if (isset($_POST['productOption']) && count($_POST['productOption'])>0) {
				foreach ($_POST['productOption'] as $optionId => $valueId) {
					if (!isset($_SESSION['shop']['cart']['products'][$cartProdId]['options'][$optionId])) {
						$_SESSION['shop']['cart']['products'][$cartProdId]['options'][$optionId] = array();
					}
					
					if (is_array($valueId) && count($valueId) != 0) {
						foreach ($valueId as $id) {
							array_push($_SESSION['shop']['cart']['products'][$cartProdId]['options'][$optionId], $id);
						}
					} elseif (!empty($valueId)) {
						array_push($_SESSION['shop']['cart']['products'][$cartProdId]['options'][$optionId], $valueId);
					}
				}
			}
    	}
			
			
		// check countries
		$_SESSION['shop']['countryId2'] = isset($_POST['countryId2']) ? intval($_POST['countryId2']) : $this->arrConfig['country_id']['value'];		
			
		// Update quantity to cart
		if (isset($_POST['update']) || isset($_POST['continue'])) {
		    if (is_array($_SESSION['shop']['cart']['products']) && !empty($_SESSION['shop']['cart']['products'])){
				foreach ($_SESSION['shop']['cart']['products'] as $cartProdId => $arrProduct ){
					// Remove Products
					if ($_REQUEST['quantity'][$cartProdId] == 0 && empty($_REQUEST['quantity'][$cartProdId])) {
						unset($_SESSION['shop']['cart']['products'][$cartProdId]);
					} else {
						$_SESSION['shop']['cart']['products'][$cartProdId]['quantity'] = intval($_REQUEST['quantity'][$cartProdId]);
					}
				}
		    }
        }

		// go to the next step
		if (isset($_POST['continue']))  {
		    header ("Location: ?section=shop&cmd=login");  	    
        }
		
		if (is_array($_SESSION['shop']['cart']['products']) && !empty($_SESSION['shop']['cart']['products'])) {
	    	foreach ($_SESSION['shop']['cart']['products'] as $cartProdId => $arrProduct) {
				$objResult = $objDatabase->SelectLimit("SELECT title,
				                   catid,
				                   normalprice,
				                   resellerprice,
				                   discountprice,
				                   is_special_offer
				              FROM ".DBPREFIX."module_shop_products
				             WHERE status = 1 
				               AND id = ".$arrProduct['id'], 1);
				
		        if ($objResult !== false && $objResult->RecordCount()==1) {
					$productOptions = '';
					$productOptionsPrice = 0;
					
			        //get option names
			        foreach ($_SESSION['shop']['cart']['products'][$cartProdId]['options'] as $optionId => $arrValueIds) {
			        	foreach ($arrValueIds as $valueId) {
			        		$productOptions .= '['.$this->arrProductAttributes[$arrProduct['id']][$optionId]['values'][$valueId]['value'].'] ';
			        		$productOptionsPrice += $this->arrProductAttributes[$arrProduct['id']][$optionId]['values'][$valueId]['price_prefix'] == "+" ? $this->arrProductAttributes[$arrProduct['id']][$optionId]['values'][$valueId]['price'] : -$this->arrProductAttributes[$arrProduct['id']][$optionId]['values'][$valueId]['price'];
			        	}
			        }
					
			        if ($productOptionsPrice != 0) {
						$_SESSION['shop']['cart']['products'][$cartProdId]['optionPrice'] = $this->objCurrency->getCurrencyPrice($productOptionsPrice);
						$priceOptions = $this->objCurrency->getCurrencyPrice($productOptionsPrice);
			        } else {
			        	$priceOptions = 0;
			        }
					
					$price = $this->_getProductPrice($objResult->fields['normalprice'], $objResult->fields['resellerprice'],$objResult->fields['discountprice'], $objResult->fields['is_special_offer']);
					$quantity = $_SESSION['shop']['cart']['products'][$cartProdId]['quantity'];
					
			        $this->_objTpl->setVariable(array(
				        'SHOP_PRODUCT_ID' 		        => $arrProduct['id'],
				        'SHOP_PRODUCT_CART_ID' 		    => $cartProdId,
				        'SHOP_PRODUCT_TITLE' 		    => $objResult->fields['title'].'<br />',
				        'SHOP_PRODUCT_OPTIONS'          => $productOptions,
				        'SHOP_PRODUCT_PRICE'     	    => $this->objCurrency->formatPrice(($price+$priceOptions)*$quantity),
				        'SHOP_PRODUCT_PRICE_UNIT'  	    => $this->aCurrencyUnitName,			        		        		        
				        'SHOP_PRODUCT_QUANTITY'         => $quantity,       		        
				        'SHOP_PRODUCT_ITEMPRICE'        => $this->objCurrency->formatPrice($price+$priceOptions),
				        'SHOP_PRODUCT_ITEMPRICE_UNIT'   => $this->aCurrencyUnitName,					        		        
				        ));
				    $this->_objTpl->parse("shopCartRow");
		        }
			}
	    } else {
			    $this->_objTpl->hideBlock("shopCart");   			       	
	    } 

	    $_SESSION['shop']['cart']['total_price'] = $this->_calculatePrice($_SESSION['shop']['cart']);
        $_SESSION['shop']['cart']['items'] = $this->calculateItems($_SESSION['shop']['cart']);							
		
	    $this->_objTpl->setVariable(array(
	        'SHOP_PRODUCT_TOTALITEM'           => $_SESSION['shop']['cart']['items'],
	        'SHOP_PRODUCT_TOTALPRICE'          => $_SESSION['shop']['cart']['total_price'],
	        'SHOP_PRODUCT_TOTALPRICE_UNIT'     => $this->aCurrencyUnitName, 
	        'SHOP_COUNTRIES_MENU'              => $this->_getCountriesMenu($menuName="countryId2", 
	                                                                       $selectedId=$_SESSION['shop']['countryId2'],
	                                                                       $onchange="document.forms['shopForm'].submit()"
	                                                                       ),	 	               
		));
    }  
    
    
    
    
    function login()
    {	
    	global $objDatabase, $_ARRAYLANG;     	   	
    	
		if ($this->is_auth==1){
			// redirect to the checkout page
			header ("Location: ?section=shop&cmd=account");			
		} else {
			$statusMessage = "";
			$loginUsername = "";	

			if (!empty($_REQUEST['username']) AND !empty($_REQUEST['password'])){
				// check authentification
				$_SESSION['shop']['username']= htmlspecialchars(addslashes(strip_tags($_REQUEST['username'])));
				$_SESSION['shop']['password']=addslashes(strip_tags($_REQUEST['password']));
				$loginUsername = $_SESSION['shop']['username'];										
				if ($this->_authenticate()) {
					if ($_REQUEST['redirect']=="shop"){
						header ("Location: ?section=shop");
					} else {
						header ("Location: ?section=shop&cmd=account");
					}
				} else {
                    $statusMessage = $ARRAYLANG['txtNoValidCustomerAccount'];
				}				
			}				

	    	$this->_objTpl->setVariable(array(   	   	
						'SHOP_LOGIN_EMAIL' => $loginUsername,
						'SHOP_LOGIN_ACTION'	=> "?section=shop&amp;cmd=login",
						'SHOP_LOGIN_STATUS'	=> $statusMessage,							
	    	    ));  					    
		}		   	
    }     


    
    
    
    
    function account()
    {	
    	global $objDatabase, $shopObj, $_ARRAYLANG;
    	
    	// hide currency navbar
    	$this->_hideCurrencyNavbar=true;
    	
    	// initialise variables
    	$status = "";
        
    	// check the submission
    	if ( empty($_POST['prefix']) OR
    	    empty($_POST['lastname']) OR 
    	    empty($_POST['firstname']) OR 
    	    empty($_POST['address']) OR 
    	    empty($_POST['zip']) OR 
    	    empty($_POST['city']) OR
    	    empty($_POST['phone']) OR 
    	    empty($_POST['prefix2']) OR
    	    empty($_POST['lastname2']) OR 
    	    empty($_POST['firstname2']) OR 
    	    empty($_POST['address2']) OR 
    	    empty($_POST['zip2']) OR 
    	    empty($_POST['city2']) OR
    	    empty($_POST['phone2']) OR 
    	    (empty($_POST['email']) AND $this->is_auth == 0) OR     	    
    	    (empty($_POST['password']) AND $this->is_auth == 0)   	    
          ) {
        	$status = $_ARRAYLANG['TXT_FILL_OUT_ALL_REQUIRED_FIELDS'];
        }
        
        if (!empty($_POST['password']) AND $this->is_auth == 0){	       	       	
        	if (strlen(trim($_POST['password']))<6){
        	    $status .= "<br />".$_ARRAYLANG['TXT_INVALID_PASSWORD'];   		
	    	}
        }
        
        if (!empty($_POST['email']) AND $shopObj->is_auth == 0){	       	       	
        	if (!$this->shopCheckEmail($_POST['email'])){
        		$status .= "<br />".$_ARRAYLANG['TXT_INVALID_EMAIL_ADDRESS'];
        	}
        	if (!$this->_checkEmailIntegrity($_POST['email'])) {
        		$status .= (empty($status) ? "" : "<br />").$_ARRAYLANG['TXT_EMAIL_USED_BY_OTHER_CUSTOMER'];
        	}
        }    
              	
    	if (empty($status)){  
			foreach($_POST as $key => $value){
				$value = get_magic_quotes_gpc() ? strip_tags(trim($value)) : addslashes(strip_tags(trim($value)));
				$_SESSION['shop'][$key]=htmlspecialchars($value);
			}
			header("Location: ?section=shop&cmd=payment");
    	}
    	else 
    	{
			if (isset($_POST) AND is_array($_POST)){
				foreach($_POST as $key => $value) {
					$value = get_magic_quotes_gpc() ? strip_tags(trim($value)) : addslashes(strip_tags(trim($value)));
					$_SESSION['shop'][$key]=htmlspecialchars($value);
				}				 
				
				if (isset($_POST['equalAddress'])){
				    $_SESSION['shop']['equalAddress']= "checked='checked'";
				} else {
					if (!isset($_SESSION['shop']['equalAddress'])) {
						$_SESSION['shop']['equalAddress']= "";
					}
				}

                if (isset($_POST['countryId'])) {
                    $_SESSION['shop']['countryId']=intval($_POST['countryId']);
                } else {
					if (!isset($_SESSION['shop']['countryId'])) {
						$_SESSION['shop']['countryId']=$_SESSION['shop']['countryId2'];	
					}
                }				
			}
    	} 
    	
        // customer already logged in
		if ($this->is_auth==1) {		
			$query = "SELECT * FROM ".DBPREFIX."module_shop_customers 
			                WHERE customerid=$this->customerId";
			
			$objResult = $objDatabase->SelectLimit($query, 1);
			
	    	$this->_objTpl->setVariable(array(   	   	
						'SHOP_ACCOUNT_COMPANY'		=> $objResult->fields['company'],
						'SHOP_ACCOUNT_PREFIX'		=> $objResult->fields['prefix'],
						'SHOP_ACCOUNT_LASTNAME'		=> $objResult->fields['lastname'],
						'SHOP_ACCOUNT_FIRSTNAME'	=> $objResult->fields['firstname'],
						'SHOP_ACCOUNT_ADDRESS'		=> $objResult->fields['address'],
						'SHOP_ACCOUNT_ZIP'			=> $objResult->fields['zip'],
						'SHOP_ACCOUNT_CITY'			=> $objResult->fields['city'],
						'SHOP_ACCOUNT_COUNTRY'		=> $objResult->fields['country'],
						//'SHOP_ACCOUNT_EMAIL'		=> $objResult->fields['email'],
						'SHOP_ACCOUNT_PHONE'		=> $objResult->fields['phone'],									
						'SHOP_ACCOUNT_FAX'			=> $objResult->fields['fax'],
						'SHOP_ACCOUNT_ACTION'       => "?section=shop&amp;cmd=payment",				
	    	    )); 					
	    	   $this->_objTpl->hideBlock('account_details');
		} 
		else {              
	    	$this->_objTpl->setVariable(array(   	   	
						'SHOP_ACCOUNT_COMPANY'		=> stripslashes($_SESSION['shop']['company']),
						'SHOP_ACCOUNT_PREFIX'		=> stripslashes($_SESSION['shop']['prefix']),
						'SHOP_ACCOUNT_LASTNAME'		=> stripslashes($_SESSION['shop']['lastname']),
						'SHOP_ACCOUNT_FIRSTNAME'	=> stripslashes($_SESSION['shop']['firstname']),
						'SHOP_ACCOUNT_ADDRESS'		=> stripslashes($_SESSION['shop']['address']),
						'SHOP_ACCOUNT_ZIP'			=> stripslashes($_SESSION['shop']['zip']),
						'SHOP_ACCOUNT_CITY'			=> stripslashes($_SESSION['shop']['city']),
						'SHOP_ACCOUNT_COUNTRY'		=> $this->_getCountriesMenu($menuName="countryId", $_SESSION['shop']['countryId'] ),
						'SHOP_ACCOUNT_EMAIL'		=> stripslashes($_SESSION['shop']['email']),
						'SHOP_ACCOUNT_PHONE'		=> stripslashes($_SESSION['shop']['phone']),									
						'SHOP_ACCOUNT_FAX'			=> stripslashes($_SESSION['shop']['fax']),
						'SHOP_ACCOUNT_EQUAL_ADDRESS' => $_SESSION['shop']['equalAddress'] 			
	    	    )); 
		}
    	$this->_objTpl->setVariable(array(   	   	
					'SHOP_ACCOUNT_COMPANY2'		=> stripslashes($_SESSION['shop']['company2']),
					'SHOP_ACCOUNT_PREFIX2'		=> stripslashes($_SESSION['shop']['prefix2']),
					'SHOP_ACCOUNT_LASTNAME2'	=> stripslashes($_SESSION['shop']['lastname2']),
					'SHOP_ACCOUNT_FIRSTNAME2'	=> stripslashes($_SESSION['shop']['firstname2']),
					'SHOP_ACCOUNT_ADDRESS2'		=> stripslashes($_SESSION['shop']['address2']),
					'SHOP_ACCOUNT_ZIP2'			=> stripslashes($_SESSION['shop']['zip2']),
					'SHOP_ACCOUNT_CITY2'		=> stripslashes($_SESSION['shop']['city2']),
					'SHOP_ACCOUNT_COUNTRY2'		=> $this->arrCountries[$_SESSION['shop']['countryId2']]['countries_name'],						
					'SHOP_ACCOUNT_PHONE2'		=> stripslashes($_SESSION['shop']['phone2']),
					'SHOP_ACCOUNT_EQUAL_ADDRESS'=> $_SESSION['shop']['equalAddress'],
					'SHOP_ACCOUNT_ACTION'       => "?section=shop&amp;cmd=account",			
    	    )); 
    	    
    	$this->_objTpl->setVariable(array(   	   	
					'TXT_CUSTOMER_ADDRESS'		=> $_ARRAYLANG['TXT_CUSTOMER_ADDRESS'],
					'TXT_SHIPPING_ADDRESS'		=> $_ARRAYLANG['TXT_SHIPPING_ADDRESS'],
					'TXT_REQUIRED_FIELDS'		=> $_ARRAYLANG['TXT_REQUIRED_FIELDS'],					
					'TXT_SAME_BILLING_ADDRESS'		=> $_ARRAYLANG['TXT_SAME_BILLING_ADDRESS'],					
					'TXT_COMPANY' => $_ARRAYLANG['TXT_COMPANY'],					
					'TXT_GREETING' => $_ARRAYLANG['TXT_GREETING'],							
					'TXT_SURNAME' => $_ARRAYLANG['TXT_SURNAME'],
					'TXT_FIRSTNAME'	=> $_ARRAYLANG['TXT_FIRSTNAME'],
					'TXT_ADDRESS'=> $_ARRAYLANG['TXT_ADDRESS'],
					'TXT_POSTALE_CODE'	=> $_ARRAYLANG['TXT_POSTALE_CODE'],					
					'TXT_CITY'	=> $_ARRAYLANG['TXT_CITY'],					
					'TXT_COUNTRY'=> $_ARRAYLANG['TXT_COUNTRY'],
					'TXT_PASSWORD' => $_ARRAYLANG['TXT_PASSWORD'],
					'TXT_EMAIL' => $_ARRAYLANG['TXT_EMAIL'],
					'TXT_YOUR_ACCOUNT_DETAILS' => $_ARRAYLANG['TXT_YOUR_ACCOUNT_DETAILS'],					
					'TXT_PASSWORD_MIN_CHARS' => $_ARRAYLANG['TXT_PASSWORD_MIN_CHARS'],
					'TXT_NEXT' => $_ARRAYLANG['TXT_NEXT'],
					'TXT_RESET' => $_ARRAYLANG['TXT_RESET'],
					'TXT_PHONE_NUMBER' => $_ARRAYLANG['TXT_PHONE_NUMBER'],
					'TXT_FAX_NUMBER' => $_ARRAYLANG['TXT_FAX_NUMBER']					 					
					));     	   	    
    	    
	    $this->_objTpl->setVariable("SHOP_ACCOUNT_STATUS",$status);		    
    }  
    


    

    
     
    
    function payment()
    {		 	
     	global $objDatabse, $_ARRAYLANG;

     	// Reloading or loading without sessions   	
    	if (!isset($_SESSION['shop']['cart'])) {
			header("Location: ?section=shop");
    	}      	
     	
    	// hide currency navbar
    	$this->_hideCurrencyNavbar=true;     	
     	
     	//initialize variables
     	$paymentStatus = ""; 
 	
    	$_SESSION['shop']['customer_note'] = isset($_POST['customer_note']) ? htmlspecialchars($_POST['customer_note']) : "";
    	$_SESSION['shop']['agb'] = isset($_POST['agb']) ? "checked='".intval($_POST['agb'])."'" : "";

    	
    	// get shipment stuff
    	$arrShipmentId = $this->objShipment->getCountriesRelatedShippingIdArray($_SESSION['shop']['countryId']);
    	if (isset($_SESSION['shop']['shipmentId'])) {
    	    $_SESSION['shop']['shipmentId'] = isset($_POST['shipmentId']) ? intval($_POST['shipmentId']) : $_SESSION['shop']['shipmentId'];
    	} else {
    		// get default shipment Id
    		$_SESSION['shop']['shipmentId'] = next($arrShipmentId);
    	}      
    	$shipmentMenu = $this->objShipment->getShipmentMenu($arrShipmentId, $_SESSION['shop']['shipmentId'], "document.forms['shopForm'].submit()");	


    	// get payment stuff
    	$arrPaymentId = $this->objPayment->getCountriesRelatedPaymentIdArray($_SESSION['shop']['countryId']);
    	if (isset($_SESSION['shop']['paymentId'])) {
    	    $_SESSION['shop']['paymentId'] = isset($_POST['paymentId']) ? intval($_POST['paymentId']) : $_SESSION['shop']['paymentId'];	 
    	} else {
    		// get default payment Id
    		$_SESSION['shop']['paymentId'] = next($arrPaymentId);
    	}      
    	$paymentMenu = $this->objPayment->getPaymentMenu($arrPaymentId, $_SESSION['shop']['paymentId'], "document.forms['shopForm'].submit()");	
    	// end payment
    	
    	$_SESSION['shop']['paymentId'] = isset($_POST['paymentId']) ? intval($_POST['paymentId']) : $_SESSION['shop']['paymentId'];
		$_SESSION['shop']['total_price'] = $this->_calculatePrice($_SESSION['shop']['cart']);
		$_SESSION['shop']['shipment_price'] = $this->_calculateShipmentPrice($_SESSION['shop']['shipmentId'], $_SESSION['shop']['total_price']);
    	$_SESSION['shop']['payment_price'] = $this->_calculatePaymentPrice($_SESSION['shop']['paymentId'], $_SESSION['shop']['total_price']);
        $_SESSION['shop']['items'] = $this->calculateItems($_SESSION['shop']['cart']);
		
        // are taxtes enabled?
    	if ($this->arrConfig['tax_number']['status'] ==1) {   		    		
    		// taxes are included
    		if ($this->arrConfig['tax_included']['value']==1) {			 
    			// taxes are necessary -> shop country
    			if ($_SESSION['shop']['countryId']==intval($this->arrConfig['country_id']['value'])){  			    
			        $_SESSION['shop']['grand_total_price']= $this->objCurrency->formatPrice($_SESSION['shop']['total_price'] +
			                                                                                $_SESSION['shop']['payment_price'] +
			                                                                                $_SESSION['shop']['shipment_price']); 		                                                                                
			                                                                                				    
    				$_SESSION['shop']['tax_price']= $this->calculateTax($_SESSION['shop']['grand_total_price']); 
					$_SESSION['shop']['tax_products_txt'] = $_ARRAYLANG['TXT_TAX_INCLUDED'];
					$_SESSION['shop']['tax_grand_txt'] = $_ARRAYLANG['TXT_TAX_INCLUDED'];
					$_SESSION['shop']['tax_procentual'] = $this->getPercentatedTax();    	    
    			}
    			// foreign country 
    			// subtraction of total price taxes 
    			else {
					$_SESSION['shop']['tax_products_txt'] = $_ARRAYLANG['TXT_TAX_INCLUDED'];
					$_SESSION['shop']['tax_grand_txt'] = $_ARRAYLANG['TXT_TAX_EXCLUDED'];
					$_SESSION['shop']['tax_procentual'] = $this->getPercentatedTax();	    				
				    $_SESSION['shop']['tax_price']= " -".$this->calculateTax($_SESSION['shop']['total_price']);				    
			        $_SESSION['shop']['grand_total_price']= $this->objCurrency->formatPrice($_SESSION['shop']['total_price'] +
			                                                                                $_SESSION['shop']['payment_price'] +
			                                                                                $_SESSION['shop']['shipment_price'] -
			                                                                                $_SESSION['shop']['tax_price']);		
    			}
    		} 
    		// taxes are excluded
    		else {    			
   			    // taxes are necessary -> shop country
    			if ($_SESSION['shop']['countryId']==intval($this->arrConfig['country_id']['value'])){  			    
					$_SESSION['shop']['tax_products_txt'] = $_ARRAYLANG['TXT_TAX_EXCLUDED'];
					$_SESSION['shop']['tax_grand_txt'] = $_ARRAYLANG['TXT_TAX_INCLUDED'];
					$_SESSION['shop']['tax_procentual'] = $this->getPercentatedTax();    				
    				
    				$_SESSION['shop']['tax_price']= $this->calculateTax($_SESSION['shop']['total_price'] +
				                                                        $_SESSION['shop']['payment_price'] +
				                                                        $_SESSION['shop']['shipment_price']);
				    				    
			        $_SESSION['shop']['grand_total_price']= $this->objCurrency->formatPrice($_SESSION['shop']['total_price'] +
			                                                                                $_SESSION['shop']['payment_price'] +
			                                                                                $_SESSION['shop']['shipment_price'] +
			                                                                                $_SESSION['shop']['tax_price']);
    			} else {			                                                                                
					$_SESSION['shop']['tax_products_txt'] = $_ARRAYLANG['TXT_TAX_EXCLUDED'];
					$_SESSION['shop']['tax_grand_txt'] = $_ARRAYLANG['TXT_TAX_EXCLUDED'];
					$_SESSION['shop']['tax_procentual'] = "0.00";
				    $_SESSION['shop']['tax_price']= "0.00";				    
			        $_SESSION['shop']['grand_total_price']= $this->objCurrency->formatPrice($_SESSION['shop']['total_price'] +
			                                                                                $_SESSION['shop']['payment_price'] +
			                                                                                $_SESSION['shop']['shipment_price']);								
    			} 		
    		}  		
    	} else {   		
		    $_SESSION['shop']['tax_price'] = "0.00";
			$_SESSION['shop']['tax_products_txt'] = "";
			$_SESSION['shop']['tax_grand_txt'] = "";
			$_SESSION['shop']['tax_procentual'] = "0.00";
			$_SESSION['shop']['grand_total_price']= $this->objCurrency->formatPrice($_SESSION['shop']['total_price'] +
			                                                                        $_SESSION['shop']['payment_price'] +
			                                                                        $_SESSION['shop']['shipment_price']);		
    	}
    	 
    	// Process
    	if (isset($_POST['check'])){  	   	
	    	if ( !empty($_POST['agb']) AND !empty($_POST['shipmentId']) AND !empty($_POST['paymentId']) ) {										
					header("Location: ?section=shop&cmd=confirm");
					exit;
	        } else {  
				$paymentStatus = $_ARRAYLANG['TXT_FILL_OUT_ALL_REQUIRED_FIELDS'];
	        	if (empty($_POST['agb'])) {
	        		$paymentStatus = $_ARRAYLANG['TXT_ACCEPT_AGB'];
	        	} 				
	        }
	    }   				
			
	    $this->_objTpl->setVariable(array(
	    	'SHOP_UNIT' => $this->aCurrencyUnitName,	
			'SHOP_TOTALITEM' => $_SESSION['shop']['items'],
			'SHOP_SHIPMENT_PRICE' => $_SESSION['shop']['shipment_price'],
			'SHOP_PAYMENT_PRICE' => $_SESSION['shop']['payment_price'],
			'SHOP_TOTALPRICE' => $_SESSION['shop']['total_price'],								
			'SHOP_SHIPMENT_MENU' => $shipmentMenu,
			'SHOP_PAYMENT_MENU' => $paymentMenu,											 			      	        
			'SHOP_GRAND_TOTAL' => $_SESSION['shop']['grand_total_price'], 	
			'SHOP_CUSTOMERNOTE' => $_SESSION['shop']['customer_note'],
			'SHOP_AGB' => $_SESSION['shop']['agb'],
			'SHOP_STATUS' => $paymentStatus,		
			'SHOP_TAX_PRICE' => $_SESSION['shop']['tax_price'],
			'SHOP_TAX_PRODUCTS_TXT' => $_SESSION['shop']['tax_products_txt'],
			'SHOP_TAX_GRAND_TXT' => $_SESSION['shop']['tax_grand_txt'],
			'SHOP_TAX_PROCENTUAL'=> $_SESSION['shop']['tax_procentual']		
		));	
		
	    $this->_objTpl->setVariable(array(
	    	'TXT_PRODUCTS' => $_ARRAYLANG['TXT_PRODUCTS'],	
	    	'TXT_TOTALLY_GOODS' => $_ARRAYLANG['TXT_TOTALLY_GOODS'],
	    	'TXT_PRODUCT_S' => $_ARRAYLANG['TXT_PRODUCT_S'],
	    	'TXT_SHIPPING_METHODS' => $_ARRAYLANG['TXT_SHIPPING_METHODS'],	    	
	    	'TXT_PAYMENT_TYPES' => $_ARRAYLANG['TXT_PAYMENT_TYPES'],	    	
	    	'TXT_TAX_PART' => $_ARRAYLANG['TXT_TAX_PART'],	
	    	'TXT_PROCENTUAL_TAX_PART' => $_ARRAYLANG['TXT_PROCENTUAL_TAX_PART'],	
	    	'TXT_ORDER_SUM' => $_ARRAYLANG['TXT_ORDER_SUM'],	
	    	'TXT_COMMENTS' => $_ARRAYLANG['TXT_COMMENTS'],	
	    	'TXT_TAC' => $_ARRAYLANG['TXT_TAC'],
	    	'TXT_ACCEPT_TAC' => $_ARRAYLANG['TXT_ACCEPT_TAC'],
	    	'TXT_UPDATE' => $_ARRAYLANG['TXT_UPDATE'],
	    	'TXT_NEXT' => $_ARRAYLANG['TXT_NEXT'],
	    	'TXT_TOTAL_PRICE' => $_ARRAYLANG['TXT_TOTAL_PRICE']    	    	
		));			
		
    } 

    

    
    
    
	/**
	* Generate the order overview
	*
	* Generate the complete overview of the order and generate the link to the payment offerer
	*
	* @access public
	* @see _getProductPrice(), objCurrency->formatPrice(), _getShipmentMethod(), _authenticate(), objCurrency->getActiveCurrencyParameter(), objLanguage->getLanguageParameter(), objSaferpay->payInit(), objYellowpay->getForm()
	*/
    function confirm()
    {		 	
     	global $objDatabase, $_ARRAYLANG, $shopObj, $objDatabase;
     	
    	if (!isset($_SESSION['shop']['cart'])){
			header("Location: ?section=shop");
			exit;
    	}
    	
    	// initalize variables
	    $statusMessage = "";
    	
    	// hide currency navbar
    	$this->_hideCurrencyNavbar=true;
    	
    	// Show payment processing page
    	if (isset($_POST['process'])) { 
    		$this->_objTpl->hideBlock("shopConfirm");	     
             
            // checks for page reloading
            if (!isset($_SESSION['shop']['orderid'])) {	    	    	
				// register the order	  		 
				$customer_ip = htmlspecialchars($_SERVER['REMOTE_ADDR']);		
				$customer_host = htmlspecialchars(@gethostbyaddr($_SERVER['REMOTE_ADDR']));
				$customer_lang = htmlspecialchars(getenv('HTTP_ACCEPT_LANGUAGE'));
				$customer_browser = htmlspecialchars(getenv('HTTP_USER_AGENT'));
				
				if ($this->is_auth == 1) {
					$customerid = $this->customerId;
					// update customer
					$query = "UPDATE ".DBPREFIX."module_shop_customers
											   SET company='".trim($_SESSION['shop']['company']," \t")."',
							                   prefix='".trim($_SESSION['shop']['prefix']," \t")."',
											   firstname='".trim($_SESSION['shop']['firstname']," \t")."',
											   lastname='".trim($_SESSION['shop']['lastname']," \t")."',
											   address='".trim($_SESSION['shop']['address']," \t")."',			
											   city='".trim($_SESSION['shop']['city']," \t")."',			
											   zip='".trim($_SESSION['shop']['zip']," \t")."',			
											   country_id='".intval($_SESSION['shop']['countryId'])."',
											   phone='".trim($_SESSION['shop']['phone']," \t")."',
							                   fax='".trim($_SESSION['shop']['fax']," \t")."',						
											   ccnumber='".trim($_SESSION['shop']['ccnumber']," \t")."',
											   ccdate='{$_SESSION['shop']['ccdate']}',
							                   ccname='".trim($_SESSION['shop']['ccname']," \t")."',
											   cvc_code='".trim($_SESSION['shop']['cvcCode']," \t")."'
										 WHERE customerid=".$customerid;
				} else {
					// Add to customer table
					$query = "INSERT INTO ".DBPREFIX."module_shop_customers 
							               SET username='".trim($_SESSION['shop']['email']," \t")."',
											   password='".md5($_SESSION['shop']['password'])."',
											   company='".trim($_SESSION['shop']['company']," \t")."',
							                   prefix='".trim($_SESSION['shop']['prefix']," \t")."',
											   firstname='".trim($_SESSION['shop']['firstname']," \t")."',
											   lastname='".trim($_SESSION['shop']['lastname']," \t")."',
											   address='".trim($_SESSION['shop']['address']," \t")."',			
											   city='".trim($_SESSION['shop']['city']," \t")."',			
											   zip='".trim($_SESSION['shop']['zip']," \t")."',			
											   country_id='".intval($_SESSION['shop']['countryId'])."',
											   phone='".trim($_SESSION['shop']['phone']," \t")."',
							                   fax='".trim($_SESSION['shop']['fax']," \t")."',						
											   email='".trim($_SESSION['shop']['email']," \t")."',									
											   ccnumber='".trim($_SESSION['shop']['ccnumber']," \t")."',
											   ccdate='{$_SESSION['shop']['ccdate']}',
							                   ccname='".trim($_SESSION['shop']['ccname']," \t")."',
											   cvc_code='".trim($_SESSION['shop']['cvcCode']," \t")."',
											   customer_status=1,
							                   register_date=NOW()";	
					$objDatabase->Execute($query);													
					
					$customerid = $objDatabase->Insert_ID();
				}
				$_SESSION['shop']['customerid']= $customerid;
				
				// Add to order table
				$query = "INSERT INTO ".DBPREFIX."module_shop_orders 
					                   SET customerid=$customerid,
										   selected_currency_id='{$_SESSION['shop']['currencyId']}',
										   currency_order_sum ='{$_SESSION['shop']['grand_total_price']}',
										   order_date=NOW(),
										   order_status='0',
										   ship_company='".trim($_SESSION['shop']['company2']," \t")."',
				                           ship_prefix='".trim($_SESSION['shop']['prefix2']," \t")."',
										   ship_firstname='".trim($_SESSION['shop']['firstname2']," \t")."',			
										   ship_lastname='".trim($_SESSION['shop']['lastname2']," \t")."',			
										   ship_address='".trim($_SESSION['shop']['address2']," \t")."',			
										   ship_city='".trim($_SESSION['shop']['city2']," \t")."',
										   ship_zip='".trim($_SESSION['shop']['zip2']," \t")."',						
										   ship_country_id='".intval($_SESSION['shop']['countryId2'])."',
										   ship_phone='".trim($_SESSION['shop']['phone2']," \t")."',
				                           currency_ship_price='{$_SESSION['shop']['shipment_price']}',
				                           shipping_id='{$_SESSION['shop']['shipmentId']}',
										   payment_id ='{$_SESSION['shop']['paymentId']}',
										   currency_payment_price = '{$_SESSION['shop']['payment_price']}',
										   customer_ip='$customer_ip',
										   customer_host='$customer_host',
										   customer_lang='$customer_lang',
										   customer_browser='$customer_browser',
				                           customer_note = '{$_SESSION['shop']['customer_note']}'";
				$objDatabase->Execute($query);
	
				$orderid = $objDatabase->Insert_ID();				
				$_SESSION['shop']['orderid'] = $orderid;				
				
				foreach ($_SESSION['shop']['cart']['products'] as $cartProdId => $arrProduct){
					$objResult = $objDatabase->SelectLimit("SELECT title,
					                      normalprice,
					                      resellerprice,
					                      discountprice,
					                      is_special_offer
					                 FROM ".DBPREFIX."module_shop_products   
					                WHERE status = 1 
					                  AND id = ".$arrProduct['id'], 1);
					if ($objResult !== false && $objResult->RecordCount() == 1) {
				        $price = $this->_getProductPrice($objResult->fields['normalprice'], $objResult->fields['resellerprice'],$objResult->fields['discountprice'],$objResult->fields['is_special_offer']);		        		        	
						$productName = $objResult->fields['title'];
						
				        // Add to order items table
						$objDatabase->Execute("INSERT INTO ".DBPREFIX."module_shop_order_items 
							                SET orderid = $orderid,
									            productid=".$arrProduct['id'].",
						                        product_name='$productName',
												price ='".($price+$arrProduct['optionPrice'])."',
												quantity=".$arrProduct['quantity']);
						$orderItemsId = $objDatabase->Insert_ID();
						
						foreach ($arrProduct['options'] as $optionId => $arrValueIds) {
							foreach ($arrValueIds as $valueId) {
								// add product attributes to order items attribute table
								$query = "INSERT INTO ".DBPREFIX."module_shop_order_items_attributes
												  SET order_items_id=".$orderItemsId.",
												  	  order_id='$orderid',
													  product_id=".$arrProduct['id'].",
													  product_option_name='".$this->arrProductAttributes[$arrProduct['id']][$optionId]['name']."',
													  product_option_value='".$this->arrProductAttributes[$arrProduct['id']][$optionId]['values'][$valueId]['value']."',
													  product_option_values_price='".$this->objCurrency->getCurrencyPrice($this->arrProductAttributes[$arrProduct['id']][$optionId]['values'][$valueId]['price'])."',
													  price_prefix='".$this->arrProductAttributes[$arrProduct['id']][$optionId]['values'][$valueId]['price_prefix']."'";
								$objDatabase->Execute($query);
							}
						}
						

					}
				}
            }
            
            $objLanguage = new FWLanguage();
    		$this->objProcessing->initProcessor($this->objPayment->arrPaymentObject[$_SESSION['shop']['paymentId']]['processor_id'],
    		                                    $this->objCurrency->getActiveCurrencyParameter('code'),
    		                                    $objLanguage->getLanguageParameter($this->langId,'lang'));
			$this->_objTpl->setVariable('SHOP_PAYMENT_PROCESSING',$this->objProcessing->checkOut());
	    } 
	    // Show confirming page
	    else 
	    { 
		    $this->_objTpl->hideBlock("shopProcess");		    
	    	$this->_objTpl->setCurrentBlock("shopCartRow");
			foreach ($_SESSION['shop']['cart']['products'] as $cartProdId => $arrProduct) {
				$objResult = $objDatabase->SelectLimit("SELECT title,
				                   catid,
				                   normalprice,
				                   resellerprice,
				                   discountprice,
				                   is_special_offer
				              FROM ".DBPREFIX."module_shop_products   
				             WHERE status = 1 
				               AND id = ".$arrProduct['id'], 1);
				if ($objResult !== false && $objResult->RecordCount()==1) {
			        $price = $this->_getProductPrice($objResult->fields['normalprice'], $objResult->fields['resellerprice'],$objResult->fields['discountprice'], $objResult->fields['is_special_offer']);
			        
			        if (isset($arrProduct['optionPrice'])) {
			        	$priceOptions = $arrProduct['optionPrice'];
			        } else {
			        	$priceOptions = 0;
			        }
			        
		            if (isset($arrProduct['options'])) {
		            	$productOptions = "<br /><i>";
						foreach ($arrProduct['options'] as $optionId => $arrValueIds) {
							$productOptions .= "-".$this->arrProductAttributes[$arrProduct['id']][$optionId]['name'].": ";
							foreach ($arrValueIds as $valueId) {
								$productOptions .= $this->arrProductAttributes[$arrProduct['id']][$optionId]['values'][$valueId]['value']."; ";
							}
							$productOptions = substr($productOptions,0,strlen($productOptions)-2)."<br />";
						}
						$productOptions = substr($productOptions,0,strlen($productOptions)-6)."</i>";
		            } else {
		            	$productOptions = "";
		            }
			        
			        $this->_objTpl->setVariable(array(
				        'SHOP_PRODUCT_ID' => $arrProduct['id'],
				        'SHOP_PRODUCT_TITLE' => $objResult->fields['title'].$productOptions,
				        'SHOP_PRODUCT_PRICE' => $this->objCurrency->formatPrice(($price+$priceOptions)*$arrProduct['quantity']),	        			                
				        'SHOP_PRODUCT_QUANTITY' => $arrProduct['quantity'],     		        
				        'SHOP_PRODUCT_ITEMPRICE' => $this->objCurrency->formatPrice($price+$priceOptions),
				        'SHOP_UNIT'  => $this->aCurrencyUnitName,        
				        ));
				    $this->_objTpl->parse("shopCartRow");
				}	     
			}
			
		    $this->_objTpl->setVariable(array(
		    	'SHOP_UNIT' => $this->aCurrencyUnitName,	
				'SHOP_TOTALITEM' => $_SESSION['shop']['items'],
				'SHOP_SHIPMENT_PRICE' => $_SESSION['shop']['shipment_price'],
				'SHOP_PAYMENT_PRICE' => $_SESSION['shop']['payment_price'],
				'SHOP_TOTALPRICE' => $_SESSION['shop']['total_price'],								
				'SHOP_SHIPMENT' => $this->objShipment->arrActiveShipmentMethods[$_SESSION['shop']['shipmentId']]['name'],
				'SHOP_PAYMENT' => $this->objPayment->arrPaymentObject[$_SESSION['shop']['paymentId']]['name'],											 			      	        
				'SHOP_GRAND_TOTAL' => $_SESSION['shop']['grand_total_price'], 	
				'SHOP_CUSTOMERNOTE' => $_SESSION['shop']['customer_note'],		
				'SHOP_TAX_PRICE' => $_SESSION['shop']['tax_price'],
				'SHOP_TAX_PRODUCTS_TXT' => $_SESSION['shop']['tax_products_txt'],
				'SHOP_TAX_GRAND_TXT' => $_SESSION['shop']['tax_grand_txt'],
				'SHOP_TAX_PROCENTUAL'=> $_SESSION['shop']['tax_procentual'],						  				
				'SHOP_COMPANY' => stripslashes($_SESSION['shop']['company']),
				'SHOP_PREFIX' => stripslashes($_SESSION['shop']['prefix']),
				'SHOP_LASTNAME'	=> stripslashes($_SESSION['shop']['lastname']),
				'SHOP_FIRSTNAME'=> stripslashes($_SESSION['shop']['firstname']),
				'SHOP_ADDRESS' => stripslashes($_SESSION['shop']['address']),
				'SHOP_ZIP' => stripslashes($_SESSION['shop']['zip']),
				'SHOP_CITY'	=> stripslashes($_SESSION['shop']['city']),
				'SHOP_COUNTRY'	=> $this->arrCountries[$_SESSION['shop']['countryId']]['countries_name'],
				'SHOP_EMAIL'=> stripslashes($_SESSION['shop']['email']),
				'SHOP_PHONE'=> stripslashes($_SESSION['shop']['phone']),
				'SHOP_FAX'	=> stripslashes($_SESSION['shop']['fax']),
				'SHOP_COMPANY2'	=> stripslashes($_SESSION['shop']['company2']),
				'SHOP_PREFIX2'=> stripslashes($_SESSION['shop']['prefix2']),
				'SHOP_LASTNAME2'=> stripslashes($_SESSION['shop']['lastname2']),
				'SHOP_FIRSTNAME2'=> stripslashes($_SESSION['shop']['firstname2']),
				'SHOP_ADDRESS2'	=> stripslashes($_SESSION['shop']['address2']),
				'SHOP_ZIP2'	=> stripslashes($_SESSION['shop']['zip2']),
				'SHOP_CITY2'=> stripslashes($_SESSION['shop']['city2']),
				'SHOP_COUNTRY2'	=> $this->arrCountries[$_SESSION['shop']['countryId2']]['countries_name'],
				'SHOP_PHONE2'=> stripslashes($_SESSION['shop']['phone2']),
				'TXT_ORDER_INFOS' => $_ARRAYLANG['TXT_ORDER_INFOS'],		
				'TXT_ID' => $_ARRAYLANG['TXT_ID'],
				'TXT_PRODUCT' => $_ARRAYLANG['TXT_PRODUCT'],
				'TXT_UNIT_PRICE' => $_ARRAYLANG['TXT_UNIT_PRICE'],				
				'TXT_QUANTITY' => $_ARRAYLANG['TXT_QUANTITY'],				
				'TXT_TOTAL' => $_ARRAYLANG['TXT_TOTAL'],				
				'TXT_INTER_TOTAL' => $_ARRAYLANG['TXT_INTER_TOTAL'],
				'TXT_PRODUCT_S' => $_ARRAYLANG['TXT_PRODUCT_S'],
				'TXT_SHIPPING_METHOD' => $_ARRAYLANG['TXT_SHIPPING_METHOD'],				
				'TXT_PAYMENT_TYPE' => $_ARRAYLANG['TXT_PAYMENT_TYPE'],				
				'TXT_PROCENTUAL_TAX_PART' => $_ARRAYLANG['TXT_PROCENTUAL_TAX_PART'],				
				'TXT_TAX_PART' => $_ARRAYLANG['TXT_TAX_PART'],
				'TXT_TOTAL_PRICE' => $_ARRAYLANG['TXT_TOTAL_PRICE'],	
				'TXT_ADDRESS_CUSTOMER' => $_ARRAYLANG['TXT_ADDRESS_CUSTOMER'],					
				'TXT_SHIPPING_ADDRESS' => $_ARRAYLANG['TXT_SHIPPING_ADDRESS'],					
				'TXT_COMMENTS' => $_ARRAYLANG['TXT_COMMENTS'],					
				'TXT_ORDER_NOW' => $_ARRAYLANG['TXT_ORDER_NOW']								
			));	    	        	    
	    } // end if process	
	    $this->_objTpl->setVariable('SHOP_STATUS',$statusMessage);		    
    }
    
    

    
	/**
	* Receives data from the payment offerer
	*
	* Receives the data from the payment offerer and check if it is correct.
	*
	* @access public
	*/
    function success()
    {
    	global $_ARRAYLANG;
    	// hide currency navbar
    	$this->_hideCurrencyNavbar=true; 
    	
    	// check for active session otherwise redirect to shop start page
//    	if (!isset($_SESSION['shop']['cart'])){
//			header("Location: ?section=shop");
//			exit;
//    	}
   	
    	$orderId = $this->objProcessing->checkIn();

    	if (isset($orderId) && !empty($orderId) && $this->_checkPaymentValidation($orderId)) {
			$statusMessage = $_ARRAYLANG['TXT_ORDER_PROCESSED'];
    	} else {
    		$statusMessage = $_ARRAYLANG['TXT_NO_PENDING_ORDER'];
    	}   	
    	$this->_objTpl->setVariable('SHOP_STATUS',$statusMessage);
    	$this->destroyCart();
    }

    
    
    
    /**
	* Check payment validation
	*
	* If the order exists and it wasn't already set to paid, do this and send an mail to the customer and the shop owners
	*
	* @access private
	* @return boolean validation
	* @see shopSendmail()
	*/
    function _checkPaymentValidation($orderId)
    {
    	global $objDatabase;
    	
    	$query = "SELECT order_status FROM ".DBPREFIX."module_shop_orders WHERE orderid = ".intval($orderId);
    	$objResult = $objDatabase->Execute($query);
    	if ($objResult->fields['order_status'] == 1) {
    		$this->_sendProcessedMail();
    		return true;
    	} else {
			$query = "UPDATE ".DBPREFIX."module_shop_orders
	              		 SET order_status='1'
	                   WHERE orderid =".intval($orderId);
	
			if (($objResult = $objDatabase->Execute($query))) {
				$this->_sendProcessedMail();
				return true;
			} else {
				return false;
			}
    	}
    }
    
    
    /**
     * Sends an email with the order data
     *
     * @access private
     * @see _checkPaymentValidation()
     */
    function _sendProcessedMail()
	{
		$this->shopSetMailtemplate(1);
		$mailTo = $_SESSION['shop']['email'];
		$mailFrom = $this->arrShopMailTemplate['mail_from'];
		$mailFromText = $this->arrShopMailTemplate['mail_x_sender'];
		$mailSubject = $this->arrShopMailTemplate['mail_subject'];
		$mailBody = $this->arrShopMailTemplate['mail_body'];
		$today = date("d.m.Y");			    
		$mailSubject = str_replace("<DATE>",$today,$mailSubject);	
	    $mailBody = $this->_generateEmailBody($mailBody); 													
		$this->shopSendmail($mailTo,$mailFrom,$mailFromText,$mailSubject,$mailBody);
		$copies = explode(",",trim($this->arrConfig['confirmation_emails']['value']));
	    foreach($copies as $sendTo){	
			$this->shopSendmail($sendTo,$mailFrom,$mailFromText,$mailSubject,$mailBody);
	    }    	
    }
    
    
    /**
	* replace all substitute symbols and generates the email body
	*  
	*
	* @access private
	* @return string emailbody
	* @param string emailbody
	*/
    function _generateEmailBody($body)
    {		
		global $objDatabase, $_ARRAYLANG, $objDatabase;
		
		$body=stripslashes($body);
		$today = date("d.m.Y");
		$cartTxt = "";
		
        $customerAddress = "\n".stripslashes($_SESSION['shop']['company'])."\n".stripslashes($_SESSION['shop']['prefix'])." ".stripslashes($_SESSION['shop']['firstname'])." ".stripslashes($_SESSION['shop']['lastname']).
                           "\n".stripslashes($_SESSION['shop']['address'])."\n".stripslashes($_SESSION['shop']['zip'])." ".stripslashes($_SESSION['shop']['city']).
                           "\n".$this->arrCountries[$_SESSION['shop']['countryId']]['countries_name']."\n";
		
        $shippingAddress = "\n".stripslashes($_SESSION['shop']['company2'])."\n".stripslashes($_SESSION['shop']['prefix2'])." ".stripslashes($_SESSION['shop']['firstname2'])." ".stripslashes($_SESSION['shop']['lastname2']).
                           "\n".stripslashes($_SESSION['shop']['address2'])."\n".stripslashes($_SESSION['shop']['zip2'])." ".stripslashes($_SESSION['shop']['city2']).
                           "\n".$this->arrCountries[$_SESSION['shop']['countryId2']]['countries_name']."\n";
                           
                           
		foreach ($_SESSION['shop']['cart']['products'] as $cartProdId => $arrProduct) {
			$objResult = $objDatabase->SelectLimit("SELECT id,
			                      title,
			                      catid,
			                      normalprice,
			                      resellerprice,
			                      discountprice,
			                      is_special_offer
			                 FROM ".DBPREFIX."module_shop_products   
			                WHERE status = 1 
			                  AND id = ".$arrProduct['id'], 1);
			if ($objResult !== false && $objResult->RecordCount()==1) {
		        $price = $this->_getProductPrice($objResult->fields['normalprice'], $objResult->fields['resellerprice'], $objResult->fields['discountprice'],$objResult->fields['is_special_offer']);
	            $productName = substr($objResult->fields['title'], 0, 40);
	            
		        if (isset($arrProduct['optionPrice'])) {
		        	$price += $arrProduct['optionPrice'];
		        } else {
		        	$priceOptions = 0;
		        }
	            
	            if (isset($arrProduct['options']) && count($arrProduct['options'])>0) {
	            	$productOptions = " (";
					foreach ($arrProduct['options'] as $optionId => $arrValueIds) {
						$productOptions .= $this->arrProductAttributes[$arrProduct['id']][$optionId]['name'].": ";
						foreach ($arrValueIds as $valueId) {
							$productOptions .= $this->arrProductAttributes[$arrProduct['id']][$optionId]['values'][$valueId]['value'].", ";
						}
						$productOptions = substr($productOptions,0,strlen($productOptions)-2)."; ";
					}
					$productOptions = substr($productOptions,0,strlen($productOptions)-2).")";
	            } else {
	            	$productOptions = "";
	            }
	            
	            
		        $cartTxt .= $objResult->fields['id']." | ".
	                        $productName.$productOptions." | ".
	                        $price." ".$this->aCurrencyUnitName." | ".
	                        $arrProduct['quantity']." | ".
	                        $this->objCurrency->formatPrice($price*$arrProduct['quantity'])." ".$this->aCurrencyUnitName."\n";	
	                        
	            // Taxes are enabled
	            $taxTxt = "";
	            if ($this->arrConfig['tax_number']['status']==1) {
	            	$taxTxt = $_ARRAYLANG['TXT_TAX_PART'].": ".$_SESSION['shop']['tax_procentual']." - ".$_SESSION['shop']['tax_grand_txt']." ".$this->aCurrencyUnitName;
	            }
			}
		}
        $orderData = <<<ENDOFTEXT
-----------------------------------------------------------------
{$_ARRAYLANG['TXT_ORDER_INFOS']}:
-----------------------------------------------------------------  
{$_ARRAYLANG['TXT_ID']} | {$_ARRAYLANG['TXT_PRODUCT']} | {$_ARRAYLANG['TXT_UNIT_PRICE']} | {$_ARRAYLANG['TXT_QUANTITY']} | {$_ARRAYLANG['TXT_TOTAL']}
-----------------------------------------------------------------   
$cartTxt
-----------------------------------------------------------------    
{$_ARRAYLANG['TXT_INTER_TOTAL']}: {$_SESSION['shop']['items']} {$_ARRAYLANG['TXT_PRODUCT_S']} {$_SESSION['shop']['total_price']} $this->aCurrencyUnitName  
-----------------------------------------------------------------   
{$_ARRAYLANG['TXT_SHIPPING_METHOD']}: {$this->objShipment->arrActiveShipmentMethods[$_SESSION['shop']['shipmentId']]['name']} | {$_SESSION['shop']['shipment_price']} $this->aCurrencyUnitName 
{$_ARRAYLANG['TXT_PAYMENT_TYPE']}: {$this->objPayment->arrPaymentObject[$_SESSION['shop']['paymentId']]['name']} | {$_SESSION['shop']['payment_price']} $this->aCurrencyUnitName  
$taxTxt 
-----------------------------------------------------------------  
{$_ARRAYLANG['TXT_TOTAL_PRICE']}: {$_SESSION['shop']['grand_total_price']} $this->aCurrencyUnitName 
----------------------------------------------------------------- 
ENDOFTEXT;

        $orderSum = $_SESSION['shop']['grand_total_price']." ".$this->aCurrencyUnitName;

    	$search  = array ('<ORDER_ID>', '<CUSTOMER_ID>', '<CUSTOMER_EMAIL>', '<DATE>', 
    	                  '<USERNAME>', '<PASSWORD>', '<CUSTOMER_ADDRESS>', '<SHIPPING_ADDRESS>',
    	                  '<ORDER_DATA>', '<ORDER_SUM>', '<REMARKS>');
    	                  
		$replace = array ($_SESSION['shop']['orderid'], $_SESSION['shop']['customerid'], $_SESSION['shop']['email'], $today, 
		                  $_SESSION['shop']['email'],$_SESSION['shop']['password'], $customerAddress, $shippingAddress,
		                  $orderData, $orderSum, strip_tags($_SESSION['shop']['customer_note']));
		                  
		return str_replace($search, $replace, $body);
    }    
}  
?>