<?php
/**
* Class Shop 
*
* Manages shop settings storing
*
* @copyright    ASTALAVISTA SECURE CMS - 2004 Astalavista IT Engineering 
* @author       Ivan Schmid <ivan.schmid@astalavista.ch>  
* @package		shop
*/
class Settings
{
	/**
	* Database link object
	* @access private
	* @var object
	* @see __construct()
	*/
	var $_objDatabase;	
	
	/**
	* ADORecordSet
	* @access private
	* @var object
	*/
	var $_objResult;

	/**
	* Array of all countries
	*
	* @var array [$arrCountries] array of all countries
	* @access public
	* @see _initCountries()
	*/  	
	var $arrCountries = array();
	
	/**
	* PHP4 Constructor
	*/
	function Settings()
	{
		$this->__construct();
	}

	/**
	* PHP5 Constructor
	*/	
	function __construct()
	{
		global $objDatabase;
        $this->_objDatabase = $objDatabase;
		
        $this->_storeGeneral();
        
        $this->_deleteCurrency();
        $this->_storeNewCurrency();
        $this->_storeCurrencies();
        
        $this->_deletePayment();
        $this->_storeNewPayments();
        $this->_storePayments();
        
        $this->_deleteShipment();
        $this->_storeNewShipment();
        $this->_storeShipment();
        
        $this->_storeCountries();
        
        $this->_deleteZone();
        $this->_storeNewZone();
        $this->_storeZones();
        
        $this->_delMailTpl();
        $this->_addMail();
        $this->_storeMails();
	}
	
	function _initCountries()
    {
     	$query = "SELECT countries_id, 
     	                   countries_name,
		                   countries_iso_code_2, 
		                   countries_iso_code_3,
     	                   activation_status
		              FROM ".DBPREFIX."module_shop_countries
     	             ORDER BY countries_id"; 
     	
     	$this->_objResult = $this->_objDatabase->Execute($query);
     		                    	
	 	while(!$this->_objResult->EOF) {
			$this->arrCountries[$this->_objResult->fields['countries_id']]= array(
	           'countries_id' => $this->_objResult->fields['countries_id'],
	           'countries_name' => $this->_objResult->fields['countries_name'],
	           'countries_iso_code_2' => $this->_objResult->fields['countries_iso_code_2'],
	           'countries_iso_code_3' => $this->_objResult->fields['countries_iso_code_3'],
	           'activation_status' => $this->_objResult->fields['activation_status']
	           );
	        $this->_objResult->MoveNext();
		}
    }

    /**
	* Store general settings
	*/
	function _storeGeneral()
	{
		if(isset($_POST['general']) && !empty($_POST['general']))
		{
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config 
									Set value='".addslashes($_POST['email'])."'
									WHERE name='email'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".addslashes($_POST['confirmation_emails'])."'
									WHERE name='confirmation_emails'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".addslashes($_POST['telephone'])."'
									WHERE name='telephone'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".addslashes($_POST['fax'])."'
									WHERE name='fax'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".addslashes($_POST['yellowpay_id'])."', status=".intval($_POST['yellowpay_status'])."
									WHERE name='yellowpay_id'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".addslashes($_POST['yellowpay_hash_seed'])."'
									WHERE name='yellowpay_hash_seed'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".addslashes($_POST['yellowpay_delivery_payment_type'])."'
									WHERE name='yellowpay_delivery_payment_type'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".addslashes($_POST['saferpay_id'])."', status=".intval($_POST['saferpay_status'])."
									WHERE name='saferpay_id'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value=".intval($_POST['saferpay_finalize_payment'])."
									WHERE name='saferpay_finalize_payment'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config 
			                         SET status='".intval($_POST['saferpay_use_test_account'])."'
			                       WHERE name='saferpay_use_test_account'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config 
			                         SET value='".intval($_POST['saferpay_window_option'])."'
			                       WHERE name='saferpay_window_option'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".addslashes($_POST['paypal_account_email'])."', status=".intval($_POST['paypal_status'])."
									WHERE name='paypal_account_email'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".addslashes($_POST['tax_number'])."', status='".intval($_POST['tax_number_status'])."'
									WHERE name='tax_number'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".addslashes($_POST['tax_percentaged_value'])."'
									WHERE name='tax_percentaged_value'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".intval($_POST['tax_included'])."'
									WHERE name='tax_included'"
								);
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_config
									Set value='".intval($_POST['country_id'])."'
									WHERE name='country_id'"
								);
								
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_config");
		}
	}

	/**
	* Delete currency
	*/
	function _deleteCurrency()
	{
		if(isset($_GET['currencyId']) && !empty($_GET['currencyId'])) {
			$this->_objDatabase->Execute("DELETE FROM ".DBPREFIX."module_shop_currencies WHERE id=".intval($_GET['currencyId'])." AND is_default=0");
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_currencies");
		}
	}
	
	/**
	* Store new currency
	*/
	function _storeNewCurrency()
	{
		if(isset($_POST['currency_add']) && !empty($_POST['currency_add'])) {
			$_POST['currencyActiveNew'] = isset($_POST['currencyActiveNew']) ? 1 : 0;
			$_POST['currencyDefaultNew'] = isset($_POST['currencyDefaultNew']) ? 1 : 0;

			$query = "INSERT INTO ".DBPREFIX."module_shop_currencies
									    (code, symbol, name, rate, status, is_default)
								 VALUES ('".addslashes($_POST['currencyCodeNew'])."',
										 '".addslashes($_POST['currencySymbolNew'])."',
										 '".addslashes($_POST['currencyNameNew'])."',
										 '".addslashes($_POST['currencyRateNew'])."',
										 ".intval($_POST['currencyActiveNew']).",
										 ".intval($_POST['currencyDefaultNew']).")";
								
			$this->_objResult = $this->_objDatabase->Execute($query);
			$cId = $this->_objDatabase->Insert_Id();
			if($_POST['currencyDefaultNew']) {
				$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_currencies Set is_default=0 WHERE id!=".intval($cId));
			}
			
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_currencies");
		}
	}
	
	/**
	* Store currency settings
	*/
	function _storeCurrencies()
	{
		if(isset($_POST['currency']) && !empty($_POST['currency'])) {
		 	foreach ($_POST['currencyCode'] as $cId => $value){	 		
		 		$is_default=($_POST['currencyDefault']==$cId)?1:0;	 		
		 		$status = isset($_POST['currencyActive'][$cId])?1:0;
		 		// default currency must be activated
		 		$is_active = ($is_default==1 && $status==0)?1:$status;

				$query = "UPDATE ".DBPREFIX."module_shop_currencies
			                           SET code='".addslashes($value)."',
										   symbol='".addslashes($_POST['currencySymbol'][$cId])."',
										   name='".addslashes($_POST['currencyName'][$cId])."',	
										   rate='".addslashes($_POST['currencyRate'][$cId])."',
										   status=".intval($is_active).",
										   is_default=".intval($is_default)."
			                     WHERE id =".intval($cId);
				
				$this->_objDatabase->Execute($query);
			} // end foreach
			
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_currencies");
	    }
	}
	
	/**
	* Delete payment method
	*/
	function _deletePayment()
	{
		if(isset($_GET['paymentId']) && !empty($_GET['paymentId'])) {
			$this->_objResult = $this->_objDatabase->SelectLimit("SELECT id FROM ".DBPREFIX."module_shop_payment", 2, 0);
			if($this->_objResult->RecordCount() == 2) {
				$this->_objDatabase->Execute("DELETE FROM ".DBPREFIX."module_shop_payment WHERE id=".intval($_GET['paymentId']));
				$this->_objDatabase->Execute("DELETE FROM ".DBPREFIX."module_shop_rel_payment WHERE payment_id=".intval($_GET['paymentId']));
				
				$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_payment");
				$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_rel_payment");
			}
		}
	}
	
	/**
	* Store new payment method
	*/
	function _storeNewPayments()
	{
		if(isset($_POST['payment_add']) && !empty($_POST['payment_add'])) {
			$_POST['paymentActive_new'] = isset($_POST['paymentActive_new']) ? 1 : 0;

			$query = "INSERT INTO ".DBPREFIX."module_shop_payment (
											  name,
											  processor_id,
											  costs,
											  costs_free_sum,
											  status
											  ) VALUES (
											  '".addslashes($_POST['paymentName_new'])."',
											  '".intval($_POST['paymentHandler_new'])."',
											  '".addslashes($_POST['paymentCosts_new'])."',
											  '".addslashes($_POST['paymentCostsFreeSumNew'])."',
											  ".intval($_POST['paymentActive_new']).")";
			
			$this->_objDatabase->Execute($query);
			$pId = $this->_objDatabase->Insert_ID();
			$this->_objDatabase->Execute("INSERT INTO ".DBPREFIX."module_shop_rel_payment (zones_id, payment_id) VALUES (".intval($_POST['paymentZone_new']).",".intval($pId).")");

			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_payment");
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_rel_payment");
		}
	}
	
	/**
	* Store payment settings
	*/
	function _storePayments()
	{
		if(isset($_POST['payment']) && !empty($_POST['payment'])) {
			foreach ($_POST['paymentName'] as $pId => $value) {
				$_POST['paymentActive'][$pId] = isset($_POST['paymentActive'][$pId]) ? 1 : 0;

				$query = "UPDATE ".DBPREFIX."module_shop_payment
										Set name='".addslashes($value)."',
											processor_id='".intval($_POST['paymentHandler'][$pId])."',
											costs='".addslashes($_POST['paymentCosts'][$pId])."',
				 							costs_free_sum='".addslashes($_POST['paymentCostsFreeSum'][$pId])."',
											status='".intval($_POST['paymentActive'][$pId])."'
										WHERE id=".intval($pId);
									
				$this->_objDatabase->Execute($query);

									
				if($_POST['old_paymentZone'][$pId] != $_POST['paymentZone'][$pId]) {
					$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_rel_payment Set zones_id='".intval($_POST['paymentZone'][$pId])."' WHERE payment_id=".intval($pId));
					if(!$this->_objDatabase->Affected_Rows()) {
						$this->_objDatabase->Execute("INSERT INTO ".DBPREFIX."module_shop_rel_payment
											  (zones_id, payment_id) VALUES (".intval($_POST['paymentZone'][$pId]).", ".intval($pId).")");
					}
				}
			}
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_payment");
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_rel_payment");
		}
	}
	
	/**
	* Delete shipment method
	*/
	function _deleteShipment()
	{
		if(isset($_GET['shipmentId']) && !empty($_GET['shipmentId'])) {
			$this->_objResult = $this->_objDatabase->SelectLimit("SELECT id FROM ".DBPREFIX."module_shop_shipment", 2, 0);
			if($this->_objResult->Affected_Rows() == 2) {
				$this->_objDatabase->Execute("DELETE FROM ".DBPREFIX."module_shop_shipment WHERE id=".intval($_GET['shipmentId']));
				$this->_objDatabase->Execute("DELETE FROM ".DBPREFIX."module_shop_rel_shipment WHERE shipment_id=".intval($_GET['shipmentId']));
				
				$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_shipment");
				$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_rel_shipment");
			}
		}		
	}
	
	/**
	* Store new shipment method
	*/
	function _storeNewShipment()
	{
		if(isset($_POST['shipment_add']) && !empty($_POST['shipment_add'])) {
			$_POST['shipmentActiveNew'] = isset($_POST['shipmentActiveNew']) ? 1 : 0;

			$query = "INSERT INTO ".DBPREFIX."module_shop_shipment
									    (name, costs, costs_free_sum, status)
								 VALUES ('".addslashes($_POST['shipmentNameNew'])."',
										'".addslashes($_POST['shipmentCostsNew'])."',
										'".addslashes($_POST['shipmentCostsFreeSumNew'])."',
										 ".intval($_POST['shipmentActiveNew']).")";
			$this->_objDatabase->Execute($query);
			
			$sId = $this->_objDatabase->Insert_ID();
			$this->_objDatabase->Execute("INSERT INTO ".DBPREFIX."module_shop_rel_shipment (zones_id, shipment_id) VALUES (".intval($_POST['shipmentZoneNew']).",".intval($sId).")");
			
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_shipment");
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_rel_shipment");
		}
	}
	
	/**
	* Store shipment settings
	*/
	function _storeShipment()
	{
		if(isset($_POST['shipment']) && !empty($_POST['shipment'])) {
			foreach ($_POST['shipmentName'] as $sId => $value) {
				$_POST['shipmentActive'][$sId] = isset($_POST['shipmentActive'][$sId]) ? 1 : 0;

				$query = "UPDATE ".DBPREFIX."module_shop_shipment
										Set name='".addslashes($value)."',
											costs='".addslashes($_POST['shipmentCosts'][$sId])."',
											costs_free_sum='".addslashes($_POST['shipmentCostsFreeSum'][$sId])."',
											status='".intval($_POST['shipmentActive'][$sId])."'
										WHERE id='".intval($sId)."'";
				
				$this->_objDatabase->Execute($query);
				if($_POST['old_shipmentZone'][$sId] != $_POST['shipmentZone'][$sId]) {
					$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_rel_shipment Set zones_id='".intval($_POST['shipmentZone'][$sId])."' WHERE shipment_id=".intval($sId));
					if(!$this->_objDatabase->Affected_Rows()) {
						$this->_objDatabase->Execute("INSERT INTO ".DBPREFIX."module_shop_rel_shipment
											  (zones_id, shipment_id) VALUES (".intval($_POST['shipmentZone'][$sId]).", ".intval($sId).")");
					}
				}
			}
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_shipment");
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_rel_shipment");
		}
	}
	
	/**
	* Store countries settings
	*/
	function _storeCountries()
	{
		if(isset($_POST['countries']) && !empty($_POST['countries'])) {
			$this->_initCountries();
			$updateList = count($_POST['list1']) < count($_POST['list2']) ? 'list1' : 'list2';
			if(!isset($_POST[$updateList])) {
				$_POST[$updateList] = array();
			}
			// Set new list
			foreach ($this->arrCountries as $cValues) {
				if($cValues['activation_status'] == ($updateList == 'list1' ? 1 : 0)) {
					if(!in_array($cValues['countries_id'],$_POST[$updateList])) {
						$query = "UPDATE ".DBPREFIX."module_shop_countries
													Set activation_status=".($updateList == 'list1' ? 0 : 1)."
													WHERE countries_id=".intval($cValues['countries_id']);
						$this->_objDatabase->Execute($query);
					} else {
						unset($_POST[$updateList][array_search($cValues['countries_id'],$_POST[$updateList])]);
					}
				}
			}
			foreach ($_POST[$updateList] as $cId) {
				$query = "UPDATE ".DBPREFIX."module_shop_countries
											Set activation_status=".($updateList == 'list1' ? 1 : 0)."
											WHERE countries_id=".intval($cId);
				$this->_objDatabase->Execute($query);
			}
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_countries");
		}
	}
	
	/*
	* Delete Zone
	*/
	function _deleteZone()
	{
		if(isset($_GET['zonesId']) && !empty($_GET['zonesId'])) {
			// Delete zone
			$this->_objDatabase->Execute("DELETE FROM ".DBPREFIX."module_shop_zones WHERE zones_id=".intval($_GET['zonesId']));
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_zones");
			
			// Delete country relations
			$this->_objDatabase->Execute("DELETE FROM ".DBPREFIX."module_shop_rel_countries WHERE zones_id=".intval($_GET['zonesId']));
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_rel_countries");
			
			// Update relations
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_rel_payment Set zones_id=1 WHERE zones_id=".intval($_GET['zonesId']));
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_rel_payment");
			$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_rel_shipment Set zones_id=1 WHERE zones_id=".intval($_GET['zonesId']));
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_rel_shipment");
		}
	}
	
	/**
	* Store new zone
	*/
	function _storeNewZone()
	{
		if(isset($_POST['zones_new']) && !empty($_POST['zones_new'])) {
			$this->_objDatabase->Execute("INSERT INTO ".DBPREFIX."module_shop_zones (zones_name, activation_status) VALUES ('".addslashes($_POST['zone_name_new'])."',".(isset($_POST['zone_active_new']) ? 1 : 0).")");
			$zId = $this->_objDatabase->Insert_ID();
			
			if(isset($_POST['selected_countries'])) {
				foreach ($_POST['selected_countries'] as $cId) {
					$this->_objDatabase->Execute("INSERT INTO ".DBPREFIX."module_shop_rel_countries (zones_id, countries_id) VALUES (".intval($zId).",".intval($cId).")");
				}
				$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_rel_countries");
			}
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_zones");
		}		
	}
	
	/**
	* Store zone settings
	*/
	function _storeZones()
	{
		if(isset($_POST['zones']) && !empty($_POST['zones'])) {
			$query= "SELECT zones_id, countries_id FROM ".DBPREFIX."module_shop_rel_countries";
			$this->_objResult = $this->_objDatabase->Execute($query);
			if ($this->_objResult !== false) {
				while (!$this->_objResult->EOF) {
					if(!isset($arrRelCountries[$this->_objResult->fields['zones_id']]['countries'])) {
						$arrRelCountries[$this->_objResult->fields['zones_id']]['countries'] = array();
					}
					array_push($arrRelCountries[$this->_objResult->fields['zones_id']]['countries'],$this->_objResult->fields['countries_id']);
					$this->_objResult->MoveNext();
				}
	
				if(isset($_POST['zone_list']) && !empty($_POST['zone_list'])) {
	
					foreach ($_POST['zone_list'] as $zId) {
						$query = "UPDATE ".DBPREFIX."module_shop_zones
												 Set zones_name='".addslashes($_POST['zone_name'][$zId])."',
													 activation_status=".(isset($_POST['zone_active'][$zId]) ? 1 : 0)."
											   WHERE zones_id=".intval($zId);
						
						$this->_objDatabase->Execute($query);
						
						if(isset($arrRelCountries[$zId]['countries'])) {
							foreach ($arrRelCountries[$zId]['countries'] as $cId) {
								if(!in_array($cId,$_POST['selected_countries'][$zId])) {
									$this->_objDatabase->Execute("DELETE FROM ".DBPREFIX."module_shop_rel_countries WHERE zones_id=".intval($zId)." AND countries_id=".intval($cId));
								} else {
									unset($_POST['selected_countries'][$zId][array_search($cId,$_POST['selected_countries'][$zId])]);
								}
							}
						}
						if(isset($_POST['selected_countries'][$zId])) {	
							foreach ($_POST['selected_countries'][$zId] as $cId) {
								$this->_objDatabase->Execute("INSERT INTO ".DBPREFIX."module_shop_rel_countries (zones_id, countries_id) VALUES (".intval($zId).", ".intval($cId).")");
							}
						}
					}
					$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_zones");
					$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_rel_countries");
				}
			}
		}
	}
	
	/**
	* Delete template
	*/
	function _delMailTpl()
	{
		if(isset($_GET['delTplId']) && !empty($_GET['delTplId'])){
			$this->_objDatabase->Execute("DELETE FROM ".DBPREFIX."module_shop_mail WHERE id=".intval($_GET['delTplId'])." AND protected!=1");
			if($this->_objDatabase->affected_rows() == 1){
				$this->_objDatabase->Execute("DELETE FROM ".DBPREFIX."module_shop_mail_content WHERE tpl_id=".intval($_GET['delTplId']));
			}
		}
		if(isset($_GET['delMailId']) && !empty($_GET['delMailId'])){
			$objLanguage = &new FWLanguage();
			$arrLanguage = $objLanguage->arrLanguage;
			foreach ($arrLanguage as $langValues){
				if($langValues['is_default']){
					$defaultLang = $langValues['id'];
					break;
				}
			}
			$this->_objDatabase->Execute("DELETE FROM ".DBPREFIX."module_shop_mail_content WHERE id=".intval($_GET['delMailId'])." AND lang_id!=".$defaultLang);
		}
		if((isset($_GET['delTplId']) && !empty($_GET['delTplId'])) || (isset($_GET['delMailId']) && !empty($_GET['delMailId']))){
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_mail");
			$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_mail_content");
		}
	}
	
	/**
	* Add new template
	*/
	function _addMail()
	{
		if(isset($_POST['mails']) && !empty($_POST['mails'])){
			if($_POST['tplId'] == 0 || (isset($_POST['shopMailSaveNew']) && !empty($_POST['shopMailSaveNew']))){
				
				$query = "INSERT INTO ".DBPREFIX."module_shop_mail (tplname, protected) VALUES ('".addslashes($_POST['shopMailTemplate'])."',0)";
				$this->_objDatabase->Execute($query);
				$tlpId = $this->_objDatabase->Insert_ID();
				
				$objLanguage = &new FWLanguage();
				$arrLanguage = $objLanguage->arrLanguage;
				
				foreach ($arrLanguage as $langValues){
					if($langValues['is_default']){
						$defaultLang = $langValues['id'];
						break;
					}
				}
				
				$query = "INSERT INTO ".DBPREFIX."module_shop_mail_content (
												  tpl_id,
												  lang_id,
												  from_mail,
												  xsender,
												  subject,
												  message
												  ) VALUES (
												  ".intval($tlpId).",
												  ".$defaultLang.",
												  '".addslashes($_POST['shopMailFromAddress'])."',
												  '".addslashes($_POST['shopMailFromName'])."',
												  '".addslashes($_POST['shopMailSubject'])."',
												  '".addslashes($_POST['shopMailBody'])."'
												  )";
				$this->_objDatabase->Execute($query);
				
				$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_mail");
				$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_mail_content");
			}
		}
	}
	
	/**
	* Store mail template
	*/
	function _storeMails()
	{
		if(isset($_POST['mails']) && !empty($_POST['mails'])){
			if(!isset($_POST['shopMailSaveNew']) && ((isset($_POST['shopMailFromName']) && !empty($_POST['shopMailFromName']))
				|| (isset($_POST['shopMailSubject']) && !empty($_POST['shopMailSubject']))
				|| (isset($_POST['shopMailBody']) && !empty($_POST['shopMailBody']))))
			{
				if(isset($_POST['mailId']) && !empty($_POST['mailId']))
				{
					$query = "UPDATE ".DBPREFIX."module_shop_mail_content
											  Set from_mail='".addslashes($_POST['shopMailFromAddress'])."',
												  xsender='".addslashes($_POST['shopMailFromName'])."',
												  subject='".addslashes($_POST['shopMailSubject'])."',
												  message='".addslashes($_POST['shopMailBody'])."'
											WHERE id=".intval($_POST['mailId']);
					$this->_objDatabase->Execute($query);
				} else {
					$this->_objDatabase->Execute("INSERT INTO ".DBPREFIX."module_shop_mail_content (
													  tpl_id,
													  lang_id,
													  from_mail,
													  xsender,
													  subject,
													  message
													  ) VALUES (
													  ".intval($_POST['tplId']).",
													  ".intval($_POST['langId']).",
													  '".addslashes($_POST['shopMailFromAddress'])."',
													  '".addslashes($_POST['shopMailFromName'])."',
													  '".addslashes($_POST['shopMailSubject'])."',
													  '".addslashes($_POST['shopMailBody'])."'
													  )");
				}
				$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_mail_content");
				$this->objResult = $this->_objDatabase->Execute("SELECT protected FROM ".DBPREFIX."module_shop_mail WHERE id=".intval($_POST['tplId']));
				if(!$this->_objResult->EOF){
					if(!$this->_objResult->fields['protected']){
						$this->_objDatabase->Execute("UPDATE ".DBPREFIX."module_shop_mail Set tplname='". addslashes($_POST['shopMailTemplate'])."' WHERE id=".intval($_POST['tplId']));
						$this->_objDatabase->Execute("OPTIMIZE TABLE ".DBPREFIX."module_shop_mail");
					}
				}
			}
		}
	}
}
?>